@@ -113,12 +113,25 @@ def startup(settings_module=None):
     This is usually called in the initialization code snippet of a :doc:`tested
     document </dev/doctests>`.
 
+    If your doctest reports a failure of the following type::
+
+        Failed example:
+            startup('lino_amici.projects.amici1.settings.demo')
+        Expected nothing
+        Got:
+            Started /usr/lib/python3.10/doctest.py ... docs/specs/overview.rst (using lino_amici.projects.amici1.settings.demo) --> PID 217238
+
+    then it's because your project directory contains a :xfile:`log` directory.
+
+
     """
     if settings_module:
         os.environ['DJANGO_SETTINGS_MODULE'] = settings_module
 
+    # print("20221102 startup() 1")
     import django
     django.setup()
+    # print("20221102 startup() 2")
 
 
 class AppConfig(AppConfig):
