@@ -7,8 +7,12 @@ import logging ; logger = logging.getLogger(__name__)
 
 # logger.info("20140227 dd.py a")
 
+import time
+from asgiref.sync import sync_to_async
+
 from django.conf import settings
 from django.db.models import *
+from django.utils import timezone
 
 from lino.core.tables import VirtualTable
 
@@ -74,6 +78,7 @@ from lino.core.fields import DurationField
 from lino.core.fields import HtmlBox, PriceField, RichTextField
 
 from lino.core.fields import DisplayField, displayfield, htmlbox, delayedhtmlbox
+# from lino.core.fields import DisplayField, displayfield, htmlbox
 from lino.core.fields import VirtualField, virtualfield
 from lino.core.fields import VirtualBooleanField
 from lino.core.fields import RequestField, requestfield
@@ -107,6 +112,7 @@ from lino.core.signals import pre_add_child
 from lino.core.signals import pre_remove_child
 from lino.core.signals import pre_ui_build
 from lino.core.signals import post_ui_build
+from lino.core.signals import post_delete, pre_delete
 
 from django.db.models.signals import pre_save, post_save
 from django.db.models.signals import pre_init, post_init
@@ -194,11 +200,32 @@ except ImportError as e:
     # logger.info("schedule not installed (%s)", e)
     schedule = None
 
+def job_schedule(fn):
+    class e_catcher:
+
+        def __call__(self, *args, **kwargs):
+            try:
+                fn(*args, **kwargs)
+            except Exception as e:
+                logging.getLogger('linod').exception(e)
+                from channels.layers import get_channel_layer
+                from asgiref.sync import async_to_sync
+                from lino.modlib.linod.utils import LINOD
+                async_to_sync(get_channel_layer().send)(LINOD, {'type': 'deferred.job', 'name': fn.__name__})
+                return schedule.CancelJob
+
+        def __repr__(self):
+            return fn.__name__
+
+        def __str__(self):
+            return fn.__name__
+
+    return e_catcher()
 
 def schedule_often(every=10):
     def decorator(func):
         if settings.SITE.use_linod:
-            schedule.every(every).seconds.do(func)
+            schedule.every(every).seconds.do(job_schedule(func))
         return func
     return decorator
 
@@ -206,7 +233,6 @@ def schedule_often(every=10):
 def schedule_daily(at="20:00"):
     def decorator(func):
         if settings.SITE.use_linod:
-            # schedule.every(10).seconds.do(func)
-            schedule.every().day.at(at).do(func)
+            schedule.every().day.at(at).do(job_schedule(func))
         return func
     return decorator
