@@ -1,5 +1,5 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2015-2021 Rumma & Ko Ltd
+# Copyright 2015-2022 Rumma & Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
 
 """
@@ -17,8 +17,9 @@ from django.test import Client
 from django.db import connection, reset_queries as reset_sql_queries
 import json
 from bs4 import BeautifulSoup
+import textwrap
 
-from rstgen import table
+from rstgen import table, ul
 import rstgen
 from rstgen import attrtable
 from rstgen.utils import unindent, rmu, sixprint
@@ -32,7 +33,7 @@ from lino.utils.sql import sql_summary
 from lino.core import actors, kernel
 from lino.core.menus import find_menu_item
 from lino.sphinxcontrib.actordoc import menuselection_text
-from pprint import pprint
+from pprint import pprint, pformat
 from lino.utils.diag import visible_for
 from lino.core.utils import full_model_name
 # from lino.core.utils import PseudoRequest
@@ -110,11 +111,8 @@ def check_json_result(response, expected_keys=None, msg=''):
     return result
 
 
-def demo_get(
-        username, url_base, json_fields=None,
-        expected_rows=None, **kwargs):
-    case = HttpQuery(username, url_base, json_fields,
-                     expected_rows, kwargs)
+def demo_get(username, url_base, json_fields=None, expected_rows=None, **kwargs):
+    case = HttpQuery(username, url_base, json_fields, expected_rows, kwargs)
     # Django test client does not like future pseudo-unicode strings
     # See #870
     url = str(settings.SITE.buildurl(case.url_base, **case.kwargs))
@@ -138,19 +136,23 @@ def demo_get(
             raise Exception(
                 "Status code %s other than 403 for anonymous on GET %s" % (
                     response.status_code, url))
-    ses= rt.login(username)
+    ses = rt.login(username)
     test_client.force_login(ses.user)
     response = test_client.get(url, REMOTE_USER=username)
     # try:
     if True:
+        what = "GET %s for user %s" % (url, ses.user)
         # user = settings.SITE.user_model.objects.get(
         #     username=case.username)
-        result = check_json_result(
-            response, case.json_fields,
-            "GET %s for user %s" % (url, ses.user))
+        result = check_json_result(response, case.json_fields, what)
 
         num = case.expected_rows
-        if num is not None:
+        if num is None:
+            return
+        if num == -1:
+            print("{} got\n{}".format(what, pformat(result)))
+            # print("got {} rows".format(result['count']))
+        else:
             if not isinstance(num, tuple):
                 num = [num]
             if result['count'] not in num:
@@ -249,26 +251,8 @@ def show_workflow(actions, all=False, language=None):
             return doit()
     return doit()
 
+def get_fields(model, fieldnames=None, columns=None):
 
-def fields_help(model, fieldnames=None, columns=False, all=None):
-    """
-    Print an overview description of the specified fields of the
-    specified model.
-
-    If model is an action or table, print the parameter fields of that
-    action or table.
-
-    If model is a table and you want the columns instead of the
-    parameter fields, then specify `columns=True`.
-
-    By default this shows only fields which have a help text.  If you
-    specify `all=True`, then also fields that have no help text will
-    be shown.
-    """
-    cells = []
-    cols = ["Internal name", "Verbose name", "Help text"]
-    if all is None:
-        all = fieldnames is not None
     if isinstance(model, BoundAction):
         get_field = model.action.parameters.get
         if fieldnames is None:
@@ -299,15 +283,40 @@ def fields_help(model, fieldnames=None, columns=False, all=None):
     if isinstance(fieldnames, str):
         fieldnames = fieldnames.split()
     for n in fieldnames:
-        fld = get_field(n)
+        yield get_field(n)
+
+
+def fields_help(model, fieldnames=None, columns=False, all=None):
+    """
+    Print an overview description of the specified fields of the
+    specified model.
+
+    If model is an action or table, print the parameter fields of that
+    action or table.
+
+    If model is a table and you want the columns instead of the
+    parameter fields, then specify `columns=True`.
+
+    By default this shows only fields that have a help text.  If you
+    specify `all=True`, then also fields that have no help text will
+    be shown.
+    """
+    if all is None:
+        all = fieldnames is not None
+
+    cells = []
+    cols = ["Internal name", "Verbose name", "Help text"]
+    for fld in get_fields(model, fieldnames, columns):
         if fld is not None and hasattr(fld, 'verbose_name'):
             ht = fld.help_text or ''
             if ht or all:
-                cells.append([n,
+                cells.append([fld.name,
                               fld.verbose_name,
                               unindent(ht)])
 
-    return table(cols, cells).strip()
+    # return table(cols, cells).strip()
+    items = ["{} ({}) : {}".format(row[1], row[0], row[2]) for row in cells]
+    return ul(items).strip()
 
 def show_fields(*args, **kwargs):
     print(fields_help(*args, **kwargs))
@@ -473,6 +482,50 @@ def show_choicelists():
 def show_permissions(*args):
     print(visible_for(*args))
 
+def show_translations(things, fmt, languages=None):
+    if languages is None:
+        languages = [lng.name for lng in settings.SITE.languages]
+    elif isinstance(languages, str):
+        languages = languages.split()
+    headers = ["Name"] + languages
+    rows = []
+    for thing in things:
+        name, x = fmt(thing)
+        cells = [name]
+        for lng in languages:
+            with translation.override(lng):
+                x, txt = fmt(thing)
+                cells.append(txt)
+        rows.append(cells)
+    print(table(headers, rows))
+
+def show_model_translations(*models, **kwargs):
+    def fmt(m):
+        return (full_model_name(m), "{0.verbose_name}\n{0.verbose_name_plural}".format(m._meta))
+    show_translations(models, fmt, **kwargs)
+
+def show_field_translations(model, fieldnames=None, wrap_width=40, **kwargs):
+    """
+    Print a table with the verbose name and the help text of the specified
+    fields in multiple languages.
+
+    If `fieldnames` is not given, print all fields.
+
+    If `languages` is not given, print all languages defined by the
+    :term:`language distribution` of this :term:`Lino site`.
+
+    """
+    def fmt(fld):
+        if fld.help_text:
+            txt = "{} : {}".format(fld.verbose_name, fld.help_text)
+        else:
+            txt = str(fld.verbose_name)
+        txt = '\n'.join(textwrap.wrap(txt, wrap_width))
+        return (fld.name, txt)
+    show_translations(get_fields(model, fieldnames), fmt, **kwargs)
+
+
+
 
 def show_quick_search_fields(*args):
     for m in args:
@@ -592,3 +645,6 @@ def walk_store_fields(only_detail_fields=False):
                 #     continue
                 # found.add(sf.field)
                 yield a, sf
+
+
+# settings.SITE.kernel.check_virgin()
