@@ -1,4 +1,4 @@
-"""A shortcut import for usage in a Django shell or a :manage:`run`
+"""A shortcut import for usage in a Django shell or a :cmd:`pm run`
 script.
 
 Typical usage::
