@@ -1,5 +1,5 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2009-2021 Rumma & Ko Ltd
+# Copyright 2009-2023 Rumma & Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
 
 """This defines the :class:`Action` class and the :func:`action`
@@ -78,7 +78,7 @@ def resolve_layout(cls, k, spec, layout_class, **options):
 def install_layout(cls, k, layout_class, **options):
     """
     - `cls` is the actor (a class object)
-    - `k` is one of 'detail_layout', 'insert_layout', 'params_layout', 'card_layout', 'item_layout'
+    - `k` is one of 'detail_layout', 'insert_layout', 'params_layout', 'card_layout', 'list_layout'
     - `layout_class`
 
     """
@@ -136,8 +136,7 @@ def setup_params_choosers(self):
 
 def make_params_layout_handle(self):
     # `self` is either an Action instance or an Actor class object
-    return self.params_layout.get_layout_handle(
-        settings.SITE.kernel.default_ui)
+    return self.params_layout.get_layout_handle()
 
 
 class Action(Parametrizable, Permittable):
@@ -298,7 +297,7 @@ class Action(Parametrizable, Permittable):
     Also can be defined as a class method, that takes the actor as the only
     argument and should return a JavaScript executable.
     An example use case is defined in
-    :class:`lino.modlib.help.models.OpenHelpWindow` where the return string
+    :class:`lino.modlib.help.OpenHelpWindow` where the return string
     follows the format::
 
         return "let _ = window.open('URL')"
@@ -373,13 +372,19 @@ class Action(Parametrizable, Permittable):
     of a plain html view.
     """
 
-    show_in_bbar = True
+    never_collapse = False
+    """
+    When `True` the action will always be visible, regardless of whether
+    the toolbar collapsed or not.
+    """
+
+    show_in_side_toolbar = False
+
+    show_in_toolbar = True
     """
 
     Whether this action should be displayed in the toolbar.
 
-    TODO: rename this to `show_in_toolbar`.
-
     In ExtJS this will also cause it to be in the context menu of a grid.
 
     For example the :class:`CheckinVisitor
@@ -462,7 +467,7 @@ class Action(Parametrizable, Permittable):
             self.label = label
 
         # if self.parameters is not None and self.select_rows:
-        #     self.show_in_bbar = False
+        #     self.show_in_toolbar = False
         #     # see ticket #105
 
         for k, v in kwargs.items():
@@ -797,7 +802,7 @@ class ShowTable(TableAction):
     def get_window_layout(self, actor):
         # ~ return self.actor.list_layout
         return None
-        # return actor.card_layout or actor.item_layout  # 20210910
+        # return actor.card_layout or actor.list_layout  # 20210910
 
     def get_window_size(self, actor):
         return actor.window_size
@@ -818,7 +823,7 @@ class ShowDetail(Action):
 
     def __init__(self, dl, label=None, **kwargs):
         self.owner = dl
-        super(ShowDetail, self).__init__(label, **kwargs)
+        super().__init__(label, **kwargs)
 
     def attach_to_actor(self, actor, name):
         self.help_text = _("Open a detail window on records of " + actor.app_label + ".")
@@ -853,13 +858,13 @@ class ShowEmptyTable(ShowDetail):
 
     # def attach_to_actor(self, actor, name):
     #     self.label = actor.label
-    #     return super(ShowEmptyTable, self).attach_to_actor(actor, name)
+    #     return super().attach_to_actor(actor, name)
 
     def get_label(self):
         return self.label or self.defining_actor.label
 
     def as_bootstrap_html(self, ar):
-        return super(ShowEmptyTable, self).as_bootstrap_html(ar, '-99998')
+        return super().as_bootstrap_html(ar, '-99998')
 
 
 class ShowExtraDetail(ShowEmptyTable):
@@ -888,6 +893,7 @@ class ShowInsert(TableAction):
     help_text = _("Insert a new record")
 
     show_in_workflow = False
+    show_in_side_toolbar = True
     opens_a_window = True
     window_type = 'i'
     hide_navigator = True  # 20210509
@@ -905,7 +911,7 @@ class ShowInsert(TableAction):
         if owner.model is not None:
             self.help_text = format_lazy(
                 _("Open a dialog window to insert a new {}."), owner.model._meta.verbose_name)
-        return super(ShowInsert, self).attach_to_actor(owner, name)
+        return super().attach_to_actor(owner, name)
 
     def get_action_title(self, ar):
         # return _("Insert into %s") % force_str(ar.get_title())
@@ -927,7 +933,7 @@ class ShowInsert(TableAction):
         # want to hide it for readonly users.
         if user_type and user_type.readonly:
             return False
-        return super(ShowInsert, self).get_view_permission(user_type)
+        return super().get_view_permission(user_type)
 
     def create_instance(self, ar):
         """
@@ -937,7 +943,7 @@ class ShowInsert(TableAction):
         return ar.create_instance()
 
     def get_status(self, ar, **kw):
-        kw = super(ShowInsert, self).get_status(ar, **kw)
+        kw = super().get_status(ar, **kw)
         if 'record_id' in kw:
             return kw
         if 'data_record' in kw:
@@ -1151,7 +1157,7 @@ class SubmitInsert(CreateRow):
 
 class ExplicitRefresh(Action):  # experimental 20170929
     label = _("Go")
-    show_in_bbar = False
+    show_in_toolbar = False
     # js_handler = 'function(panel) {panel.refresh()}'
     js_handler = 'function(btn, evt) {console.log("20170928", this); this.refresh()}'
     # def run_from_ui(self, ar, **kw):
@@ -1165,12 +1171,12 @@ class ShowSlaveTable(Action):
     """
     TABLE2ACTION_ATTRS = ('help_text', 'icon_name', 'react_icon_name', 'label',
                           'sort_index', 'required_roles', 'button_text')
-    show_in_bbar = True
+    show_in_toolbar = True
 
     def __init__(self, slave_table, **kw):
         self.slave_table = slave_table
         self.explicit_attribs = set(kw.keys())
-        super(ShowSlaveTable, self).__init__(**kw)
+        super().__init__(**kw)
 
     @classmethod
     def get_actor_label(self):
@@ -1189,7 +1195,7 @@ class ShowSlaveTable(Action):
             if k not in self.explicit_attribs:
                 attr = getattr(self.slave_table, k, None)
                 setattr(self, k, attr)
-        return super(ShowSlaveTable, self).attach_to_actor(actor, name)
+        return super().attach_to_actor(actor, name)
 
     def run_from_ui(self, ar, **kw):
         obj = ar.selected_rows[0]
@@ -1210,7 +1216,7 @@ class WrappedAction(Action):
     """
 
     instance = None  # for Renderer.menu_item_button()
-    show_in_bbar = True
+    show_in_toolbar = True
     callable_from = 'd'
 
     WRAPPED_ATTRS = ('help_text', 'icon_name', 'react_icon_name', 'label',
@@ -1225,7 +1231,7 @@ class WrappedAction(Action):
         for k in self.WRAPPED_ATTRS:
             if k not in kwargs:
                 kwargs[k] = getattr(bound_action.action, k)
-        super(WrappedAction, self).__init__(**kwargs)
+        super().__init__(**kwargs)
 
     def get_required_roles(self, actor):
         # print(self.bound_action, actor.required_roles | self.bound_action.required)
@@ -1338,7 +1344,6 @@ class DeleteSelected(MultipleRowAction):
             # refresh_all must be True e.g. for when user deletes an item of a
             # bank statement
             ar2.success(record_deleted=True, refresh_all=True)
-
             # hack required for extjs:
             if ar2.actor.detail_action:
                 ar2.set_response(
