@@ -1,5 +1,5 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2009-2022 Rumma & Ko Ltd
+# Copyright 2009-2023 Rumma & Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
 
 """This defines :class:`Actor` and related classes.
@@ -8,12 +8,12 @@ See :doc:`/dev/actors`.
 
 
 """
-from future.utils import with_metaclass
 
 import logging; logger = logging.getLogger(__name__)
 
 import copy
 import traceback
+import html
 from types import GeneratorType
 from inspect import getmro
 
@@ -80,7 +80,7 @@ def discover():
 def register_actor(a):
     """
 
-    Internally called during startup process to insert a
+    Called during startup process to insert an
     actor class in the global actors_list and actors_dict.
 
     Special attention is given to the case when a plugin extends another plugin
@@ -93,7 +93,9 @@ def register_actor(a):
     """
     #~ logger.debug("register_actor %s",a)
     if not a.abstract:
-        if not settings.SITE.is_installed(a.app_label):
+        # if not settings.SITE.is_installed(a.app_label):
+        p = settings.SITE.plugins.get(a.app_label, None)
+        if p is None or not p.is_active():
             # avoid registering choicelists of non-installed plugins
             # logger.info("20190107 skip register_actor for %s", a)
             return
@@ -113,9 +115,8 @@ def field_getter(name):
         return getattr(obj, name)
     return func
 
-from lino.core.classproperty import classproperty
 
-class ActorMetaClass(type('classproperty', (classproperty,), {})):
+class ActorMetaClass(type):
 
     def __new__(meta, classname, bases, classDict):
         #~ if not classDict.has_key('app_label'):
@@ -177,54 +178,14 @@ class ActorMetaClass(type('classproperty', (classproperty,), {})):
         cls._setup_done = False
         cls._setup_doing = False
         cls.virtual_fields = {}
-        # cls.extra_fields = {}
         cls._constants = {}
         cls._actions_dict = {}  # AttrDict()
         cls._actions_list = []  # 20121129
-        # cls._pending_field_updates = []
 
         cls.collect_virtual_fields()
 
-
-        # def register_class_attribute(k, v):
-        #     if isinstance(v, fields.Constant):
-        #         cls.add_constant(k, v)
-        #     elif isinstance(v, fields.VirtualField):  # 20120903b
-        #         cls.add_virtual_field(k, v)
-        #     elif isinstance(v, models.Field):  # 20130910
-        #         # ~ print "20130910 add virtual field " ,k, cls
-        #         vf = fields.VirtualField(v, field_getter(k))
-        #         cls.add_virtual_field(k, vf)
-        #
-        # # inherit virtual fields defined on parent actors
-        # for b in bases:
-        #     for cl in b.__mro__:
-        #         for k, v in cl.__dict__.items():
-        #             register_class_attribute(k, v)
-        # for k, v in classDict.items():
-        #     register_class_attribute(k, v)
-
-        #~ if classname == 'Tasks':
-            #~ logger.info("20130817 no longer added actor vfs")
-
-        #~ cls.params = []
-        #~ for k,v in classDict.items():
-            #~ if isinstance(v,models.Field):
-                #~ v.set_attributes_from_name(k)
-                #~ v.table = cls
-                #~ cls.params.append(v)
-        #~ cls.install_params_on_actor()
         if actor_classes is not None:
             actor_classes.append(cls)
-        # if classname not in (
-        #         'Table', 'AbstractTable', 'VirtualTable',
-        #         'Action', 'Actor', 'Frame',
-        #         'ChoiceList', 'Workflow',
-        #         'EmptyTable', 'Dialog'):
-        #     elif not cls.__name__.startswith('unused_'):
-        #         # ~ cls.class_init() # 20120115
-        #         actor_classes.append(cls)
-        #     #~ logger.debug("ActorMetaClass.__new__(%s)", cls)
         return cls
 
     def __str__(cls):
@@ -248,7 +209,8 @@ class ActorMetaClass(type('classproperty', (classproperty,), {})):
         return cls.get_actor_editable()
 
 
-class Actor(with_metaclass(ActorMetaClass, type('NewBase', (actions.Parametrizable, Permittable), {}))):
+# class Actor(metaclass=ActorMetaClass, type('NewBase', (actions.Parametrizable, Permittable), {}))):
+class Actor(actions.Parametrizable, Permittable, metaclass=ActorMetaClass):
     """
     The base class for all actors.  Subclassed by :class:`AbstractTable
     <lino.core.tables.AbstractTable>`, :class:`Table
@@ -317,6 +279,7 @@ class Actor(with_metaclass(ActorMetaClass, type('NewBase', (actions.Parametrizab
     # """
 
     only_fields = None
+    display_mode = None
 
     app_label = None
     """
@@ -456,7 +419,7 @@ class Actor(with_metaclass(ActorMetaClass, type('NewBase', (actions.Parametrizab
     detail_layout = None
     insert_layout = None
     card_layout = None
-    item_layout = None
+    list_layout = None
 
     detail_template = None    # deprecated: use insert_layout instead
     insert_template = None    # deprecated: use detail_layout instead
@@ -549,8 +512,8 @@ class Actor(with_metaclass(ActorMetaClass, type('NewBase', (actions.Parametrizab
 
         You need to override this on slave actors whose
         :attr:`master` is not a database model,
-        e.g. the :class:`ProblemsByChecker
-        <lino.modlib.checkdata.ProblemsByChecker>` table.
+        e.g. the :class:`MessagesByChecker
+        <lino.modlib.checkdata.MessagesByChecker>` table.
 
         `ar` is the action request on this actor. `model` is the
         :attr:`master`, except if :attr:`master` is `ContentType` (in
@@ -694,7 +657,11 @@ class Actor(with_metaclass(ActorMetaClass, type('NewBase', (actions.Parametrizab
             # subsequent calls, causing tracebacks like "AttributeError:
             # 'TableHandle' object has no attribute 'store'"
             setattr(self, hname, h)
-            if True:  # 20210610
+
+            # In released versions the following should be True. We might want
+            # to catch exceptions only for debugging purposes.
+
+            if True:
                 settings.SITE.kernel.setup_handle(h, ar)
             else:
                 try:
@@ -730,10 +697,6 @@ class Actor(with_metaclass(ActorMetaClass, type('NewBase', (actions.Parametrizab
             raise ChangedAPI(
                 "{0} must convert `required` to `required_roles`".format(cls))
 
-        if hasattr(cls, 'display_mode'):
-            raise ChangedAPI(
-                "{0} must convert `display_mode` to `display_mode_main` or `display_mode_slave`".format(cls))
-
         master = getattr(cls, 'master', None)
         if isinstance(master, str):
         # if isinstance(master, string_types):
@@ -770,7 +733,7 @@ class Actor(with_metaclass(ActorMetaClass, type('NewBase', (actions.Parametrizab
         actions.install_layout(cls, 'insert_layout', layouts.InsertLayout,
             window_size=(cls.insert_layout_width, 'auto'))
         actions.install_layout(cls, 'card_layout', layouts.DetailLayout)
-        actions.install_layout(cls, 'item_layout', layouts.DetailLayout)
+        actions.install_layout(cls, 'list_layout', layouts.DetailLayout)
 
         cls.extra_layouts = dict()
         for name, main in cls.get_extra_layouts():
@@ -1272,20 +1235,6 @@ class Actor(with_metaclass(ActorMetaClass, type('NewBase', (actions.Parametrizab
             # return str(self)
         return E.div(*forcetext([ar.obj2html(obj)]))
 
-    # @classmethod
-    # def disabled_actions(self, ar, obj):  # no longer used since 20170909
-    #     """
-    #     Returns a dictionary containg the names of the actions
-    #     that are disabled  for the given object instance `obj`
-    #     and the user who issued the given ActionRequest `ar`.
-
-    #     Application developers should not need to override this method.
-
-    #     Default implementation returns an empty dictionary.
-    #     Overridden by :class:`dd.Table`
-
-    #     """
-    #     return {}
 
     @classmethod
     def override_column_headers(self, ar, **kwargs):
@@ -1519,7 +1468,7 @@ class Actor(with_metaclass(ActorMetaClass, type('NewBase', (actions.Parametrizab
         """
 
         for ba in self.get_button_actions(parent):
-            if ba.action.show_in_bbar and ba.get_view_permission(user_type):
+            if ba.action.show_in_toolbar and ba.get_view_permission(user_type):
                 if ba.action.readonly or not self.hide_editing(user_type):
                     yield ba
 
@@ -1561,20 +1510,19 @@ class Actor(with_metaclass(ActorMetaClass, type('NewBase', (actions.Parametrizab
         return classmethod(wrapped)
 
     @classmethod
-    def get_detail_layout(cls, *args):
+    def get_detail_layout(cls):
         assert cls.detail_action is not None
         wl = cls.detail_action.get_window_layout()
-        return wl.get_layout_handle(*args)
+        return wl.get_layout_handle()
 
     @classmethod
     def get_list_layout(cls, *args):
         assert cls.default_action is not None
         ah = cls.get_handle()
         return ah.get_list_layout()
-        # return ll.get_layout_handle(*args)
 
     @classmethod
-    def get_detail_elems(cls, *args):
+    def get_detail_elems(cls):
         """
         Return a list of the widgets (layout elements) that make up
         the detail layout.
@@ -1585,7 +1533,7 @@ class Actor(with_metaclass(ActorMetaClass, type('NewBase', (actions.Parametrizab
         <lino.core.kernel.Kernel.default_ui>`.
 
         """
-        lh = cls.get_detail_layout(*args)
+        lh = cls.get_detail_layout()
         return lh.main.elements
 
     @classmethod
@@ -1708,6 +1656,8 @@ class Actor(with_metaclass(ActorMetaClass, type('NewBase', (actions.Parametrizab
 
         Deprecated. Rather call cls.request(parent=ar)
         """
+        raise Exception("Deprecated (Actor.request_from). Rather call cls.request(parent=ar)")
+        # logger.warning("Deprecated (Actor.request_from). Rather call cls.request(parent=ar)")
         sar = cls.request(*args, **kwargs)
         sar.setup_from(ar)
         return sar
@@ -1731,11 +1681,12 @@ class Actor(with_metaclass(ActorMetaClass, type('NewBase', (actions.Parametrizab
     @classmethod
     def slave_as_html(cls, master, ar):
         """
-        Creates and returns the method to be used when :attr:`display_mode_main`
-        is `html`.
+        Creates and returns the method to be used when :attr:`display_mode`
+        is DISPLAY_MODE_HTML.
         """
         ar = cls.request(
-            master, request=ar.request, param_values=ar.param_values if getattr(cls, "use_detail_params_value", False) else {},
+            master, request=ar.request,
+            param_values=ar.param_values if getattr(cls, "use_detail_params_value", False) else {},
             is_on_main_actor=False)
         ar.renderer = settings.SITE.kernel.default_renderer
         el = ar.table2xhtml()
@@ -1746,11 +1697,40 @@ class Actor(with_metaclass(ActorMetaClass, type('NewBase', (actions.Parametrizab
 
     summary_sep = E.br
 
+    @classmethod
+    def get_table_as_list(cls, obj, ar):
+        sar = cls.request(parent=ar, master_instance=obj, is_on_main_actor=False)
+        html_text = ""
+        for i, obj in enumerate(sar.data_iterator):
+            if i == cls.preview_limit:
+                break
+            par = sar.row_as_paragraph(obj)  # 20230207
+            par = sar.add_detail_link(obj, par)
+            par = "<p>{}</p>".format(par)
+            # url = sar.obj2url(obj)
+            # if url is not None:
+            #     url = html.escape(url)
+            #     # par += ' <a href="{}">(Detail)</a>'.format(url)
+            #     par = '<a href="{}">{}</a>'.format(url, par)
+            # else:  # a funny way to debug:
+            #     par = '<a href="{}">{}</a>'.format(str(sar.renderer), par)
+
+            html_text += par
+
+        if cls.insert_action is not None:
+            if not cls.editable:
+                return html_text
+            ir = cls.insert_action.request_from(sar)
+            if ir.get_permission():
+                html_text = tostring(ir.ar2button()) + html_text
+
+        return "<div>" + html_text + "</div>"
+
     @classmethod
     def get_table_summary(cls, obj, ar):
         """Return the HTML `<div>` to be displayed by
         :class:`lino.core.elems.TableSummaryPanel`.  That is (1) in a
-        detail form when :attr:`display_mode_main` is `summary` or (2)
+        detail form when :attr:`display_mode` is DISPLAY_MODE_SUMMARY or (2)
         in a grid.
 
         Lino internally creates a virtualfield ``slave_summary`` on each table
@@ -1760,7 +1740,7 @@ class Actor(with_metaclass(ActorMetaClass, type('NewBase', (actions.Parametrizab
         # ar = ar.spawn(self, master_instance=obj, is_on_main_actor=False)
         # sar = ar.spawn_request(actor=cls, master_instance=obj,
         #     is_on_main_actor=False)
-        sar = cls.request_from(ar, master_instance=obj, is_on_main_actor=False)
+        sar = cls.request(parent=ar, master_instance=obj, is_on_main_actor=False)
         p = E.div(*qs2summary(sar, sar.data_iterator, separator=cls.summary_sep,
                 max_items=cls.preview_limit))
 
