@@ -1,4 +1,4 @@
-# Copyright 2011-2020 Rumma & Ko Ltd
+# Copyright 2011-2023 Rumma & Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
 
 """Utilities for authentication. Adapted from `django.contrib.auth`.
@@ -9,13 +9,14 @@ from django.conf import settings
 from django.utils.crypto import constant_time_compare
 from django.utils.module_loading import import_string
 
-from lino.utils import SimpleSingleton
 
-class AnonymousUser(SimpleSingleton):
-    """A singleton class whose instance will be assigned to the
+class AnonymousUser:
+    """An instance of this will be assigned to the
     :attr:`user` attribute of anonymous incoming requests, similar to
     Django's approach.
 
+    The memo parser uses another instance of this.
+
     See also :attr:`lino.core.site.Site.anonymous_user_type`.
 
     """
@@ -29,7 +30,6 @@ class AnonymousUser(SimpleSingleton):
     is_active = False
 
     email = None
-    username = 'anonymous'
     modified = None
     partner = None
     language = None
@@ -38,13 +38,11 @@ class AnonymousUser(SimpleSingleton):
     id = None
     time_zone =  None
     notify_myself = False
-    user_type = None
     is_anonymous = True
 
-    def __init__(self):
-        settings.SITE.startup()
-        from lino.modlib.users.choicelists import UserTypes
-        self.user_type = UserTypes.get_by_name(self.username, None)
+    def __init__(self, username, user_type):
+        self.username = username
+        self.user_type = user_type
 
     def __str__(self):
         return self.username
