@@ -124,7 +124,7 @@ class BoundAction(object):
         #~ if self.actor is None: return False
         return self.actor.get_row_permission(obj, ar, state, self)
 
-    def get_bound_action_permission(self, ar, obj, state):
+    def get_bound_action_permission(self, ar, obj=None, state=None):
         """Checks whether the bound action gives permission to run.
 
         If this is a list action, `obj` is None.  If this is a row
