@@ -1,5 +1,5 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2008-2020 Rumma & Ko Ltd
+# Copyright 2008-2023 Rumma & Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
 
 """
@@ -8,7 +8,6 @@ Defines the classes :class:`Choice` and :class:`ChoiceList`.  See
 """
 
 from future.utils import with_metaclass
-from past.builtins import cmp
 
 import warnings
 
@@ -21,8 +20,7 @@ from django.db.models import NOT_PROVIDED
 from django.db.migrations.serializer import BaseSerializer
 from django.db.migrations.writer import MigrationWriter
 
-
-from lino.utils import is_string
+from lino.core.utils import resolve_field
 from lino.core import actions
 from lino.core import actors
 from lino.core import tables
@@ -310,6 +308,53 @@ class CallableChoice(object):
         return self.ChoiceList.get_by_name(self.name)
         # return self.callfn(*args, **kwargs)
 
+class MissingRow():
+
+    def __init__(self, pointing_field, pointing_choice):
+        self.pointing_field = pointing_field
+        self.pointing_choice = pointing_choice
+
+    def __str__(self):
+        return _("No {} pointing to {}").format(
+            self.pointing_field.model._meta.verbose_name, self.pointing_choice)
+
+    def __repr__(self):
+        return "{}({})".format(self.__class__.__name__, repr(self.pointing_choice))
+
+
+class PointingChoice(Choice):
+    """
+    Usage examples: :class:`lino_xl.lib.ledger.CommonAccounts`,
+    :class:`lino_xl.lib.properties.PropertyAreas`.
+    """
+    pointing_field_name = None
+
+    _pointing_field = None
+    _instance = None
+
+    @property
+    def pointing_field(self):
+        if self._pointing_field is None:
+            self._pointing_field = resolve_field(self.pointing_field_name)
+        return self._pointing_field
+
+    def set_object(self, obj):
+        self._instance = obj
+
+    def get_object(self):
+        # return rt.models.ledger.Account.objects.get(ref=self.value)
+        if self._instance is None:
+            pf = self.pointing_field
+            try:
+                self._instance = pf.model.objects.get(**{pf.name: self})
+            except pf.model.DoesNotExist:
+                self._instance = MissingRow(pf,self)
+        return self._instance
+
+    def has_row(self):
+        return not isinstance(self.get_object(), MissingRow)
+
+
 class ChoiceList(with_metaclass(ChoiceListMeta, tables.AbstractTable)):
 
     """
@@ -672,7 +717,7 @@ class ChoiceList(with_metaclass(ChoiceListMeta, tables.AbstractTable)):
         #~ We must make it dynamic since e.g. UserTypes can change after
         #~ the fields have been created.
 
-        #~ https://docs.djangoproject.com/en/3.1/ref/models/fields/
+        #~ https://docs.djangoproject.com/en/4.1/ref/models/fields/
         #~ note that choices can be any iterable object -- not necessarily
         #~ a list or tuple. This lets you construct choices dynamically.
         #~ But if you find yourself hacking choices to be dynamic, you're
@@ -850,7 +895,7 @@ class ChoiceListField(models.CharField):
         self.choicelist = choicelist
         self.force_selection = force_selection
         if default is not None:
-            if is_string(default):
+            if isinstance(default, str):
                 default = choicelist.as_callable(default)
             kw.update(default=default)
         defaults = dict(
@@ -880,7 +925,7 @@ class ChoiceListField(models.CharField):
     def deconstruct(self):
         """
         Needed for Django 1.7+, see
-        https://docs.djangoproject.com/en/3.1/howto/custom-model-fields/#custom-field-deconstruct-method
+        https://docs.djangoproject.com/en/4.1/howto/custom-model-fields/#custom-field-deconstruct-method
         """
 
         name, path, args, kwargs = super(ChoiceListField, self).deconstruct()
@@ -908,7 +953,7 @@ class ChoiceListField(models.CharField):
 
     def to_python(self, value):
         """See Django's docs about `to_python()
-        <https://docs.djangoproject.com/en/1.11/ref/models/fields/#django.db.models.Field.to_python>`__.
+        <https://docs.djangoproject.com/en/4.1/ref/models/fields/#django.db.models.Field.to_python>`__.
 
         """
         #~ if self.attname == 'query_register':
@@ -935,11 +980,11 @@ class ChoiceListField(models.CharField):
     def get_prep_value(self, value):
         """
         Excerpt from `Django docs
-        <https://docs.djangoproject.com/en/3.0/howto/custom-model-fields/#converting-python-objects-to-query-values>`__:
+        <https://docs.djangoproject.com/en/4.1/howto/custom-model-fields/#converting-python-objects-to-query-values>`__:
         "If you override `to_python()
-        <https://docs.djangoproject.com/en/3.0/ref/models/fields/#django.db.models.Field.to_python>`__
+        <https://docs.djangoproject.com/en/4.1/ref/models/fields/#django.db.models.Field.to_python>`__
         you also have to override `get_prep_value()
-        <https://docs.djangoproject.com/en/3.0/ref/models/fields/#django.db.models.Field.get_prep_value>`__
+        <https://docs.djangoproject.com/en/4.1/ref/models/fields/#django.db.models.Field.get_prep_value>`__
         to convert Python objects back to query values."
         """
         #~ if self.attname == 'query_register':
