@@ -55,7 +55,7 @@ def base_attrs(cl):
 def add_gridfilters(qs, gridfilters):
     """Converts a `filter` request in the format used by
     :extux:`Ext.ux.grid.GridFilters` into a `Django field lookup
-    <https://docs.djangoproject.com/en/1.11/ref/models/querysets/#field-lookups>`_
+    <https://docs.djangoproject.com/en/4.1/ref/models/querysets/#field-lookups>`_
     on a :class:`django.db.models.query.QuerySet`.
 
     :param qs: the queryset to be modified.
@@ -204,15 +204,15 @@ class Table(AbstractTable):
 
     @classmethod
     def init_layouts(cls):
-        # if cls.item_layout is None:
+        # if cls.list_layout is None:
         if cls.model is not None and issubclass(cls.model, Model):
             if not cls.abstract:
                 for tbl in cls.__mro__:
                     # print("20210629", tbl)
-                    if 'item_layout' in tbl.__dict__:
+                    if 'list_layout' in tbl.__dict__:
                         break
-                    if tbl == actors.Actor:
-                        cls.item_layout = 'list_item'
+                    if issubclass(tbl, actors.Actor):
+                        cls.list_layout = 'list_item'
                         break
         super(Table, cls).init_layouts()
 
@@ -299,10 +299,12 @@ class Table(AbstractTable):
 
     @classmethod
     def get_table_story(cls, obj, ar):
-        sar = cls.request_from(ar, master_instance=obj, is_on_main_actor=False)
+        sar = cls.request(parent=ar, master_instance=obj, is_on_main_actor=False)
         html = ""
-        for obj in sar.data_iterator:
-            html += obj.as_story_item(ar)
+        for i, obj in enumerate(sar.data_iterator):
+            if i == cls.preview_limit:
+                break
+            html += obj.as_story_item(sar)
         if cls.insert_action is not None:
             if not cls.editable:
                 return html
@@ -340,9 +342,9 @@ class Table(AbstractTable):
     #         # u = ar.get_user()
     #         for ba in self.get_actions(ar.bound_action.action):
     #             if ba.action.action_name:
-    #                 if ba.action.show_in_bbar and not self.get_row_permission(obj, ar, state, ba):
-    #                 # if ba.action.show_in_bbar and not obj.get_row_permission(u,state,ba.action):
-    #                 # if a.show_in_bbar and not a.get_action_permission(ar.get_user(),obj,state):
+    #                 if ba.action.show_in_toolbar and not self.get_row_permission(obj, ar, state, ba):
+    #                 # if ba.action.show_in_toolbar and not obj.get_row_permission(u,state,ba.action):
+    #                 # if a.show_in_toolbar and not a.get_action_permission(ar.get_user(),obj,state):
     #                     d[ba.action.action_name] = True
     #             # if ba.action.action_name == 'do_clear_cache':
     #                 # logger.info("20121127 %s %s", obj, d)
@@ -548,7 +550,7 @@ class Table(AbstractTable):
                 return s
             for ba in cls.get_button_actions(parent):
                 a = ba.action
-                if a.action_name and a.show_in_bbar:
+                if a.action_name and a.show_in_toolbar:
                     if not cls.get_row_permission(obj, ar, state, ba):
                         s.add(a.action_name)
         return s
