@@ -1,5 +1,5 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2008-2021 Rumma & Ko Ltd
+# Copyright 2008-2022 Rumma & Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
 
 """
@@ -15,6 +15,7 @@ from django import http
 from django.conf import settings
 from django.db import models
 from django.utils.translation import gettext_lazy as _
+from django.utils.text import format_lazy
 from django.core.exceptions import ValidationError
 from django.core.exceptions import FieldDoesNotExist
 from django.db.models.fields import NOT_PROVIDED
@@ -22,7 +23,7 @@ from django.utils.functional import cached_property
 
 from etgen.html import E, forcetext
 
-from lino.core.utils import resolve_field, full_model_name, resolve_model
+from lino.core.utils import resolve_field, full_model_name, resolve_model, ParameterPanel
 from lino.core.exceptions import ChangedAPI
 from lino.core.diff import ChangeWatcher
 from lino.core import constants
@@ -156,7 +157,7 @@ class MonthField(models.DateField):
 class PriceField(models.DecimalField):
     """
     A thin wrapper around Django's `DecimalField
-    <https://docs.djangoproject.com/en/3.1/ref/models/fields/#decimalfield>`_
+    <https://docs.djangoproject.com/en/4.1/ref/models/fields/#decimalfield>`_
     which adds default values for `decimal_places`, `max_length` and
     `max_digits`.
     """
@@ -168,7 +169,54 @@ class PriceField(models.DecimalField):
             decimal_places=2,
         )
         defaults.update(kwargs)
-        super(PriceField, self).__init__(verbose_name, **defaults)
+        super().__init__(verbose_name, **defaults)
+
+
+# from lino.core.utils import resolve_field
+#
+# class FieldRange(ParameterPanel):
+#
+#     def __init__(self, fldspec, **kwargs):
+#         fld = resolve_field(fldspec)
+#         self.start_field = dbfield2params_field(fld)
+#         self.end_field = dbfield2params_field(fld)
+
+class PriceRange(ParameterPanel):
+    def __init__(self, field_name, verbose_name=_("Price"), **kwargs):
+        self.field_name = field_name
+        self.verbose_name = verbose_name
+        kwargs["start_"+field_name] = PriceField(
+            verbose_name=format_lazy(_("{} from"), verbose_name),
+            blank=True, null=True)
+        kwargs["end_"+field_name] = PriceField(
+            verbose_name=_("to"), blank=True, null=True)
+        super().__init__(**kwargs)
+
+    def check_values(self, pv):
+        start_value = getattr(pv, "start_" + self.field_name)
+        if start_value is None:
+            return
+        end_value = getattr(pv, "end_" + self.field_name)
+        if end_value is None:
+            return
+        if start_value > end_value:
+            raise Warning(_("Invalid price range"))
+
+    def get_title_tags(self, ar):
+        pv = ar.param_values
+        start_value = getattr(pv, "start_" + self.field_name)
+        end_value = getattr(pv, "end_" + self.field_name)
+        if start_value:
+            if end_value:
+                yield _("{} {}...{}").format(
+                    self.verbose_name, start_value, end_value)
+            else:
+                yield _("{} from {}").format(self.verbose_name, start_value)
+        elif end_value:
+            yield _("{} until {}").format(self.verbose_name, end_value)
+
+
+
 
 
 #~ class MyDateField(models.DateField):
@@ -238,7 +286,7 @@ class FakeField(object):
     remote_field = None
     blank = True  # 20200425
     delayed_value = False
-    max_length = 0
+    max_length = None
 
     wildcard_data_elem = False
     """Whether to consider this field as wildcard data element.
@@ -412,19 +460,18 @@ class HtmlBox(DisplayField):
     Like :class:`DisplayField`, but to be rendered as a panel rather
     than as a form field.
     """
-    pass
+
+    # Needed when the object passes through the process of params_values creation, as if this object were a choicelist
+    empty_strings_allowed = True
 
 class DelayedHtmlBox(HtmlBox):
     """
 
-    A simple extention of :class:`HtmlBox` that uses the :class:`DelayedValue
+    A simple extension of :class:`HtmlBox` that uses the :class:`DelayedValue
     <lino.utils.DelayedValue>` for its related store field value.
 
     """
 
-    # Needed when the object passes through the process of params_values creation, as if this object were a choicelist
-    empty_strings_allowed = True
-
     def __init__(self, *args, **kwargs):
         kwargs.update(delayed_value=True)
         super().__init__(*args, **kwargs)
@@ -482,6 +529,11 @@ class VirtualField(FakeField):
     (because they inherit from that class).
     """
 
+    simple_elem = False
+    """
+    Used in :meth:`get_field_options` to set :term:`front end` rendering options.
+    """
+
     def __init__(self, return_type, get, **kwargs):
         """
         Normal VirtualFields are read-only and not editable.
@@ -495,6 +547,8 @@ class VirtualField(FakeField):
         self.return_type = return_type  # a Django Field instance
         self.get = get
 
+        self.simple_elem = kwargs.get('simple_elem', self.simple_elem)
+
         # if isinstance(return_type, FakeField):
         #     sortable_by = return_type.sortable_by
         #     self.sortable_by = sortable_by
@@ -505,7 +559,7 @@ class VirtualField(FakeField):
         #     setattr(self, k, getattr(return_type, k, None))
 
         settings.SITE.register_virtual_field(self)
-        super(VirtualField, self).__init__(**kwargs)
+        super().__init__(**kwargs)
 
     def lino_resolve_type(self):
         """
@@ -809,7 +863,7 @@ class CharField(models.CharField):
 
     Example usage:
 
-      belgian_phone_no = dd.CharField(max_length=15,strip_chars_re='')
+      belgian_phone_no = dd.CharField(max_length=15, strip_chars_re='')
     """
 
     def __init__(self, *args, **kw):
@@ -836,7 +890,7 @@ class QuantityField(models.CharField):
 
     def __init__(self, *args, **kw):
         kw.setdefault('max_length', 6)
-        super(QuantityField, self).__init__(*args, **kw)
+        super().__init__(*args, **kw)
         if self.blank and not self.null:
             raise ChangedAPI(
                 "When `blank` is True, `null` must be True as well.")
@@ -847,7 +901,7 @@ class QuantityField(models.CharField):
     def to_python(self, value):
         """
         Excerpt from `Django docs
-        <https://docs.djangoproject.com/en/3.1/howto/custom-model-fields/#converting-values-to-python-objects>`__:
+        <https://docs.djangoproject.com/en/4.1/howto/custom-model-fields/#converting-values-to-python-objects>`__:
 
             As a general rule, :meth:`to_python` should deal gracefully with
             any of the following arguments:
@@ -882,6 +936,12 @@ class QuantityField(models.CharField):
         #     return ''
         return str(value) if value else ''
 
+    def clean(self, raw_value, obj):
+        if len(str(raw_value)) > self.max_length:
+            # print("20230129 Can't store {}={} in {}".format(self.name, raw_value, obj))
+            return -1
+        return super().clean(raw_value, obj)
+
 
 class DurationField(QuantityField):
     """
@@ -1153,12 +1213,12 @@ class TableRow(object):
         #         return v
         #     raise Exception("Oops, {} on {} is {}".format(name, cls, v))
 
-    def obj2href(self, ar, *args, **kwargs):
+    def obj2href(self, ar, text=None, **kwargs):
         if ar is None:
-            if len(args):
-                return args[0]
+            if text:
+                return text
             return str(self)
-        return ar.obj2html(self, *args, **kwargs)
+        return ar.obj2html(self, text, **kwargs)
 
     def get_detail_action(self, ar):
         """Return the (bound) detail action to use for showing this object in
@@ -1211,7 +1271,7 @@ class TableRow(object):
     #     return ar.actor.get_table_summary(self, ar)
 
     # @fields.displayfield(_("Description"))
-    # @fields.htmlbox(_("Overview"))
+    # @htmlbox(_("Overview"))
     @htmlbox()
     def overview(self, ar):
         if ar is None:
@@ -1223,12 +1283,23 @@ class TableRow(object):
         if ar is None:
             return str(self)
         return ar.obj2html(self)
+        # return "".join([ar.row_as_paragraph(row) for row in ar.selected_rows])
         # return E.div(*forcetext(self.get_overview_elems(ar)))
 
     def get_overview_elems(self, ar):
         # return [ar.obj2html(self)]
         return [self.obj2href(ar)]
 
+    def as_page(self, ar):
+        return []
+
+    def as_paragraph(self, ar):
+        """Return a rich text that represents the given row as a list item.
+
+        See :ref:`dev.as_paragraph`.
+        """
+        return str(self)
+
     def save_existing_instance(self, ar):
         watcher = ChangeWatcher(self)
         # print("20210213 save_existing_instance", ar.ah, ar.rqdata, self.disabled_fields)
@@ -1349,11 +1420,12 @@ def pointer_factory(cls, othermodel, *args, **kw):
 
     - It supports `othermodel` being `None` or the name of some
       non-installed model and returns a :class:`DummyField` in that
-      case. This difference is useful when designing reusable models.
+      case. This is useful when designing reusable models.
 
     - Explicitly sets the default value for `on_delete
-      <https://docs.djangoproject.com/en/3.2/ref/models/fields/#django.db.models.ForeignKey.on_delete>`__
+      <https://docs.djangoproject.com/en/4.1/ref/models/fields/#django.db.models.ForeignKey.on_delete>`__
       to ``CASCADE`` (as required by Django 2).
+
     """
     if othermodel is None:
         return DummyField(othermodel, *args, **kw)
@@ -1457,20 +1529,24 @@ def make_remote_field(model, name):
         # all intermediate fields are OneToOneRel
         target = obj
         try:
-            for fld in field_chain:
+            for i, fld in enumerate(field_chain):
                 # print("20180712a %s" % fld)
                 if isinstance(fld, (models.OneToOneRel, models.ForeignKey)):
                     reltarget = getattr(target, fld.name, None)
                     if reltarget is None:
-                        rkw = { fld.field.name: target }
+                        # rkw = { fld.field.name: target }
                         # print(
                         #     "20180712 create {}({})".format(
                         #         fld.related_model, rkw))
                         reltarget = fld.related_model(**rkw)
-                        reltarget.full_clean()
-                        reltarget.save()
+                        reltarget.save_new_instance(fld.related_model.get_default_table().request())
 
                     setattr(target, fld.name, reltarget)
+
+                    if target == obj and target.id is None:
+                        # Model.save_new_instance will be called do not insert this record.
+                        target = reltarget
+                        continue
                     target.full_clean()
                     target.save()
                     # print("20180712b {}.{} = {}".format(
