@@ -1,15 +1,12 @@
-# Copyright 2010-2018 Rumma & Ko Ltd
-# License: BSD (see file COPYING for details)
+# Copyright 2010-2021 Rumma & Ko Ltd
+# License: GNU Affero General Public License v3 (see file COPYING for details)
 """Helper methods for GenericForeignKey
 
 """
 
-import six
 from django.conf import settings
 from django.db.models import ForeignKey
 
-from .utils import UnresolvedField, UnresolvedModel
-
 if settings.SITE.is_installed('contenttypes'):
     from lino.modlib.gfks.fields import GenericForeignKey
     from django.contrib.contenttypes.models import ContentType
@@ -21,6 +18,7 @@ if settings.SITE.is_installed('contenttypes'):
     def is_foreignkey(fld):
         return isinstance(fld, (ForeignKey, DjangoGenericForeignKey))
 else:
+    from lino.core.utils import UnresolvedField, UnresolvedModel
     GenericForeignKey = UnresolvedField
     ContentType = UnresolvedModel
     GenericRelation = UnresolvedField
@@ -50,7 +48,7 @@ def gfk2lookup(gfk, obj, **kw):
     else:
         ct = ContentType.objects.get_for_model(obj.__class__)
         kw[gfk.ct_field] = ct
-        if not isinstance(obj.pk, six.integer_types):
+        if not isinstance(obj.pk, int):
             # IntegerField gives `long` when using MySQL
             return kw
         kw[gfk.fk_field] = obj.pk
