@@ -34,6 +34,7 @@ import atexit
 import threading
 from importlib import import_module
 # import dill
+import json
 
 
 from django.apps import AppConfig
@@ -108,7 +109,6 @@ class Kernel(object):
         # logger.info("20140227 Kernel.__init__() a")
         self.site = site
         self.GFK_LIST = []
-        self.kernel_startup(site)
         # logger.info("20140227 Kernel.__init__() done")
 
     _code_mtime = None
@@ -116,49 +116,18 @@ class Kernel(object):
 
     @property
     def code_mtime(self):
-        # We set `code_mtime` only after kernel_startup() because
-        # codetime watches only those modules which are already
-        # imported.
         if self._code_mtime is None:
-            if self.site.is_demo_site:
+            # packages = [os.environ['DJANGO_SETTINGS_MODULE'], 'lino']
+            # self._code_mtime = codetime(*packages)
+            if self.site.developer_site_cache:
                 self._code_mtime = codetime()
             else:
-                self._code_mtime = os.stat(import_module(
-                    os.environ['DJANGO_SETTINGS_MODULE']).__file__).st_mtime
+                # On a production server we test only the timestamp of
+                # settings.py file because otherwise the result can differ
+                # depending on which modules have already been imported.
+                self._code_mtime = codetime(settings.SETTINGS_MODULE)
         return self._code_mtime
 
-    @property
-    def lino_version(self):
-        """
-
-        This gathers all of the apps version numbers and add them up in order,
-        to use it as modification stamp. Any updates on any of the dependent
-        django apps will increase this collective version number and will be
-        used as a stamp to propagate changes through the system.
-
-        This is automatically activated when :attr:`Site.never_build_site_cache
-        <lino.core.site.Site.never_build_site_cache>` is set to `True`,
-        supposedly used in a production server.
-
-        """
-        if self._lino_version is None:
-            mods = set([mod.split('.')[0] for mod in settings.INSTALLED_APPS])
-            version = [0, 0, 0]
-            for mod in mods:
-                m = import_module(mod)
-                if hasattr(m, '__version__'):
-                    v = [int(num) for num in m.__version__.split('.')]
-                    for i in range(len(v)):
-                        version[i] += v[i]
-                        if i == 2:
-                            break
-            rn = [int(num) for num in self.site.revision_number.split('.')]
-            for i in range(rn):
-                version[i] = version[i] + rn[i]
-            version = [str(num) for num in version]
-            self._lino_version = '.'.join(version)
-        return self._lino_version
-
     def kernel_startup(self, site):
         """This is a part of a Lino site startup.  The Django Model
         definitions are done, now Lino analyzes them and does certain
@@ -173,7 +142,7 @@ class Kernel(object):
 
         """
         # logger.info("20161219 kernel_startup")
-        if site.history_aware_logging:
+        if site._history_aware_logging:
             if len(sys.argv) == 0:
                 process_name = 'WSGI'
             else:
@@ -262,7 +231,7 @@ class Kernel(object):
                     self.GFK_LIST.append(f)
             self.GFK_LIST.sort(key=lambda f: str(f))
 
-        site.load_actors()
+        # site.load_actors()
 
         # raise Exception("20190102 {!r}".format(site.models.courses.ActivitiesByLine.detail_link))
 
@@ -433,6 +402,10 @@ class Kernel(object):
         # table.  This includes automatic models created by
         # ManyToManyField.
         for model in models_list:
+            p = site.plugins.get(model._meta.app_label)
+            if not p.is_active():
+                # models of inactive plugins need no _lino_default_table
+                continue
             # Not getattr but __dict__.get because of the mixins.Listings
             # trick:
             rpt = model.__dict__.get('_lino_default_table', None)
@@ -508,11 +481,12 @@ class Kernel(object):
 
         # self.memo_parser = Parser()
 
-        if 'LINO_BUILD_CACHE_ON_STARTUP' in os.environ:
-            site.build_js_cache_on_startup = True
-        if site.build_js_cache_on_startup is None:
-            site.build_js_cache_on_startup = not (
-                settings.DEBUG or is_devserver())
+        # if 'LINO_BUILD_CACHE_ON_STARTUP' in os.environ:
+        #     site.build_js_cache_on_startup = True
+        # if site.build_js_cache_on_startup is None:
+        #     site.build_js_cache_on_startup = not (settings.DEBUG or is_devserver())
+
+        site.developer_site_cache = settings.DEBUG or is_devserver()
 
         # web.site_setup(site)
 
@@ -539,20 +513,22 @@ class Kernel(object):
         # self.html_renderer = HtmlRenderer(self)
         # self.text_renderer = TextRenderer(self)
 
-        for p in site.installed_plugins:
-            p.on_ui_init(self)
-
-        site.resolve_virtual_fields()
-
         for p in self.site.installed_plugins:
             if p.app_name == self.site.default_ui:
                 if not p.force_url_prefix:
                     p.url_prefix = None
-                self.default_renderer = p.renderer
                 self.default_ui = p
                 self.html_renderer = HtmlRenderer(p)
                 self.text_renderer = TextRenderer(p)
                 break
+
+        for p in site.installed_plugins:
+            p.on_ui_init(self)
+
+        self.default_renderer = self.default_ui.renderer
+
+        site.resolve_virtual_fields()
+
         if self.site.admin_ui is not None:
             for p in self.site.installed_plugins:
                 if p.app_name == self.site.admin_ui:
@@ -613,8 +589,8 @@ class Kernel(object):
         for res in actors.actors_list:
             for ba in res.get_actions():
                 if ba.action.params_layout is not None:
-                    ba.action.params_layout.get_layout_handle(
-                        self.default_ui)
+                    ba.action.params_layout.get_layout_handle()
+
         # logger.info("20161219 kernel_startup done")
 
     def protect_foreignkeys(self, models_list):
@@ -768,8 +744,8 @@ class Kernel(object):
 
         """
         if not ar.get_permission():
-            msg = "{} has no permission to run this request".format(
-                ar.get_user())
+            # msg = "{} has no permission to run this request".format(
+            #     ar.get_user())
             msg = "No permission to run {}".format(ar)
             # raise Exception(msg)
             raise PermissionDenied(msg)
@@ -824,7 +800,7 @@ class Kernel(object):
             ll = layouts.ColumnsLayout(
                 h.actor.get_column_names(ar),
                 h.actor, hidden_elements=he)
-            h.list_layout = ll.get_layout_handle(self.default_ui)
+            h.list_layout = ll.get_layout_handle()
         else:
             h.list_layout = None
 
@@ -849,13 +825,13 @@ class Kernel(object):
         startup.
 
         """
-        # cachedir = self.site.cache_dir.child('static', 'cache', 'js')
+        # cachedir = self.site.site_dir.child('static', 'cache', 'js')
         # if not exists(settings.STATIC_ROOT):
         #     logger.info("STATIC_ROOT does not exist: %s", settings.STATIC_ROOT)
         #     return 0
-        fn = join(settings.SITE.site_cache_root, fn)
+        fn = self.site.media_root / fn
         # fn = join(settings.STATIC_ROOT, fn)
-        # fn = join(self.site.cache_dir, fn)
+        # fn = join(self.site.site_dir, fn)
         if not force and not self._must_build and exists(fn):
             mtime = os.stat(fn).st_mtime
             if mtime > self.code_mtime:
@@ -889,6 +865,47 @@ class Kernel(object):
     # def setup_static_link(self, urlpatterns, short_name,
     #                       attr_name=None, source=None):
 
+    def mark_virgin(self):
+        dbhash = self.get_dbhash()
+        fn = self.site.site_dir / "dbhash.json"
+        with fn.open("w") as fp:
+            json.dump(dbhash, fp)
+
+    def check_virgin(self):
+        new = self.get_dbhash()
+        fn = self.site.site_dir / "dbhash.json"
+        if not fn.exists():
+            raise Exception("No `dbhash.json` in {} "
+                "(did you run `django-admin prep`?)".format(self.site.site_dir))
+        with fn.open("r") as fp:
+            old = json.load(fp)
+
+        # noi1r has noi1e as master_site, but the react front end removes the
+        # tinymce plugin, i.e. noi1r doesn't care about
+        # tinymce.TextFieldTemplate model.
+
+        diffs = {}
+        for k, v in new.items():
+            oldv = old.get(k, None)
+            if oldv != v:
+                diffs[k] = (oldv, v)
+        # diff = set(old.items()) ^ set(new.items())
+        if diffs:
+            # db = self.site.django_settings.get('SETTINGS_MODULE')
+            db = self.site.site_dir
+            raise Exception("Database {} isn't virgin: {}".format(db, diffs))
+
+        # logger.info("Database certified as virgin")
+
+    def get_dbhash(self):
+        # TODO: we currently check only the number of rows per model. That's
+        # very naive.
+        rv = dict()
+        for m in get_models(include_auto_created=True):
+            k = fmn(m)
+            if k != "sessions.Session":
+                rv[k] = m.objects.count()
+        return rv
 
 def site_startup(self):
     """This is being imported and called from
@@ -898,8 +915,8 @@ def site_startup(self):
     """
     with startup_rlock:
 
-        # if self.cache_dir is not None:
-        #     raise Exception("No cache_dir is defined. "
+        # if self.site_dir is not None:
+        #     raise Exception("No site_dir is defined. "
         #                     "Check your LINO_CACHE_ROOT and project_name.")
 
         if self._starting_up:
@@ -929,6 +946,8 @@ def site_startup(self):
         #     import django
         #     django.setup()
 
+        self.kernel = Kernel(self)
+
         for a in apps.get_app_configs():
             self.models.define(str(a.label), a.models_module)
 
@@ -973,17 +992,35 @@ def site_startup(self):
 
         # logger.info("20150428 user_interfaces %s", self.user_interfaces)
 
-        self.kernel = Kernel(self)
+        self.kernel.kernel_startup(self)
 
         self.do_site_startup()
 
         for p in self.installed_plugins:
             p.post_site_startup(self)
 
-        # print("20161219 Site.startup() done")
         post_startup.send(self)
+
+        # doctest docs/specs/react/linoweb.rst is failing with "Oops,
+        # get_atomizer(contacts.Persons, contacts.RolesByPerson,
+        # contacts.RolesByPerson) returned None" because the store fields for
+        # slave tables were not yet created. Activating the following code fixes
+        # this issue bu causes other problems:
+        if False:
+            for res in actors.actors_list:
+                if res.detail_layout is not None:
+                    res.detail_layout.get_layout_handle()
+
+        # print("20161219 Site.startup() done")
         self._startup_done = True
 
+        # # doctest docs/specs/react/linoweb.rst was failing with "Oops,
+        # # get_atomizer(contacts.Persons, contacts.RolesByPerson,
+        # # contacts.RolesByPerson) returned None" because the store fields for
+        # # slave tables were not yet created:
+        # for res in actors.actors_list:
+        #     if res.detail_layout is not None:
+        #         res.detail_layout.get_layout_handle()
 
 
 CHOICELISTS = {}
