@@ -627,28 +627,27 @@ add_tabpanel() on %s horizontal 'main' panel %r."""
         #~ if kw:
             #~ print 20120525, self, self.detail_layout._element_options
 
-    def get_layout_handle(self, ui=None):
+    def get_layout_handle(self):
         """
-        Return the LayoutHandle for this layout on the specified front end `ui`.
+        Return the LayoutHandle for this layout.
         Create a LayoutHandle instance if this is the first call.
 
-        TODO: replace get_layout_handle by a simple property. We no longer have
-        Lino sites with several front ends
+        20230217: Removed ui argument because we no longer have Lino sites with
+        several front ends
 
         """
-        if ui is None:
-            ui = settings.SITE.kernel.default_ui
-        hname = ui.ui_handle_attr_name
+        front_end = settings.SITE.kernel.default_ui
+        hname = front_end.ui_handle_attr_name
         if hname is None:
             raise Exception(
-                "{0} has no `ui_handle_attr_name`!".format(ui))
+                "{0} has no `ui_handle_attr_name`!".format(front_end))
 
         # we do not want any inherited handle
         h = self.__dict__.get(hname, None)
         if h is None:
             # if str(self._datasource) == 'courses.Pupils':
             # print("20160329 layouts.py make handle", self._datasource)
-            h = LayoutHandle(self, ui)
+            h = LayoutHandle(self, front_end)
             setattr(self, hname, h)
         return h
 
@@ -667,7 +666,7 @@ add_tabpanel() on %s horizontal 'main' panel %r."""
             field.name, **kw)
 
     def to_rst(self, user_type=None, name=None):
-        lh = self.get_layout_handle(settings.SITE.kernel.default_ui)
+        lh = self.get_layout_handle()
         # if user_type is None:
         #     user_type = UserTypes.admin
         if name is None:
@@ -688,7 +687,7 @@ add_tabpanel() on %s horizontal 'main' panel %r."""
 
 
         """
-        lh = self.get_layout_handle(settings.SITE.kernel.default_ui)
+        lh = self.get_layout_handle()
         return lh[name]
 
 
