@@ -1,5 +1,5 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2013-2021 Rumma & Ko Ltd
+# Copyright 2013-2023 Rumma & Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
 """
 This defines the :class:`MergeAction` class.
@@ -93,7 +93,7 @@ class MergeAction(actions.Action):
             parameters=parameters,
             params_layout=layouts.Panel(main, **layout))
 
-        super(MergeAction, self).__init__(**kw)
+        super().__init__(**kw)
 
     #~ def action_param_defaults(self,ar,obj,**kw):
         #~ kw = super(MergeAction,self).action_param_defaults(ar,obj,**kw)
@@ -116,7 +116,13 @@ class MergeAction(actions.Action):
         def ok(ar2):
             logger.info("Gonna execute merge plan %s", mp.logmsg())
             msg = mp.execute(request=ar.request)
-            ar2.goto_instance(mp.merge_to)
+
+            # same after-run behaviour as DeleteSelected
+            ar2.success(record_deleted=True, refresh_all=True)
+            # hack required for extjs:
+            if ar2.actor.detail_action:
+                ar2.set_response(
+                    detail_handler_name=ar2.actor.detail_action.full_name())
             ar2.success(msg, alert=True, close_window=True)
             logger.info("%s : %s", ar.get_user(), msg)
 
@@ -227,10 +233,13 @@ class MergePlan(object):
                 #~ i.full_clean()
                 #~ i.save()
 
+        def fmt(obj):
+            return "{} ({})".format(obj, obj.pk)
+
         # Build the return message
         msg = _("Merged %(this)s into %(merge_to)s. "
                 "Updated %(updated)d related rows.") % dict(
-                    this=self.obj, merge_to=self.merge_to,
+                    this=fmt(self.obj), merge_to=fmt(self.merge_to),
                     updated=update_count)
 
         # Delete object from database:
