@@ -117,9 +117,6 @@ class Model(models.Model, fields.TableRow):
     _lino_tables = []
     _bleached_fields = []
 
-    def as_list_item(self, ar):
-        return E.li(str(self))
-
     def get_master_data(self, ar, master_instance=None):
         if master_instance is None:
             master_instance = ar.master_instance
@@ -332,22 +329,23 @@ class Model(models.Model, fields.TableRow):
             raise ChangedAPI("Replace bleached_fields by bleached=True on each field")
 
     @classmethod
-    def create_from_choice(cls, text):
-        # if cls.disable_create_choice:
-        #     return
-        values = cls.choice_text_to_dict(text)
+    def create_from_choice(cls, text, ar=None, save=True):
+        # Use save=False when calling this in a doctest to avoid modifying the
+        # database, which might cause failures in other tests
+        values = cls.choice_text_to_dict(text, ar)
         if values is None:
             raise ValidationError(
                 _("Cannot create {obj} from '{text}'").format(
                 obj=cls._meta.verbose_name, text=text))
         obj = cls(**values)
         obj.full_clean()
-        obj.save()
+        if save:
+            obj.save()
         return obj
 
 
     @classmethod
-    def choice_text_to_dict(cls, text):
+    def choice_text_to_dict(cls, text, ar):
         return None
 
     @classmethod
@@ -606,7 +604,7 @@ class Model(models.Model, fields.TableRow):
 
     def as_summary_row(self, ar):
         # used by tickets.Tickets table in the bootstrap frontend
-        # also when display_mode_main = constants.DISPLAY_MODE_STORY it returns html
+        # also when display_mode = ((None, constants.DISPLAY_MODE_STORY), ) it returns html
         # text for the object that is calling
         if self.summary_row_template:
             # not tested
@@ -827,7 +825,7 @@ class Model(models.Model, fields.TableRow):
 
             label = cls.verbose_name
             icon_name = None
-            show_in_bbar = False
+            show_in_toolbar = False
             no_params_window = True
             parameters = dict(choice=cls.field())
 
@@ -976,6 +974,8 @@ LINO_MODEL_ATTRIBS = (
     'get_row_permission',
     # 'get_excerpt_options',
     # 'is_attestable',
+    'as_paragraph',
+    'as_page',
     'get_data_elem',
     'get_param_elem',
     'after_ui_save',
@@ -1035,7 +1035,7 @@ def pre_delete_handler(sender, instance=None, **kw):
 
     It seems that Django deletes *generic related objects* only if
     the object being deleted has a `GenericRelation
-    <https://docs.djangoproject.com/en/1.11/ref/contrib/contenttypes/#django.contrib.contenttypes.fields.GenericRelation>`_
+    <https://docs.djangoproject.com/en/4.1/ref/contrib/contenttypes/#django.contrib.contenttypes.fields.GenericRelation>`_
     field (according to `Why won't my GenericForeignKey cascade
     when deleting?
     <https://stackoverflow.com/questions/6803018/why-wont-my-genericforeignkey-cascade-when-deleting>`_).
