@@ -1,16 +1,13 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2008-2019 Rumma & Ko Ltd
+# Copyright 2008-2023 Rumma & Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
 
 """This defines the :class:`Plugin` class.
 
-See :doc:`/dev/plugins` before reading this.
+See :doc:`/dev/plugins`.
 
 
 """
-# from future import standard_library
-# standard_library.install_aliases()
-# from builtins import object
 
 import os
 from os.path import exists, join, dirname, isdir, abspath
@@ -19,7 +16,6 @@ from os.path import exists, join, dirname, isdir, abspath
 from six.moves.urllib.parse import urlencode
 import inspect
 
-# from .features import FEATURES_HOOKS#, LINO_FEATURES
 
 class Plugin(object):
     """The base class for all plugin descriptors.
@@ -33,7 +29,7 @@ class Plugin(object):
     is the `app_label` of the plugin).
 
     The :class:`Plugin` class is comparable to Django's `AppConfig
-    <https://docs.djangoproject.com/en/1.11/ref/applications/>`_ class
+    <https://docs.djangoproject.com/en/4.1/ref/applications/>`_ class,
     which has been added in version 1.7., but there is at least one
     important difference: in Lino the :class:`Plugin` instances for
     all installed plugins are available (in :attr:`dd.plugins
@@ -131,16 +127,6 @@ class Plugin(object):
 
     """
 
-    media_root = None
-    """
-    Local path where third-party media files are installed.
-
-    Only used if this app has :attr:`media_base_url` empty and
-    :attr:`media_name` non-empty, *and* if the :xfile:`media`
-    directory has no entry named :attr:`media_name`.
-
-    """
-
     media_name = None
     """
     Either `None` (default) or a non-empty string with the name of the
@@ -172,13 +158,17 @@ class Plugin(object):
     """
 
     support_async = False
-    """Whether this plugin supports usage of :class:`lino.utils.DelayedValue`."""
+    """Whether this plugin uses :class:`lino.utils.DelayedValue`."""
 
 
     renderer = None
     """The renderer used by this plugin. See :doc:`/dev/rendering`."""
 
-    def __init__(self, site, app_label, app_name, app_module, needed_by):
+    _active = True
+    """Whether this plugin is active.
+    """
+
+    def __init__(self, site, app_label, app_name, app_module, needed_by, configs: dict):
         """This is called when the Site object *instantiates*, i.e.  you may
         not yet import `django.conf.settings`.  But you get the `site`
         object being instantiated.
@@ -194,8 +184,7 @@ class Plugin(object):
         """
         # site.logger.info("20140226 Plugin.__init__() %s",
         #                  app_label)
-        if site._startup_done:  # djangotest.TestCase.__call__
-            raise Exception(20140227)
+        assert not site._startup_done
         self.site = site
         self.app_name = app_name
         self.app_label = app_label
@@ -205,10 +194,18 @@ class Plugin(object):
             self.verbose_name = app_label.title()
         if self.short_name is None:
             self.short_name = self.verbose_name
+        self.configure(**configs)
         self.on_init()
         # import pdb; pdb.set_trace()
         # super(Plugin, self).__init__()
 
+    def is_active(self):
+        return self._active
+
+    def deactivate(self):
+        assert not self.site._startup_done
+        self._active = False
+
     def configure(self, **kw):
         """
         Set the given parameter(s) of this Plugin instance.  Any number of
@@ -217,7 +214,7 @@ class Plugin(object):
         Raise an exception if caller specified a key that does not
         have a corresponding attribute.
         """
-        for k, v in list(kw.items()):
+        for k, v in kw.items():
             if not hasattr(self, k):
                 raise Exception("%s has no attribute %s" % (self, k))
             setattr(self, k, v)
@@ -331,14 +328,20 @@ class Plugin(object):
 
     def __repr__(self):
         l = []
-        for k in ('media_name', 'media_root', 'media_base_url',
-                  'extends_models', 'needed_by'):
+        for k in ('media_name', 'media_base_url', 'extends_models'):
             v = getattr(self, k, None)
-            if v is not None:
-                l.append('%s=%s' % (k, v))
+            if v:
+                l.append('{}={}'.format(k, v))
+        if self.needed_by:
+            l.append('needed_by={}'.format(self.needed_by.app_name))
+        if self.needs_plugins:
+            # l.append('needs_plugins={}'.format([p.app_name for p in self.needs_plugins]))
+            l.append('needs_plugins={}'.format(self.needs_plugins))
         if len(l) == 0:
             return self.app_name
-        return "%s (%s)" % (self.app_name, ', '.join(l))
+        # print(l)
+        attrs = ', '.join(l)
+        return "{} ({})".format(self.app_name, attrs)
 
     def get_patterns(self):
         """
@@ -402,7 +405,7 @@ class Plugin(object):
 
     def get_menu_group(self):
         """
-        Return the plugin (a :class:`Plugin` instance) into whose menu
+        Return the plugin (a :class:`Plugin` instance) into the menu of which
         this plugin should add its menu commands.
 
         This returns `self` by default, unless
