@@ -1,12 +1,10 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2009-2020 Rumma & Ko Ltd
+# Copyright 2009-2023 Rumma & Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
 """
 Defines :class:`HtmlRenderer` and :class:`TextRenderer`.
 """
 
-import logging ; logger = logging.getLogger(__name__)
-
 from html import escape
 import rstgen
 
@@ -25,6 +23,7 @@ from lino.utils import isiterable
 from lino.utils.jsgen import py2js, js_code
 from etgen.html import E, tostring, iselement, forcetext, to_rst
 from lino.core import constants
+from lino.core.site import html2text
 from lino.core.fields import TableRow
 
 from lino.core.menus import Menu, MenuItem
@@ -179,7 +178,7 @@ class HtmlRenderer(Renderer):
         from bs4 import BeautifulSoup
         import rstgen
         if display_mode == constants.DISPLAY_MODE_CARDS:
-            layout = ar.actor.card_layout or actor.item_layout
+            layout = ar.actor.card_layout or actor.list_layout
             lh = layout.get_layout_handle()
         else:
             lh = ar.bound_action.get_layout_handel()
@@ -250,10 +249,10 @@ class HtmlRenderer(Renderer):
         Silently ignores the parameters `stripped` and `header_links`
         since for HTML these options have no meaning.
         """
+        if display_mode is None:
+            display_mode = ar.actor.get_display_mode()
         if not nosummary:
-            if display_mode is None:
-                display_mode = ar.actor.display_mode_main
-            if display_mode == 'summary':
+            if display_mode == constants.DISPLAY_MODE_SUMMARY:
                 yield ar.actor.get_table_summary(ar.master_instance, ar)
                 return
 
@@ -262,6 +261,10 @@ class HtmlRenderer(Renderer):
             h = getattr(E, k)(str(ar.get_title()))
             yield h
 
+        if display_mode == constants.DISPLAY_MODE_LIST:
+            yield ar.actor.get_table_as_list(ar.master_instance, ar)
+            return
+
         yield ar.table2xhtml(**kwargs)
 
         # if show_toolbar:
@@ -466,7 +469,7 @@ class HtmlRenderer(Renderer):
             return E.em(*text)
         return self.href_button(url, text, **kwargs)
 
-    def obj2str(self, *args, **kwargs):
+    def obj2htmls(self, *args, **kwargs):
         return tostring(self.obj2html(*args, **kwargs))
 
     def quick_upload_buttons(self, rr):
@@ -691,6 +694,9 @@ class TextRenderer(HtmlRenderer):
     def get_request_url(self, ar, *args, **kw):
         return None
 
+    # def obj2url(self, ar, obj):
+    #     return None
+
     # def get_detail_url(self, actor, pk, *args, **kw):
     #     # return str(actor)+"/"+str(pk)
     #     return "Detail"  # many doctests depend on this
@@ -707,7 +713,8 @@ class TextRenderer(HtmlRenderer):
         :meth:`ar.show <lino.core.request.BaseRequest.show>`.
         """
         if display_mode is None:
-            display_mode = ar.actor.display_mode_main
+            display_mode = ar.actor.get_display_mode()
+            # display_mode = [dmi[1] for dmi in ar.actor.display_mode if dmi[0] is None][0]
         # if ar.actor.master is not None and not nosummary:
         if not nosummary:
             if display_mode == constants.DISPLAY_MODE_SUMMARY:
@@ -726,6 +733,28 @@ class TextRenderer(HtmlRenderer):
             # rows = [ar.show_detail]
             return
 
+        if display_mode == constants.DISPLAY_MODE_LIST:
+            # s = to_rst(ar.actor.get_table_as_list(ar.master_instance, ar), stripped=stripped)
+            cls = ar.actor
+            items = []
+            if cls.insert_action is not None and cls.editable:
+                ir = cls.insert_action.request_from(ar)
+                if ir.get_permission():
+                    items.append("(+) {}".format(cls.insert_action.action.help_text))
+            # for i, obj in enumerate(ar.data_iterator):
+            #     if i == cls.preview_limit:
+            #         break
+            for obj in ar.sliced_data_iterator:
+                # if i == cls.preview_limit:
+                #     break
+                txt = ar.row_as_paragraph(obj).strip()
+                txt = html2text(txt)
+                # refuse showing more than one paragraph:
+                # txt = txt.split('\n\n')[0]
+                items.append(txt)
+            yield rstgen.ul(items).strip()
+            return
+
         fields, headers, widths = ar.get_field_info(column_names)
 
         # if str(ar.actor) == "working.WorkedHours":
@@ -803,8 +832,8 @@ class TextRenderer(HtmlRenderer):
         except Warning as e:
             print(e)
 
-    def obj2str(self, ar, obj, text=None, **kwargs):
-        """Used by :meth:`lino.core.requests.BaseRequest.obj2str`.
+    def obj2htmls(self, ar, obj, text=None, **kwargs):
+        """Used by :meth:`lino.core.requests.BaseRequest.obj2htmls`.
         """
         if text is None:
             # text = force_str(obj)
@@ -812,6 +841,7 @@ class TextRenderer(HtmlRenderer):
         # return "**{0}**".format(text)
         return settings.SITE.obj2text_template.format(text)
 
+
 class TestRenderer(TextRenderer):
     """
     Like :class:`TextRenderer` but returns a string instead of
