@@ -1,24 +1,21 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2009-2020 Rumma & Ko Ltd
+# Copyright 2009-2023 Rumma & Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
 """
 Defines :class:`JsCacheRenderer`.
 """
 
 import logging ; logger = logging.getLogger(__name__)
-
-from django.conf import settings
-
-from django.utils import translation
-
 import os
 import time
 
+from django.conf import settings
+from django.utils import translation
+
 from lino.core import kernel
 from lino.core import layouts
 from lino.core.actions import resolve_layout
-from lino.modlib.users.utils import get_user_profile, with_user_profile
-from lino.modlib.users.choicelists import UserTypes
+from lino.modlib.users.utils import get_user_profile
 
 
 class JsCacheRenderer():
@@ -30,7 +27,6 @@ class JsCacheRenderer():
 
     Includes linoweb.js cacheing functionality.
 
-
     """
     lino_web_template = "extjs/linoweb.js"
 
@@ -118,7 +114,7 @@ class JsCacheRenderer():
 
             if False:
                 try:
-                    lh = fl.get_layout_handle(self.plugin)
+                    lh = fl.get_layout_handle()
                 except Exception as e:
                     logger.exception(e)
                     raise Exception("Could not define %s for %r: %s" % (
@@ -150,7 +146,7 @@ class JsCacheRenderer():
                 "%s.ParamsPanel" % res)
             add(res, self.other_panels, res.card_layout,
                 "%s.CardsPanel" % res)
-            add(res, self.other_panels, res.item_layout,
+            add(res, self.other_panels, res.list_layout,
                 "%s.ItemsPanel" % res)
 
             for ba in res.get_actions():
@@ -175,61 +171,12 @@ class JsCacheRenderer():
         env = settings.SITE.plugins.jinja.renderer.jinja_env
         return env.get_template(self.lino_web_template)
 
-    def build_site_cache(self, force=False, from_commandline=False):
-        """
-        Build the site cache files under `/media/cache`, especially the
-        :xfile:`lino*.js` files, one per user user_type and language.
-        """
-        # if not self.is_prepared:
-        #     self.prepare_layouts()
-        #     self.is_prepared = True
-
-        if not from_commandline and settings.SITE.never_build_site_cache:
-            logger.debug(
-                "Not building site cache because `settings.SITE.never_build_site_cache` is True")
-            return
-        if not os.path.isdir(settings.SITE.site_cache_root):
-            try:
-                os.mkdir(settings.SITE.site_cache_root)
-            except FileNotFoundError:
-                logger.debug(
-                    "Not building site cache because " +
-                    "parent directory '%s' of (settings.SITE.site_cache_root) does not exist.",
-                    settings.SITE.site_cache_root.parent)
-                return
-
-        started = time.time()
-        # logger.info("20140401 build_site_cache started")
-
-        settings.SITE.on_each_app('setup_site_cache', force)
-
-        settings.SITE.makedirs_if_missing(
-            os.path.join(settings.MEDIA_ROOT, 'webdav'))
-
-        if force or settings.SITE.build_js_cache_on_startup:
-            count = 0
-            for lng in settings.SITE.languages:
-                with translation.override(lng.django_code):
-                    for user_type in UserTypes.objects():
-                        count += with_user_profile(
-                            user_type, self.build_js_cache, force)
-            logger.info("%d lino*.js files have been built in %s seconds.",
-                        count, time.time() - started)
 
     def build_js_cache(self, force):
-        """Build the :xfile:`lino*.js` file for the current user and the
+        """Build the :term:`site cache` files for the current user type and the
         current language.  If the file exists and is up to date, don't
         generate it unless `force` is `True`.
 
-        This is called
-
-        - on each request if :attr:`build_js_cache_on_startup
-          <lino.core.site.Site.build_js_cache_on_startup>` is `False`.
-
-        - with `force=True` when
-          :class:`lino.modlib.lino.models.BuildSiteCache` action is
-          run.
-
         """
         fn = os.path.join(*self.lino_js_parts())
 
