@@ -6,6 +6,7 @@ See introduction in :doc:`/dev/ar`.
 """
 
 import logging; logger = logging.getLogger(__name__)
+import html
 
 from types import GeneratorType
 from copy import copy, deepcopy
@@ -22,7 +23,6 @@ from django.db import models
 from lino.core import constants
 from lino.utils import AttrDict
 from etgen.html import E, tostring, iselement
-from lino.core.auth.utils import AnonymousUser
 
 from lino.core import callbacks
 from lino.core import actions
@@ -116,6 +116,7 @@ class ValidActionResponses(object):
     refresh_all = None
     close_window = None
     record_deleted = None
+    clear_site_cache = None
 
     xcallback = None
     """
@@ -328,7 +329,7 @@ class BaseRequest(object):
               xcallback_answers=None):
         self.requesting_panel = requesting_panel
         if user is None:
-            self.user = AnonymousUser()
+            self.user = settings.SITE.get_anonymous_user()
         else:
             self.user = user
         self.current_project = current_project
@@ -546,14 +547,20 @@ class BaseRequest(object):
         """
         Given a tuple of primary keys, set :attr:`selected_rows` to a list
         of corresponding database objects.
+
+        The special pks's -99998  and -99999 are filtered out.
+
         """
         # ~ print 20131003, selected_pks
         self.selected_rows = []
         for pk in selected_pks:
-            if pk:
+            if pk and pk != '-99998'  and pk != '-99999':
                 obj = self.get_row_by_pk(pk)
-                if obj is not None:
-                    self.selected_rows.append(obj)
+                if obj is None:
+                    raise exceptions.ObjectDoesNotExist(
+                        "Invalid primary key {0} for {1}".format(
+                            pk, self.actor))
+                self.selected_rows.append(obj)
         # self.selected_rows = filter(lambda x: x, self.selected_rows)
         # note: ticket #523 was because the GET contained an empty pk ("&sr=")
 
@@ -685,6 +692,7 @@ class BaseRequest(object):
             msg = msg % args
         if kw:
             msg = msg % kw
+        # print("20221124", msg)
         k = level + '_message'
         old = self.response.get(k, None)
         if old is None:
@@ -755,17 +763,6 @@ class BaseRequest(object):
     def parse_memo(self, txt, **context):
         return settings.SITE.plugins.memo.parser.parse(txt, self, context)
 
-    def obj2memo(self, *args, **kwargs):
-        """
-        Calls the site's parser's :meth:`obj2memo
-        <lino.modlib.memo.parser.Parser.obj2memo>` method.
-        """
-        # kwargs.update(ar=self)
-        return settings.SITE.plugins.memo.parser.obj2memo(*args, **kwargs)
-
-    # def parse_memo(self, html):
-    #     return self.renderer.parse_memo(html, ar=self)
-
     def show_detail(self, *args, **kwargs):
         return self.renderer.show_detail(self, *args, **kwargs)
 
@@ -902,20 +899,22 @@ class BaseRequest(object):
                      .e.g. in :ref:`avanti.specs.roles` where we want
                      to show whether cells are clickable or not.
 
-        :nosummary: if it is a table with :attr:`display_mode_main
-                    <lino.core.tables.AbstractTable.display_mode_main>`
-                    set to ``'summary'``, force rendering it as a
-                    table.
+        :nosummary: if it is a table with :attr:`display_mode
+                    <lino.core.tables.AbstractTable.display_mode>`
+                    set to ``((None, DISPLAY_MODE_SUMMARY), )``,
+                    force rendering it as a table.
 
-        :display_mode: override the table's :attr:`display_mode_main
-                       <lino.core.tables.AbstractTable.display_mode_main>`.
+        :display_mode: override the table's :attr:`display_mode
+                       <lino.core.tables.AbstractTable.display_mode>`.
 
                        Unlike `nosummary` this can be used to ask a summary for
                        a table that would not show as summary by default.
                        Instead of saying `nosummary=True` you can say
-                       `display_mode="grid"` or `display_mode="html"` (The
-                       display modes "grid" and "html" have the same result in a
-                       printed document or in a tested spec).
+                       `display_mode=((None, DISPLAY_MODE_TABLE), )` or
+                       `display_mode=((None, DISPLAY_MODE_HTML), )` (The
+                       display modes DISPLAY_MODE_TABLE and DISPLAY_MODE_HTML
+                       have the same result in a printed document or in a
+                       tested spec).
 
         :header_level: show also the table header (using specified
                        level)
@@ -941,6 +940,7 @@ class BaseRequest(object):
           {{ar.show('users.UsersOverview')}}
         """
         from lino.utils.report import Report
+        from lino.utils.report import EmptyTable
         # from lino.core.actors import Actor
 
         if master_instance is not None:
@@ -963,6 +963,9 @@ class BaseRequest(object):
                 return ar.renderer.show_story(
                     self, story, header_level=header_level,
                     header_links=header_links, stripped=stripped)
+            elif issubclass(ar.actor, EmptyTable):
+                # e.g. rt.show('system.Dashboard')  20210910
+                return ar.renderer.show_detail(ar, None)
             elif isinstance(ar.bound_action.action, actions.ShowTable):
                 return ar.renderer.show_table(
                     ar, column_names=column_names, header_level=header_level,
@@ -973,8 +976,8 @@ class BaseRequest(object):
                 if len(ar.selected_rows) > 0:
                     obj = ar.selected_rows[0]
                 else:
-                    obj = None
-                    # e.g. rt.show('system.Dashboard')  20210910
+                    obj = ar.actor.get_request_queryset().first()
+                    # e.g. rt.show('system.SiteConfigs')  20220801
                 return ar.renderer.show_detail(ar, obj)
             else:
                 print("Cannot show", ar.bound_action.action)
@@ -1046,8 +1049,12 @@ class BaseRequest(object):
             return True
         return False
 
+    def obj2url(self, *args, **kwargs):
+        """Return a url that points to the given database object.
+        """
+        return self.renderer.obj2url(self, *args, **kwargs)
 
-    def obj2html(self, obj, *args, **kwargs):
+    def obj2html(self, obj, text=None, **kwargs):
         """
         Return a HTML element that represents a pointer to a detail view of the given
         database object. Depending on the renderer this will be more
@@ -1055,16 +1062,43 @@ class BaseRequest(object):
         """
         if obj is None:
             return ''
-        return self.renderer.obj2html(self, obj, *args, **kwargs)
+        return self.renderer.obj2html(self, obj, text, **kwargs)
 
-    def obj2str(self, *args, **kwargs):
-        """Return a string with a pointer to the given object.
+    def obj2htmls(self, *args, **kwargs):
         """
-        return self.renderer.obj2str(self, *args, **kwargs)
+        Return a safe html fragment that points to the given database object.
+        """
+        return self.renderer.obj2htmls(self, *args, **kwargs)
+
+    def add_detail_link(self, obj, txt):
+        """
+        Adds a detail link when there is a detail view and when the text does
+        not yet contain html.
+
+        This is rather for internal use to make the items in `DISPLAY_MODE_LIST`
+        clickable when needed.
+
+        Compare the following use cases:
+
+        :class:`lino.modlib.users.UsersOverview`,
+        :class:`lino_xl.lib.working.WorkedHours`,
+        :class:`lino_xl.lib.contacts.RolesByCompany` and :class:`lino_xl.lib.contacts.RolesByPerson`
+
+        """
+        # print("20230303", txt)
+        if txt.startswith("<"):
+            return txt
+        url = self.obj2url(obj)
+        if url is not None:
+            url = html.escape(url)
+            # par += ' <a href="{}">(Detail)</a>'.format(url)
+            return '<a href="{}">{}</a>'.format(url, txt)
+        # a funny way to debug:
+        # return '<a href="{}">{}</a>'.format(str(sar.renderer), txt)
+        return txt
+
 
     def html_text(self, *args, **kwargs):
-        """
-        """
         return self.renderer.html_text(*args, **kwargs)
 
     def href_button(self, *args, **kwargs):
@@ -1192,8 +1226,7 @@ class BaseRequest(object):
         """
         Returns a dict of this record, designed for usage by an InsertWindow.
         """
-        lh = ah.actor.insert_layout.get_layout_handle(
-            settings.SITE.kernel.default_ui)
+        lh = ah.actor.insert_layout.get_layout_handle()
         fields = [df._lino_atomizer for df in lh._data_elems]
         if ah.store._disabled_fields_storefield is not None:
             fields.append(ah.store._disabled_fields_storefield)
@@ -1323,9 +1356,7 @@ class ActorRequest(BaseRequest):
         # the toolbar
         if self.actor.no_phantom_row:
             return
-        # if self.actor.insert_layout is not None \
-        #    and not self.actor.stay_in_grid \
-        #    and not self.actor.force_phantom_row:
+        # if self.actor.insert_layout is not None: #  and not self.actor.stay_in_grid \
         #     return
         if self.create_kw is None or self.actor.hide_editing(self.get_user().user_type) \
                 or not self.actor.allow_create:
@@ -1569,8 +1600,7 @@ class ActionRequest(ActorRequest):
                 elif request is not None:
                     # call get_layout_handle to make sure that
                     # params_store has been created:
-                    self.actor.params_layout.get_layout_handle(
-                        self.renderer.front_end)
+                    self.actor.params_layout.get_layout_handle()
                     ps = self.actor.params_layout.params_store
                     # print('20160329 requests.py', ps, self.actor.parameters)
                     if ps is not None:
