@@ -125,7 +125,6 @@ class StoreField(object):
     def full_value_from_object(self, obj, ar=None):
         return self.field.value_from_object(obj)
 
-
     def value2list(self, ar, v, l, row):
         return l.append(v)
 
@@ -536,8 +535,7 @@ class RequestStoreField(StoreField):
 class PasswordStoreField(StoreField):
 
     def value_from_object(self, obj, request=None):
-        v = super(PasswordStoreField, self).value_from_object(
-            obj, request)
+        v = super().value_from_object(obj, request)
         if v:
             return "*" * len(v)
         return v
@@ -678,7 +676,7 @@ class DisableEditingStoreField(SpecialStoreField):
 
 class BooleanStoreField(StoreField):
     """A :class:`StoreField` for
-    `BooleanField <https://docs.djangoproject.com/en/3.1/ref/models/fields/#booleanfield>`__.
+    `BooleanField <https://docs.djangoproject.com/en/4.1/ref/models/fields/#booleanfield>`__.
 
     """
 
@@ -705,6 +703,10 @@ class BooleanStoreField(StoreField):
         return force_str(iif(v, _("Yes"), _("No")))
 
 
+# class SlaveTableStoreField(StoreField):
+#     def full_value_from_object(self, obj, ar=None):
+#         return DelayedValue(self.field, str(self.field), obj)
+
 class DisplayStoreField(StoreField):
     pass
 
@@ -784,7 +786,7 @@ class IntegerStoreField(StoreField):
 class AutoStoreField(StoreField):
 
     """A :class:`StoreField` for
-    `AutoField <https://docs.djangoproject.com/en/3.1/ref/models/fields/#autofield>`__
+    `AutoField <https://docs.djangoproject.com/en/4.1/ref/models/fields/#autofield>`__
 
     """
 
@@ -939,9 +941,10 @@ def get_atomizer(holder, fld, name):
 def create_atomizer(holder, fld, name):
     """
     The holder is where the (potential) choices come from. It can be
-    a model, an actor or an action.
+    a model, an actor or an action. `fld` is a data element.
     """
     if name is None:
+        # print("20181023 create_atomizer() no name {}".format(fld))
         return
         # raise Exception("20181023 create_atomizer() {}".format(fld))
     if isinstance(fld, fields.RemoteField):
@@ -984,9 +987,15 @@ def create_atomizer(holder, fld, name):
     if isinstance(fld, fields.RequestField):
         delegate = create_atomizer(holder, fld.return_type, fld.name)
         return RequestStoreField(fld, delegate, name)
+    if isinstance(fld, type) and issubclass(fld, actors.Actor):
+        return
     # if isinstance(fld, type) and issubclass(fld, actors.Actor):
-    #     # 20210618
+    #     raise Exception("20230219")
+    #     # 20210618 & 20230218
+    #     if settings.SITE.kernel.default_ui.support_async:
+    #         return SlaveTableStoreField(fld, name)
     #     return DisplayStoreField(fld, name)
+
     if isinstance(fld, fields.VirtualField):
         delegate = create_atomizer(holder, fld.return_type, fld.name)
         if delegate is None:
@@ -1184,26 +1193,26 @@ class Store(BaseStore):
 
         form = rh.actor.detail_layout
         if form:
-            dh = form.get_layout_handle(settings.SITE.kernel.default_ui)
+            dh = form.get_layout_handle()
             self.collect_fields(self.detail_fields, dh)
 
         for form in rh.actor.extra_layouts.values():
-            dh = form.get_layout_handle(settings.SITE.kernel.default_ui)
+            dh = form.get_layout_handle()
             self.collect_fields(self.detail_fields, dh)
 
         form = rh.actor.insert_layout
         if form:
-            dh = form.get_layout_handle(settings.SITE.kernel.default_ui)
+            dh = form.get_layout_handle()
             self.collect_fields(self.detail_fields, dh)
 
         form = rh.actor.card_layout
         if form:
-            dh = form.get_layout_handle(settings.SITE.kernel.default_ui)
+            dh = form.get_layout_handle()
             self.collect_fields(self.card_fields, dh)
 
-        form = rh.actor.item_layout
+        form = rh.actor.list_layout
         if form:
-            dh = form.get_layout_handle(settings.SITE.kernel.default_ui)
+            dh = form.get_layout_handle()
             self.collect_fields(self.item_fields, dh)
 
         if self.pk is not None:
