@@ -410,6 +410,16 @@ class TableRequest(ActionRequest):
     def summary_row(self, obj, **kwargs):
         return self.actor.summary_row(self, obj, **kwargs)
 
+    def row_as_page(self, row, **kwargs):
+        return self.actor.row_as_page(self, row, **kwargs)
+
+    def row_as_paragraph(self, row, **kwargs):
+        """Return a HTML string that represents the given row as a list item.
+
+        See :ref:`dev.as_paragraph`.
+        """
+        return self.actor.row_as_paragraph(self, row, **kwargs)
+
     def to_rst(self, *args, **kw):
         """Returns a string representing this table request in
         reStructuredText markup.
@@ -563,7 +573,7 @@ class TableRequest(ActionRequest):
             else:
                 if column_names:
                     ll = ColumnsLayout(column_names, datasource=ar.actor)
-                    lh = ll.get_layout_handle(settings.SITE.kernel.default_ui)
+                    lh = ll.get_layout_handle()
                     columns = lh.main.columns
                     columns = [e for e in columns if not e.hidden]
                 else:
