@@ -20,7 +20,6 @@ from lino.core import actors
 from lino.core import actions
 from lino.core import fields
 from lino.core import constants
-from lino.core.classproperty import classproperty
 from lino.core.utils import resolve_fields_list
 from lino.core.tablerequest import TableRequest
 
@@ -321,28 +320,36 @@ class AbstractTable(actors.Actor):
     Usually such a warning means that there is something wrong.
     """
 
-    display_mode_main = constants.DISPLAY_MODE_TABLE
+    display_mode = (
+        (70, constants.DISPLAY_MODE_LIST),
+        (None, constants.DISPLAY_MODE_TABLE),
+    )
     """
-    The default display_mode when the Table is the `main` layout element.
+    A tuple of `(width, display_mode)` items used to select a :term:`display
+    mode` depending on the available width (in characters) on the client.
+
+    The last item should have a width of `None`.
+
+    See also :meth:`get_display_mode` and :ref:`dev.format`.
     """
 
-    _display_mode_slave = None
-
-    @classproperty
-    def display_mode_slave(cls):
+    @classmethod
+    def get_display_mode(cls, available_width=None):
+        """Given the available width, return the :term:`display mode` to use.
         """
+        current_choice = (0, None)
+        for dmi in cls.display_mode:
+            if available_width is not None:
+                if dmi[0] is None and current_choice[0] == 0:
+                    current_choice = (0, dmi[1])
+                elif available_width > dmi[0] > current_choice[0]:
+                    current_choice = dmi
+            elif dmi[0] is None:
+                return dmi[1]
+        return current_choice[1]
 
-        The display_mode when the Table is something other then the `main`
-        layout element.
 
-        """
-        if cls._display_mode_slave is None:
-            return cls.display_mode_main
-        return cls._display_mode_slave
 
-    @display_mode_slave.setter
-    def display_mode_slave(cls, value):
-        cls._display_mode_slave = value
 
     max_render_depth = 2
     """
@@ -367,22 +374,22 @@ class AbstractTable(actors.Actor):
     """
 
     no_phantom_row = False
-    """Suppress a phantom row in situations where Lino would otherwise add
+    """Suppress a :term:`phantom row` in situations where Lino would otherwise add
     one.
 
-    Used for :class:`lino_xl.lib.ledger.ByJournal` where a phantom row
-    is disturbing.
+    The phantom row can disturb for example when users want to see the number of
+    existing entries.  End users can double-click on the phantom row to open an
+    insert window and create a new item.
 
-    TODO: Actually this option would not be necessary if the AJAX call
-    sent by a grid panel would include an option which says whether it
-    is main item or not.
+    Used for :class:`lino_xl.lib.ledger.ByJournal` where a phantom row
+    is disturbing and not needed.
 
     """
 
     order_by = None
-    """If specified, this must be a tuple or list of field names which
+    """If specified, this must be a tuple or list of field names that
 will be passed to Django's `order_by
-<https://docs.djangoproject.com/en/1.11/ref/models/querysets/#order-by>`__
+<https://docs.djangoproject.com/en/4.1/ref/models/querysets/#order-by>`__
 method in order to sort the rows of the queryset.
 
     """
@@ -391,7 +398,7 @@ method in order to sort the rows of the queryset.
     """If specified, this must be a `models.Q` object (not a dict of
     (fieldname -> value) pairs) which will be passed to Django's
     `filter
-    <https://docs.djangoproject.com/en/1.11/ref/models/querysets/#filter>`__
+    <https://docs.djangoproject.com/en/4.1/ref/models/querysets/#filter>`__
     method.
 
     Note that if you allow a user to insert rows into a filtered
@@ -407,14 +414,14 @@ method in order to sort the rows of the queryset.
     One advantage of :attr:`filter` over
     :attr:`known_values  <lino.core.actors.Actor.known_values>`
     is that this can use the full range of Django's `field lookup methods
-    <https://docs.djangoproject.com/en/1.11/topics/db/queries/#field-lookups>`_
+    <https://docs.djangoproject.com/en/4.1/topics/db/queries/#field-lookups>`_
 
     """
 
     exclude = None
     """If specified, this must be dict which will be passed to Django's
     `exclude
-    <https://docs.djangoproject.com/en/1.11/ref/models/querysets/#exclude>`__
+    <https://docs.djangoproject.com/en/4.1/ref/models/querysets/#exclude>`__
     method on the queryset.
 
     """
@@ -505,6 +512,21 @@ method in order to sort the rows of the queryset.
     def get_default_action(cls):
         return actions.ShowTable()
 
+    @classmethod
+    def row_as_paragraph(cls, ar, row):
+        """Return a HTML string that represents the given row as a list item.
+
+        See :ref:`dev.as_paragraph`.
+        """
+        return row.as_paragraph(ar)
+
+    @classmethod
+    def row_as_page(cls, ar, row):
+        """Yield a series HTML strings that represent the given row as a plain page.
+
+        """
+        return row.as_page(ar)
+
     @classmethod
     def get_actor_editable(self):
         if self._editable is None:
