@@ -68,7 +68,7 @@ def getrqdata(request):
     """Return the request data.
 
     Unlike the now defunct `REQUEST
-    <https://docs.djangoproject.com/en/1.11/ref/request-response/#django.http.HttpRequest.REQUEST>`_
+    <https://docs.djangoproject.com/en/4.1/ref/request-response/#django.http.HttpRequest.REQUEST>`_
     attribute, this inspects the request's `method` in order to decide
     what to return.
 
@@ -122,13 +122,13 @@ def is_devserver():
 
     """
     #~ print 20130315, sys.argv[1]
-    if sys.argv[0] == 'daphne':
-       return True
     if len(sys.argv) <= 1:
         return False
+    # if sys.argv[0] == 'daphne':
+    #    return True
     if sys.argv[0].endswith("doctest.py") or sys.argv[0].endswith("doctest_utf8.py"):
         return True
-    if sys.argv[1] in ('runserver', 'testserver', 'test', "makescreenshots"):
+    if sys.argv[1] in ('runserver', 'testserver', 'test', "makescreenshots", 'shell'):
         return True
     return False
 
@@ -491,7 +491,6 @@ def resolve_field(name, app_label=None):
     raise FieldDoesNotExist(name)
     # return UnresolvedField(name)
 
-
 def navinfo(qs, elem, limit=None):
     """Return a dict with navigation information for the given model
     instance `elem` within the given queryset.
@@ -789,7 +788,7 @@ def class_dict_items(cl, exclude=None):
 
 def dbfield2params_field(db_field):
 
-    """originally just for setting up actor parameters from get_simple_params()
+    """originally just for setting up actor parameters from get_simple_parameters()
     but also used in calview."""
 
     fld = copy.copy(db_field)
