@@ -33,14 +33,14 @@ class Command(Command):
             dest='skip_help', help="Do NOT build local help pages.")
 
     def handle(self, **options):
-        
+
         if not options['skip_collect']:
             super(Command, self).handle(**options)
             # self.collect_static.handle(**options)
 
         if not options['skip_cache']:
-            settings.SITE.kernel.default_ui.renderer.build_site_cache(
-                force=True, from_commandline=True)
+            # settings.SITE.kernel.default_ui.renderer.build_site_cache(force=True)
+            settings.SITE.build_site_cache(force=True)
 
         if not options['skip_help']:
             if settings.SITE.is_installed('help'):
