@@ -1,6 +1,6 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2013-2021 by Rumma & Ko Ltd.
-# License: BSD, see file LICENSE for more details.
+# Copyright 2013-2023 by Rumma & Ko Ltd.
+# License: GNU Affero General Public License v3 (see file COPYING for details)
 
 from io import open
 import logging ; logger = logging.getLogger(__name__)
@@ -113,9 +113,12 @@ class Command(BaseCommand):
         parser.add_argument('--noinput', action='store_false',
                             dest='interactive', default=True,
                             help='Do not prompt for input of any kind.')
-        parser.add_argument('--tolerate', action='store_true',
+        parser.add_argument('-t', '--tolerate', action='store_true',
                             dest='tolerate', default=False,
                             help='Tolerate database errors.')
+        parser.add_argument('-s', '--simulate', action='store_true',
+                            dest='simulate', default=False,
+                            help="Just simulate, don't actually write any data.")
         parser.add_argument('-o', '--overwrite', action='store_true',
                             dest='overwrite', default=False,
                             help='Overwrite existing files.')
@@ -195,17 +198,26 @@ def bv2kw(fieldname, values):
     return settings.SITE.babelkw(fieldname, %s)
 
 ''' % s)
-        self.models = sorted_models_list()
+        skip_models = {
+            'contenttypes.ContentType', 'sessions.Session', 'checkdata.Message'
+        }
+        self.models = [m for m in sorted_models_list()
+           if full_model_name(m) not in skip_models]
 
-        if settings.SITE.is_installed('contenttypes'):
-            from django.contrib.contenttypes.models import ContentType
-            self.models = [m for m in self.models
-                           if not issubclass(m, ContentType)]
-
-        if settings.SITE.is_installed('sessions'):
-            from django.contrib.sessions.models import Session
-            self.models = [m for m in self.models
-                           if not issubclass(m, Session)]
+        # if settings.SITE.is_installed('contenttypes'):
+        #     from django.contrib.contenttypes.models import ContentType
+        #     self.models = [m for m in self.models
+        #                    if not issubclass(m, ContentType)]
+        #
+        # if settings.SITE.is_installed('sessions'):
+        #     from django.contrib.sessions.models import Session
+        #     self.models = [m for m in self.models
+        #                    if not issubclass(m, Session)]
+        #
+        # if settings.SITE.is_installed('checkdata'):
+        #     from django.contrib.sessions.models import Session
+        #     M = settings.SITE.models.checkdata.Message
+        #     self.models = [m for m in self.models if not issubclass(m, M)]
 
         for model in self.models:
             self.stream.write('%s = resolve_model("%s")\n' % (
@@ -283,12 +295,17 @@ def main(args):
                 stream.write(
                     "# fields: %s\n" % ', '.join(
                         [f.name for f in fields]))
-                for obj in qs:
-                    self.count_objects += 1
-                    #~ used_models.add(model)
-                    stream.write('loader.save(create_%s(%s))\n' % (
-                        obj._meta.db_table,
-                        ','.join([self.value2string(obj, f) for f in fields])))
+                if self.options['simulate']:
+                    msg = ("The data of table {} has not been dumped because "
+                       "--simulate was specified.").format(model._meta.db_table)
+                    stream.write('raise Exception("{0}")\n'.format(msg))
+                else:
+                    for obj in qs:
+                        self.count_objects += 1
+                        #~ used_models.add(model)
+                        stream.write('loader.save(create_%s(%s))\n' % (
+                            obj._meta.db_table,
+                            ','.join([self.value2string(obj, f) for f in fields])))
                 stream.write('\n')
                 if i == len(chunks):
                     stream.write('loader.flush_deferred_objects()\n')
