@@ -125,7 +125,7 @@ Are you sure (y/n) ?""" % dbname):
             conn = connections[using]
             cursor = conn.cursor()
             cursor.execute("set foreign_key_checks=0;")
-        elif engine == 'django.db.backends.postgresql':
+        elif engine.startswith('django.db.backends.postgresql'):
             foralltables(using, "DROP TABLE IF EXISTS {} CASCADE;")
             # cmd = """select 'DROP TABLE "' || tablename || '" IF EXISTS CASCADE;' from pg_tables where schemaname = 'public';"""
             # cursor.execute(cmd)
@@ -178,14 +178,19 @@ Are you sure (y/n) ?""" % dbname):
 
         settings.SITE._site_config = None  # clear cached instance
 
-        if engine == 'django.db.backends.postgresql':
+        if engine.startswith('django.db.backends.postgresql'):
             # a first time to create tables of contenttypes. At
             # least on PostgreSQL this is required because for
             # some reason the syncdb fails when contenttypes is
             # not initialized.
             call_command('migrate', **options)
             for p in settings.SITE.installed_plugins:
-                if p.app_name.startswith('lino'):
+                makemigrations = False
+                for prefix in settings.SITE.postgres_migratable_plugin_prefixes:
+                    if p.app_name.startswith(prefix):
+                        makemigrations = True
+                        break
+                if p.app_name.startswith('lino') or makemigrations:
                     migrations_dir = Path(p.app_module.__file__).parent / 'migrations'
                     # if not migrations_dir.exists():
                     os.mkdir(migrations_dir)
@@ -197,9 +202,14 @@ Are you sure (y/n) ?""" % dbname):
             call_command('makemigrations', interactive=False, verbosity=0)
         call_command('migrate', '--run-syncdb', **options)
 
-        if engine == 'django.db.backends.postgresql':
+        if engine.startswith('django.db.backends.postgresql'):
             for p in settings.SITE.installed_plugins:
-                if p.app_name.startswith('lino'):
+                rm_mig_dir = False
+                for prefix in settings.SITE.postgres_migratable_plugin_prefixes:
+                    if p.app_name.startswith(prefix):
+                        rm_mig_dir = True
+                        break
+                if p.app_name.startswith('lino') or rm_mig_dir:
                     migrations_dir = Path(p.app_module.__file__).parent / 'migrations'
                     if migrations_dir.exists():
                         shutil.rmtree(migrations_dir)
