@@ -190,7 +190,7 @@ class Command(BaseCommand):
     def main(self, force=False, **kw):
         settings.SITE.startup()
 
-        outputbase = os.path.join(settings.SITE.site_cache_root, 'cache', 'screenshots')
+        outputbase = os.path.join(settings.SITE.media_root, 'cache', 'screenshots')
 
         urlbase = "http://" + ADDR + ":" + str(PORT)
         #~ urlbase="http://127.0.0.1:8000"
