@@ -1,5 +1,5 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2013-2021 Rumma & Ko Ltd
+# Copyright 2013-2022 Rumma & Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
 
 from django.core.management import call_command
@@ -20,10 +20,15 @@ class Command(BaseCommand):
 
         if settings.SITE.readonly:
             settings.SITE.logger.info(
-                "Skipped `initdb` on readonly site '%s'.",
+                "No need to `prep` readonly site '%s'.",
                 settings.SETTINGS_MODULE)
             return
 
+        if settings.SITE.master_site:
+            settings.SITE.logger.info(
+                "No need to `prep` slave site '%s'.", settings.SETTINGS_MODULE)
+            return
+
         args = settings.SITE.demo_fixtures
         if isinstance(args, str):
             args = args.split()
@@ -32,5 +37,6 @@ class Command(BaseCommand):
         if settings.SITE.is_installed('search') and settings.SITE.use_elasticsearch:
             call_command('createindexes', '-i')
 
-        # super(Command, self).handle(*args, **options)
-        super(Command, self).handle(**options)
+        super().handle(**options)
+
+        settings.SITE.kernel.mark_virgin()
