@@ -1,6 +1,6 @@
 # -*- coding: UTF-8 -*-
 # Copyright 2012-2021 Rumma & Ko Ltd
-# License: BSD, see LICENSE for more details.
+# License: GNU Affero General Public License v3 (see file COPYING for details)
 
 from past.builtins import execfile
 
@@ -14,7 +14,7 @@ class Command(BaseCommand):
 
     help = """Run a Python script within the Django environment for this site."""
 
-    requires_system_checks = False
+    requires_system_checks = []
 
     def add_arguments(self, parser):
         parser.add_argument('filename', nargs=argparse.REMAINDER,
