@@ -93,7 +93,7 @@ class Modified(model.Model):
     def save(self, *args, **kwargs):
         if self.auto_touch and not settings.SITE.loading_from_dump:
             self.touch()
-        super(Modified, self).save(*args, **kwargs)
+        super().save(*args, **kwargs)
 
     def touch(self):
         self.modified = timezone.now()
@@ -123,7 +123,7 @@ class Created(model.Model):
     def save(self, *args, **kwargs):
         if self.created is None and not settings.SITE.loading_from_dump:
             self.created = timezone.now()
-        super(Created, self).save(*args, **kwargs)
+        super().save(*args, **kwargs)
 
 
 class CreatedModified(Created, Modified):
@@ -246,7 +246,7 @@ class Story(model.Model):
 
 class DragAndDrop(actions.Action):
     select_rows = True
-    show_in_bbar = False
+    show_in_toolbar = False
 
     def run_from_ui(self, ar, **kw):
         obj = ar.selected_rows[0]
