@@ -32,7 +32,6 @@ def rangefmt(r):
     return fds(r[0]) + '...' + fds(r[1])
 
 
-
 class CombinedDateTime(dd.Model):
     """
     Mixin for models which have at least one couple of date and time
@@ -279,7 +278,7 @@ class ObservedDateRange(ParameterPanel):
                 default=self.get_default_end_date,
                 help_text=_("End of observed date range")),
         )
-        super(ObservedDateRange, self).__init__(**kwargs)
+        super().__init__(**kwargs)
 
     @classmethod
     def param_defaults(cls, ar, **kw):
@@ -287,7 +286,7 @@ class ObservedDateRange(ParameterPanel):
         # using Monthly or Yearly as the parameter panel of an action. Doesn't
         # work in extjs because action parameters don't use their default
         # values.
-        kw = super(ObservedDateRange, cls).param_defaults(ar, **kw)
+        kw = super().param_defaults(ar, **kw)
         kw.update(start_date=cls.get_default_start_date())
         kw.update(end_date=cls.get_default_end_date())
         return kw
