@@ -1,6 +1,6 @@
 # -*- coding: UTF-8 -*-
 # Copyright 2009-2017 Rumma & Ko Ltd
-# License: BSD (see file COPYING for details)
+# License: GNU Affero General Public License v3 (see file COPYING for details)
 
 """Defines the :class:`Polymorphic` model mixin.
 See :doc:`/dev/mti`.
@@ -10,7 +10,7 @@ from builtins import object
 from builtins import str
 
 from django.core.exceptions import ObjectDoesNotExist
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 from etgen.html import E
 
 from lino.core import fields
@@ -25,7 +25,7 @@ from lino.utils import mti
 class ChildAction(Action):
 
     readonly = False
-    show_in_bbar = False
+    show_in_toolbar = False
 
     def __init__(self, child_model, *args, **kw):
         self.child_model = child_model
