@@ -45,7 +45,7 @@ class MoveByN(actions.Action):
     # icon_name = 'arrow_up'
     #~ icon_file = 'arrow_up.png'
     readonly = False
-    show_in_bbar = False
+    show_in_toolbar = False
 
     def get_action_permission(self, ar, obj, state):
         if ar.data_iterator is None:
@@ -498,7 +498,7 @@ class Hierarchical(Duplicable):
                         et.append(ar.goto_pk(c.id, get_text(c)))
                 i -= 1
             if child == self:
-                sar = ar.actor.request_from(ar, master_instance=self, is_on_main_actor=False)
+                sar = ar.actor.request(parent=ar, master_instance=self, is_on_main_actor=False)
                 # sar = ar.spawn_request(master_instance=self, is_on_main_actor=False)
                 if ar.actor.insert_action is not None:
                     ir = ar.actor.insert_action.request_from(sar)
