@@ -50,6 +50,8 @@ class About(EmptyTable):
 
     @dd.constant()
     def about_html(cls):
+    # @dd.htmlbox()
+    # def about_html(cls, obj, ar=None):
 
         body = []
 
@@ -106,7 +108,7 @@ class About(EmptyTable):
             packages.add(p.app_name.split('.')[0])
         for src in packages:
             label = src
-            value = codetime('%s.*' % src)
+            value = codetime(src)
             if value is not None:
                 times.append((label, value))
 
