@@ -119,7 +119,7 @@ def table2html(ar, as_main=True):
                         E.span(**{'class':"glyphicon glyphicon-folder-open"}),
                         href=url, style="margin-left: 4px;",
                         **{'class':"btn btn-default pull-right"}),
-                    E.h5(ar.get_title(), style="display: inline-block;"),
+                    E.h5(str(ar.get_title()), style="display: inline-block;"),
                     **{'class': "panel-title"}),
                 **{'class':"panel-heading"}),
                 t.as_element(),
@@ -163,7 +163,7 @@ def layout2html(ar, elem):
 
     wl = ar.bound_action.get_window_layout()
     #~ print 20120901, wl.main
-    lh = wl.get_layout_handle(settings.SITE.kernel.default_ui)
+    lh = wl.get_layout_handle()
 
     items = list(lh.main.as_plain_html(ar, elem))
     # if navigator:
