@@ -21,7 +21,8 @@ class Plugin(ad.Plugin):
     needs_plugins = [
         'lino.modlib.users', 'lino.modlib.gfks']
 
-    remove_after = 6*30
+    remove_after = None
+    # remove_after = 6*30
 
 
     def setup_explorer_menu(config, site, user_type, m):
