@@ -262,7 +262,7 @@ def on_delete(sender=None, request=None, **kw):
 
 
 @receiver(on_ui_created)
-def on_create(sender=None, request=None, **kw):
+def on_ui_created(sender=None, request=None, **kw):
     """To be called when a new instance has actually been created and
     saved.
 
