@@ -34,8 +34,8 @@ class Plugin(ad.Plugin):
     media_name = 'js'
 
     def on_init(self):
-        if not self.site.plugins.notify.use_websockets:
-            raise Warning("Chat requires use_websockets = True")
+        if not self.site.use_linod:
+            raise Warning("Chat requires use_linod = True")
 
     # def get_requirements(self, site):
     #     # handled by modlib.notify
@@ -65,7 +65,7 @@ class Plugin(ad.Plugin):
 
     def get_head_lines(self, site, request):
         """Adds a JS constant to let react know we want to include WS chat info"""
-        if not self.site.plugins.notify.use_websockets:
+        if not self.site.use_linod:
             yield ""
         # from lino.utils.jsgen import py2js
         else :
