@@ -1,10 +1,10 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2015-2020 Rumma & Ko Ltd
-# License: BSD (see file COPYING for details)
+# Copyright 2015-2022 Rumma & Ko Ltd
+# License: GNU Affero General Public License v3 (see file COPYING for details)
 
-"""Adds functionality for handling data problems.
+"""Adds functionality for handling checkdata messages.
 
-See :doc:`/specs/checkdata`.
+See :doc:`/plugins/checkdata`.
 
 .. autosummary::
    :toctree:
@@ -25,10 +25,10 @@ class Plugin(ad.Plugin):
 
         The :attr:`username <lino.modlib.users.User.username>`
         of the **main checkdata responsible**, i.e. a designated
-        user who will be attributed to data problems for which
+        user who will be attributed to checkdata messages for which
         no *specific responible* could be designated (returned by the
         checker's :meth:`get_responsible_user
-        <lino.modlib.checkdata.choicelists.Checker.get_responsible_user>`
+        <lino.modlib.checkdata.Checker.get_responsible_user>`
         method).
 
         The default value for this is `None`, except on a demo site
@@ -74,13 +74,13 @@ class Plugin(ad.Plugin):
     def setup_main_menu(self, site, user_type, m):
         g = site.plugins.office
         m = m.add_menu(g.app_label, g.verbose_name)
-        m.add_action('checkdata.MyProblems')
+        m.add_action('checkdata.MyMessages')
 
     def setup_explorer_menu(config, site, user_type, m):
         g = site.plugins.system
         m = m.add_menu(g.app_label, g.verbose_name)
         m.add_action('checkdata.Checkers')
-        m.add_action('checkdata.AllProblems')
+        m.add_action('checkdata.AllMessages')
         # m.add_action('checkdata.Severities')
         # m.add_action('checkdata.Feedbacks')
 
