@@ -61,7 +61,7 @@ class Checker(dd.Choice):
         assert cls.self.model is None
         cls.self.update_problems(**kwargs)
         todo, done = cls.self.update_problems(**kwargs)
-        msg = "Found {0} and fixed {1} data problems for {2}."
+        msg = "Found {0} and fixed {1} checkdata messages for {2}."
         dd.logger.info(msg.format(len(todo), len(done), cls.self))
 
     @classmethod
@@ -78,17 +78,17 @@ class Checker(dd.Choice):
             self.model = dd.resolve_model(self.model, strict=True)
 
     def update_problems(self, obj=None, delete=True, fix=False):
-        Problem = rt.models.checkdata.Problem
+        Message = rt.models.checkdata.Message
         if delete:
             # if obj is None:
             #     flt = {
-            #         Problem.owner.ct_field.name + "__isnull": True,
-            #         Problem.owner.fk_field.name + "__isnull": True
+            #         Message.owner.ct_field.name + "__isnull": True,
+            #         Message.owner.fk_field.name + "__isnull": True
             #     }
             # else:
-            #     flt = gfk2lookup(Problem.owner, obj, checker=self)
-            flt = gfk2lookup(Problem.owner, obj, checker=self)
-            qs = Problem.objects.filter(**flt)
+            #     flt = gfk2lookup(Message.owner, obj, checker=self)
+            flt = gfk2lookup(Message.owner, obj, checker=self)
+            qs = Message.objects.filter(**flt)
             qs.delete()
 
         done = []
@@ -112,12 +112,12 @@ class Checker(dd.Choice):
             with translation.override(lang):
                 if obj is None:
                     for msg in todo:
-                        prb = Problem(message=str(msg), checker=self, user=user)
+                        prb = Message(message=str(msg), checker=self, user=user)
                         prb.full_clean()
                         prb.save()
                 else:
                     msg = '\n'.join([str(s) for s in todo])
-                    prb = Problem(owner=obj, message=msg, checker=self, user=user)
+                    prb = Message(owner=obj, message=msg, checker=self, user=user)
                     prb.full_clean()
                     prb.save()
         return (todo, done)
@@ -141,7 +141,7 @@ class Checkers(dd.ChoiceList):
 
     detail_layout = """
     value text
-    checkdata.ProblemsByChecker
+    checkdata.MessagesByChecker
     """
 
 
