@@ -18,9 +18,9 @@ from lino.api import dd, rt, _
 from .choicelists import Checker, Checkers
 
 from .roles import CheckdataUser
+from lino.core import constants
 
-
-class UpdateProblem(dd.Action):
+class UpdateMessage(dd.Action):
     icon_name = 'bell'
     ui5_icon_name = "sap-icon://bell"
     label = _("Check data")
@@ -34,10 +34,10 @@ class UpdateProblem(dd.Action):
     def run_from_ui(self, ar, fix=None):
         if fix is None:
             fix = self.fix_them
-        Problem = rt.models.checkdata.Problem
+        Message = rt.models.checkdata.Message
         # print(20150327, ar.selected_rows)
         for obj in ar.selected_rows:
-            assert isinstance(obj, Problem)
+            assert isinstance(obj, Message)
             chk = obj.checker
             owner = obj.owner
             if owner is None:
@@ -45,20 +45,20 @@ class UpdateProblem(dd.Action):
                 # has been deleted.
                 obj.delete()
             else:
-                qs = Problem.objects.filter(
-                    **gfk2lookup(Problem.owner, owner, checker=chk))
+                qs = Message.objects.filter(
+                    **gfk2lookup(Message.owner, owner, checker=chk))
                 qs.delete()
                 chk.update_problems(owner, False, fix)
         ar.set_response(refresh_all=True)
 
 
-class FixProblem(UpdateProblem):
+class FixProblem(UpdateMessage):
     label = _("Fix data problems")
     fix_them = True
     sort_index = 91
 
 
-class UpdateProblemsByController(dd.Action):
+class UpdateMessagesByController(dd.Action):
     icon_name = 'bell'
     ui5_icon_name = "sap-icon://bell"
     label = _("Check data")
@@ -68,33 +68,33 @@ class UpdateProblemsByController(dd.Action):
 
     def __init__(self, model):
         self.model = model
-        super(UpdateProblemsByController, self).__init__()
+        super(UpdateMessagesByController, self).__init__()
 
     def run_from_ui(self, ar, fix=None):
         if fix is None:
             fix = self.fix_them
-        Problem = rt.models.checkdata.Problem
-        gfk = Problem.owner
+        Message = rt.models.checkdata.Message
+        gfk = Message.owner
         checkers = get_checkers_for(self.model)
         for obj in ar.selected_rows:
             assert isinstance(obj, self.model)
-            qs = Problem.objects.filter(**gfk2lookup(gfk, obj))
+            qs = Message.objects.filter(**gfk2lookup(gfk, obj))
             qs.delete()
             for chk in checkers:
                 chk.update_problems(obj, False, fix)
         ar.set_response(refresh=True)
 
 
-class FixProblemsByController(UpdateProblemsByController):
+class FixMessagesByController(UpdateMessagesByController):
     label = _("Fix data problems")
     fix_them = True
 
 
-class Problem(Controllable, UserAuthored):
+class Message(Controllable, UserAuthored):
     class Meta(object):
         app_label = 'checkdata'
-        verbose_name = _("Data problem")
-        verbose_name_plural = _("Data problems")
+        verbose_name = _("Data problem message")
+        verbose_name_plural = _("Data problem messages")
         ordering = ['owner_type', 'owner_id', 'checker']
 
     controller_is_optional = False
@@ -105,10 +105,10 @@ class Problem(Controllable, UserAuthored):
     checker = Checkers.field(verbose_name=_("Checker"))
     # severity = Severities.field()
     # feedback = Feedbacks.field(blank=True)
-    message = models.CharField(_("Message"), max_length=250)
+    message = models.CharField(_("Message text"), max_length=250)
     # fixable = models.BooleanField(_("Fixable"), default=False)
 
-    update_problem = UpdateProblem()
+    update_problem = UpdateMessage()
     fix_problem = FixProblem()
 
     # no longer needed after 20170826
@@ -123,19 +123,19 @@ class Problem(Controllable, UserAuthored):
 
     @classmethod
     def get_simple_parameters(cls):
-        for p in super(Problem, cls).get_simple_parameters():
+        for p in super(Message, cls).get_simple_parameters():
             yield p
         yield 'checker'
 
-dd.update_field(Problem, 'user', verbose_name=_("Responsible"))
-Problem.set_widget_options('checker', width=10)
-Problem.set_widget_options('user', width=10)
-Problem.set_widget_options('message', width=50)
-Problem.update_controller_field(verbose_name = _('Database object'))
+dd.update_field(Message, 'user', verbose_name=_("Responsible"))
+Message.set_widget_options('checker', width=10)
+Message.set_widget_options('user', width=10)
+Message.set_widget_options('message', width=50)
+Message.update_controller_field(verbose_name = _('Database object'))
 
 
-class Problems(dd.Table):
-    model = 'checkdata.Problem'
+class Messages(dd.Table):
+    model = 'checkdata.Message'
     column_names = "user owner message #fixable checker *"
     auto_fit_column_widths = True
     editable = False
@@ -157,34 +157,32 @@ class Problems(dd.Table):
     """, window_size=(70, 'auto'))
 
 
-class AllProblems(Problems):
-    """Show all data problems.
+class AllMessages(Messages):
+    """Show all data problem messages.
 
-    This table can be opened by system managers using
-    :menuselection:`Explorer --> System --> Data problems`.
+    This table can be opened by site managers using
+    :menuselection:`Explorer --> System --> Data problem messages`.
 
     """
     required_roles = dd.login_required(SiteStaff)
 
 
-class ProblemsByOwner(Problems):
-    """Show data problems related to this database object.
+class MessagesByOwner(Messages):
+    """Show data problem messages related to this database object.
 
     """
     master_key = 'owner'
     column_names = "message checker user #fixable *"
-    display_mode_main = 'summary'
+    display_mode = ((None, constants.DISPLAY_MODE_SUMMARY), )
 
 
-class ProblemsByChecker(Problems):
-    """Show the data problems by checker.
-
-    This was the first use case of a slave table with a master which
-    is something else than a model instance.
+# This was the first use case of a slave table with something else than a model
+# instance as its master
+class MessagesByChecker(Messages):
+    """Show the data problem messages by checker.
 
     """
     master_key = 'checker'
-
     column_names = "user owner message #fixable *"
 
     @classmethod
@@ -197,14 +195,14 @@ class ProblemsByChecker(Problems):
         return kw
 
 
-class MyProblems(Problems):
+class MyMessages(Messages):
 
     required_roles = dd.login_required(CheckdataUser)
-    label = _("Data problems assigned to me")
+    label = _("Data problem messages assigned to me")
 
     @classmethod
     def param_defaults(self, ar, **kw):
-        kw = super(MyProblems, self).param_defaults(ar, **kw)
+        kw = super(MyMessages, self).param_defaults(ar, **kw)
         kw.update(user=ar.get_user())
         return kw
 
@@ -215,7 +213,7 @@ class MyProblems(Problems):
             return
         count = sar.get_total_count()
         if count > 0:
-            msg = _("There are {0} data problems assigned to you.")
+            msg = _("There are {0} data problem messages assigned to you.")
             msg = msg.format(count)
             yield ar.href_to_request(sar, msg)
 
@@ -225,14 +223,14 @@ def set_checkdata_actions(sender, **kw):
     for m in get_checkable_models().keys():
         if m is None:
             continue
-        assert m is not Problem
-        m.define_action(check_data=UpdateProblemsByController(m))
-        m.define_action(fix_problems=FixProblemsByController(m))
+        assert m is not Message
+        m.define_action(check_data=UpdateMessagesByController(m))
+        m.define_action(fix_problems=FixMessagesByController(m))
         if False:
             # don't add it automatically because appdev might prefer
             # to show it in a detail_layout:
             m.define_action(show_problems=dd.ShowSlaveTable(
-                ProblemsByOwner,
+                MessagesByOwner,
                 icon_name = 'bell', combo_group = "checkdata"))
 
 
@@ -241,7 +239,7 @@ def get_checkers_for(model):
 
 def check_instance(obj):
     """
-    Run all checkers on the given instance.  Return list of problems.
+    Run all checkers on the given instance.  Return list of problem messages.
     """
     for chk in get_checkers_for(obj.__class__):
         for prb in chk.check_instance(obj):
@@ -265,12 +263,12 @@ def get_checkable_models(*args):
 
 def check_data(args=[], fix=True, prune=False):
     """Called by :manage:`checkdata`. See there."""
-    Problem = rt.models.checkdata.Problem
+    Message = rt.models.checkdata.Message
     mc = get_checkable_models(*args)
     if len(mc) == 0 and len(args) > 0:
         raise Exception("No checker matches {0}".format(args))
     if prune:
-        qs = Problem.objects.all()
+        qs = Message.objects.all()
         msg = "Prune {} existing messages...".format(qs.count())
         dd.logger.info(msg)
         qs.delete()
@@ -279,29 +277,30 @@ def check_data(args=[], fix=True, prune=False):
     with translation.override('en'):
         for m, checkers in mc.items():
             if m is None:
-                qs = Problem.objects.filter(
-                    **gfk2lookup(Problem.owner, None, checker__in=checkers))
+                qs = Message.objects.filter(
+                    **gfk2lookup(Message.owner, None, checker__in=checkers))
                 qs.delete()
                 qs = [None]
                 name = "unbound data"
-                msg = "Running {0} checkers on {1}...".format(len(checkers), name)
+                msg = "Run {0} checkers on {1}...".format(len(checkers), name)
             else:
                 ct = rt.models.contenttypes.ContentType.objects.get_for_model(m)
-                qs = Problem.objects.filter(owner_type=ct, checker__in=checkers)
+                qs = Message.objects.filter(owner_type=ct, checker__in=checkers)
                 qs.delete()
                 name = str(m._meta.verbose_name_plural)
                 qs = m.objects.all()
-                msg = "Running {0} data checkers on {1} {2}...".format(
+                msg = "Run {0} data checkers on {1} {2}...".format(
                     len(checkers), qs.count(), name)
             dd.logger.debug(msg)
             sums = [0, 0, name]
             for obj in qs:
                 for chk in checkers:
                     todo, done = chk.update_problems(obj, False, fix)
-                    sums[0] += len(todo) + len(done)
+                    sums[0] += len(todo)
                     sums[1] += len(done)
             if sums[0] or sums[1]:
-                msg = "Found {0} and fixed {1} data problems in {2}."
+                # msg = "Fixed {1} problems and created {0} messages in {2}."
+                msg = "Found {0} and fixed {1} problems in {2}."
                 dd.logger.info(msg.format(*sums))
             else:
                 dd.logger.debug(
@@ -309,7 +308,8 @@ def check_data(args=[], fix=True, prune=False):
             final_sums[0] += 1
             final_sums[1] += sums[0]
             final_sums[2] += sums[1]
-    msg = "Done %d %s, found %d and fixed %d problems."
+    # msg = "Done %d %s, fixed %d problems and created %d messages."
+    msg = "%d %s have been run. Found %d and fixed %d problems."
     done, found, fixed = final_sums
     what = pluralize(done, "check,checks")
     dd.logger.info(msg, done, what, found, fixed)
