@@ -1,6 +1,6 @@
 # -*- coding: UTF-8 -*-
 # Copyright 2014-2018 Rumma & Ko Ltd
-# License: BSD (see file COPYING for details)
+# License: GNU Affero General Public License v3 (see file COPYING for details)
 
 """User roles for `lino.modlib.checkdata`."""
 
@@ -8,4 +8,4 @@ from lino.core.roles import UserRole
 
 
 class CheckdataUser(UserRole):
-    """Can see data problems."""
+    """Can see checkdata messages."""
