@@ -15,7 +15,7 @@ class Plugin(ad.Plugin):
 
     site_js_snippets = ['comments/comments.js']
 
-    needs_plugins = ['lino.modlib.office', 'lino.modlib.memo']
+    needs_plugins = ['lino.modlib.memo']
 
     # emotion_range = "social"
     emotion_range = "business"
@@ -47,7 +47,6 @@ class Plugin(ad.Plugin):
         mg = site.plugins.office
         m = m.add_menu(mg.app_label, mg.verbose_name)
         m.add_action('comments.AllComments')
-        m.add_action('comments.Mentions')
         m.add_action('comments.Reactions')
 
     def get_dashboard_items(self, user):
