@@ -1,5 +1,5 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2013-2020 Rumma & Ko Ltd
+# Copyright 2013-2023 Rumma & Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
 
 from django.db import models
@@ -17,10 +17,10 @@ from lino.modlib.users.mixins import UserAuthored
 from lino.modlib.notify.mixins import ChangeNotifier
 from lino.modlib.search.mixins import ElasticSearchable
 from lino.modlib.gfks.mixins import Controllable
-from lino.modlib.memo.mixins import Previewable
+from lino.modlib.memo.mixins import Previewable, MemoReferrable
 from lino.modlib.publisher.mixins import Publishable
 from .choicelists import CommentEvents, Emotions
-from .mixins import Commentable
+from .mixins import Commentable, CommentField
 from .fields import MyEmotionField
 # from .choicelists import PublishAllComments, PublishComment
 
@@ -37,13 +37,15 @@ class CommentType(BabelNamed):
 
 
 class Comment(CreatedModified, UserAuthored, Controllable, ElasticSearchable,
-              ChangeNotifier, Previewable, Publishable, DateRangeObservable):
+              ChangeNotifier, Previewable, Publishable, DateRangeObservable, MemoReferrable):
+
     class Meta(object):
         app_label = 'comments'
         abstract = dd.is_abstract_model(__name__, 'Comment')
         verbose_name = _("Comment")
         verbose_name_plural = _("Comments")
 
+    # elastic search indexes
     ES_indexes = [(
         'comment',
         {
@@ -114,6 +116,7 @@ class Comment(CreatedModified, UserAuthored, Controllable, ElasticSearchable,
     )]
 
     publisher_location = "c"
+    memo_command = "comment"
 
     reply_to = dd.ForeignKey(
         'self', blank=True, null=True, verbose_name=_("Reply to"),
@@ -131,6 +134,8 @@ class Comment(CreatedModified, UserAuthored, Controllable, ElasticSearchable,
 
     my_emotion = MyEmotionField()
 
+    reply = CommentField()
+
     def disabled_fields(self, ar):
         s = super().disabled_fields(ar)
         if ar.get_user().is_anonymous:
@@ -186,7 +191,7 @@ class Comment(CreatedModified, UserAuthored, Controllable, ElasticSearchable,
 
     @classmethod
     def get_user_queryset(cls, user):
-        qs = super(Comment, cls).get_user_queryset(user)
+        qs = super().get_user_queryset(user)
 
         if not user.user_type.has_required_roles([CommentsReader]):
             return qs.none()
@@ -207,22 +212,14 @@ class Comment(CreatedModified, UserAuthored, Controllable, ElasticSearchable,
     #         self.private = self.owner.is_comment_private(self, ar)
 
     def on_create(self, ar):
-        super(Comment, self).on_create(ar)
+        super().on_create(ar)
         if self.owner_id:
             self.private = self.owner.is_comment_private(self, ar)
 
     def after_ui_save(self, ar, cw):
-        super(Comment, self).after_ui_save(ar, cw)
+        super().after_ui_save(ar, cw)
         if self.owner_id:
             self.owner.on_commented(self, ar, cw)
-        if dd.is_installed("memo"):
-            ref_objects = settings.SITE.plugins.memo.parser.get_referred_objects(self.body)
-            for ref_object in ref_objects:
-                created_mention = Mention(comment=self,
-                        owner_id=ref_object.pk,
-                        owner_type=ContentType.objects.get_for_model(ref_object.__class__))
-                created_mention.touch()
-                created_mention.save()
 
     # def full_clean(self):
     #     super(Comment, self).full_clean()
@@ -240,7 +237,7 @@ class Comment(CreatedModified, UserAuthored, Controllable, ElasticSearchable,
         if isinstance(self.owner, ChangeNotifier):
             obs = self.owner
         else:
-            obs = super(Comment, self)
+            obs = super()
         for u in obs.get_change_observers(ar):
             yield u
 
@@ -257,9 +254,11 @@ class Comment(CreatedModified, UserAuthored, Controllable, ElasticSearchable,
         else:
             s = _("{user} modified comment on {obj}")
         user = ar.get_user()
-        s = s.format(
-            user=user, obj=ar.obj2memo(self.owner))
+        # s = s.format(user=user, obj=self.owner.obj2memo())
+        # return ar.obj2htmls(self.owner)
+        s = s.format(user=user, obj=ar.obj2htmls(self.owner))
         if dd.is_installed("inbox"):
+            # raise Exception("20230216")
             #mailto:ADDR@HOST.com?subject=SUBJECT&body=Filling%20in%20the%20Body!%0D%0Afoo%0D%0Abar
             s += ' <a href="{href}">{reply}</a>'.format(
                 href=comment_email.gen_href(self, user),
@@ -274,11 +273,11 @@ class Comment(CreatedModified, UserAuthored, Controllable, ElasticSearchable,
     def setup_parameters(cls, fields):
         fields.update(
             observed_event=CommentEvents.field(blank=True))
-        super(Comment, cls).setup_parameters(fields)
+        super().setup_parameters(fields)
 
     @classmethod
     def get_request_queryset(cls, ar, **filter):
-        qs = super(Comment, cls).get_request_queryset(ar, **filter)
+        qs = super().get_request_queryset(ar, **filter)
         pv = ar.param_values
         if pv.observed_event:
             qs = pv.observed_event.add_filter(qs, pv)
@@ -305,16 +304,6 @@ dd.update_field(Comment, 'user', editable=False)
 Comment.update_controller_field(verbose_name=_('Topic'))
 Comment.add_picker('my_emotion')
 
-class Mention(CreatedModified, Controllable, UserAuthored):
-
-    class Meta(object):
-        app_label = 'comments'
-        abstract = dd.is_abstract_model(__name__, 'Mention')
-        verbose_name = _("Mention")
-        verbose_name_plural = _("Mentions")
-
-    comment = dd.ForeignKey('comments.Comment', blank=True, null=True)
-
 
 class Reaction(CreatedModified, UserAuthored, DateRangeObservable):
 
@@ -330,4 +319,17 @@ class Reaction(CreatedModified, UserAuthored, DateRangeObservable):
     emotion = Emotions.field(default="ok")
 
 
+# @dd.receiver(dd.post_startup)
+# def setup_memo_commands(sender=None, **kwargs):
+#     # See :doc:`/specs/memo`
+#
+#     if not sender.is_installed('memo'):
+#         return
+#
+#     Comment = sender.models.comments.Comment
+#     mp = sender.plugins.memo.parser
+#
+#     mp.register_django_model('comment', Comment)
+
+
 from .ui import *
