@@ -1,9 +1,10 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2013-2022 Rumma & Ko Ltd
+# Copyright 2013-2023 Rumma & Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
 
 from django.utils.translation import ngettext
 from django.contrib.humanize.templatetags.humanize import naturaltime
+from django.contrib.contenttypes.models import ContentType
 from django.db import models
 
 from lino.api import dd, rt, gettext, _
@@ -12,14 +13,14 @@ from etgen.html import E, tostring
 import lxml
 # from lino.utils.soup import truncate_comment
 from lino import mixins
-from lino.core.constants import CHOICES_BLANK_FILTER_VALUE, DISPLAY_MODE_STORY
+from lino.core import constants
 from lino.core.utils import qs2summary
 from lino.core.gfks import gfk2lookup
 from lino.core import constants
 from .roles import CommentsReader, CommentsUser, CommentsStaff
 from .choicelists import CommentEvents, Emotions
 from .fields import MyEmotionField
-from .mixins import Commentable
+from .mixins import Commentable, CommentField
 
 
 class CommentTypes(dd.Table):
@@ -43,7 +44,7 @@ class CommentDetail(dd.DetailLayout):
     main = "general more"
 
     general = dd.Panel("""
-    general1:30 RepliesByComment:30
+    general1:30 general2:30
     """, label=_("General"))
 
     general1 = """
@@ -51,9 +52,10 @@ class CommentDetail(dd.DetailLayout):
     reply_to pick_my_emotion
     body #body_full_preview
     """
-    # general2 = """
-    # RepliesByComment
-    # """
+    general2 = """
+    reply
+    RepliesByComment
+    """
 
     more = dd.Panel("""
     #body more2
@@ -210,7 +212,7 @@ class CommentsByX(Comments):
     required_roles = dd.login_required(CommentsReader)
     order_by = ["-created"]
     # order_by = ["-modified"]
-    display_mode_main = "summary"
+    display_mode = ((None, constants.DISPLAY_MODE_SUMMARY), )
     # card_layout = dd.DetailLayout("""
     # card_summary
     # RepliesByComment
@@ -227,7 +229,8 @@ class CommentsByX(Comments):
 
     @classmethod
     def get_table_summary(cls, obj, ar):
-        sar = cls.request_from(ar, master_instance=obj, is_on_main_actor=False)
+        # sar = cls.request_from(ar, master_instance=obj, is_on_main_actor=False)
+        sar = cls.request(parent=ar, master_instance=obj, is_on_main_actor=False)
         elems = []
 
         if cls.insert_action is not None:
@@ -252,8 +255,8 @@ class CommentsByX(Comments):
                     # elems += [" [", btn, "]"]
                 elif isinstance(obj, Commentable):
                     # we are showing the comment about a Commentable
-                    btn = ir.ar2button(
-                        None, title=_("Start a new {} about {}").format(
+                    btn = ir.ar2button(None,
+                        title=_("Start a new {} about {}").format(
                             cls.model._meta.verbose_name, obj))
                     # btn = ir.ar2button(
                     #         None, _("Write new comment:"), # icon_name=None,
@@ -372,7 +375,7 @@ class RecentComments(CommentsByX):
     # order_by = ["-modified"]
     label = _("Recent comments")
     preview_limit = 10
-    # display_mode_main = "summary"
+    # display_mode = ((None, constants.DISPLAY_MODE_SUMMARY), )
 
 
 class CommentsByType(CommentsByX):
@@ -384,8 +387,10 @@ class CommentsByRFC(CommentsByX):
     master_key = 'owner'
     column_names = "body created user *"
     stay_in_grid = True
-    display_mode_main = constants.DISPLAY_MODE_STORY
-    display_mode_slave = constants.DISPLAY_MODE_SUMMARY
+    display_mode = (
+        (70, constants.DISPLAY_MODE_SUMMARY),
+        (None, constants.DISPLAY_MODE_STORY),
+    )
     simple_slavegrid_header = True
     insert_layout = dd.InsertLayout("""
     reply_to
@@ -397,7 +402,7 @@ class CommentsByRFC(CommentsByX):
     @classmethod
     def param_defaults(cls, ar, **kw):
         kw = super(CommentsByRFC, cls).param_defaults(ar, **kw)
-        kw['reply_to'] = CHOICES_BLANK_FILTER_VALUE
+        kw['reply_to'] = constants.CHOICES_BLANK_FILTER_VALUE
         return kw
 
     @classmethod
@@ -405,7 +410,7 @@ class CommentsByRFC(CommentsByX):
         ticket_obj = ar.master_instance
         if ticket_obj is None:
             return None
-        sar = self.request_from(ar, master_instance=ticket_obj)
+        sar = self.request(parent=ar, master_instance=ticket_obj)
         html = ticket_obj.get_rfc_description(ar)
         sar = self.insert_action.request_from(sar)
         if sar.get_permission():
@@ -455,9 +460,10 @@ class CommentsByMentioned(CommentsByX):
         mi = ar.master_instance
         if mi is None:
             return None
-        Mention = rt.models.comments.Mention
-        mkw = gfk2lookup(Mention.owner, mi)
-        mentions = Mention.objects.filter(**mkw).values_list('comment_id', flat=True)
+        Mention = rt.models.memo.Mention
+        ct = ContentType.objects.get_for_model(cls.model)
+        mkw = gfk2lookup(Mention.source, mi, owner_type=ct)
+        mentions = Mention.objects.filter(**mkw).values_list('owner_id', flat=True)
         # mentions = [o.comment_id for o in Mention.objects.filter(**mkw)]
         # print(mkw, mentions)
         # return super(CommentsByMentioned, cls).get_filter_kw(ar, **kw)
@@ -467,9 +473,8 @@ class CommentsByMentioned(CommentsByX):
 
 class RepliesByComment(CommentsByX):
     master_key = 'reply_to'
-    # display_mode_main = "list"
     stay_in_grid = True
-    # display_mode_main = DISPLAY_MODE_STORY
+    # display_mode = ((None, constants.DISPLAY_MODE_STORY), )
     # title = _("Replies")
     label = _("Replies")
     simple_slavegrid_header = True
@@ -482,20 +487,6 @@ def comments_by_owner(obj):
     return CommentsByRFC.request(master_instance=obj)
 
 
-class Mentions(dd.Table):
-    required_roles = dd.login_required(CommentsStaff)
-    editable = False
-    model = "comments.Mention"
-    column_names = "comment owner created *"
-    # detail_layout = """
-    # id comment owner created
-    # """
-
-
-class MentionsByOwner(Mentions):
-    master_key = "owner"
-
-
 class Reactions(dd.Table):
     required_roles = dd.login_required(CommentsStaff)
     editable = False
