@@ -358,7 +358,7 @@ class ExtRenderer(JsRenderer, JsCacheRenderer):
     #     Used by appy_pod renderer.
     #     """
     #     if ar.actor.master is not None and not nosummary:
-    #         if ar.actor.display_mode_main == 'summary':
+    #         if constants.DISPLAY_MODE_SUMMARY == [dmi[1] for dmi in ar.actor.display_mode if dmi[0] is None][0]:
     #             return ar.actor.get_table_summary(ar.master_instance, ar)
     #     return ar.table2xhtml(**kw)
 
@@ -409,7 +409,7 @@ class ExtRenderer(JsRenderer, JsCacheRenderer):
                 user = request.subst_user
 
         def getit():
-            if (not settings.SITE.build_js_cache_on_startup
+            if (settings.SITE.developer_site_cache
                 and not settings.SITE.never_build_site_cache):
                 self.build_js_cache(False)
 
@@ -664,13 +664,13 @@ class ExtRenderer(JsRenderer, JsCacheRenderer):
 
         #~ f.write('\n/* Application FormPanel subclasses */\n')
         for fl in self.param_panels:
-            lh = fl.get_layout_handle(self.front_end)
+            lh = fl.get_layout_handle()
             if must_render(lh, user_type):
                 for ln in self.js_render_ParamsPanelSubclass(lh):
                     f.write(ln + '\n')
 
         for fl in self.action_param_panels:
-            lh = fl.get_layout_handle(self.front_end)
+            lh = fl.get_layout_handle()
             if must_render(lh, user_type):
                 for ln in self.js_render_ActionFormPanelSubclass(lh):
                     f.write(ln + '\n')
@@ -678,7 +678,7 @@ class ExtRenderer(JsRenderer, JsCacheRenderer):
         assert user_type == get_user_profile()
 
         for fl in self.form_panels:
-            lh = fl.get_layout_handle(self.front_end)
+            lh = fl.get_layout_handle()
             if must_render(lh, user_type):
                 for ln in self.js_render_FormPanelSubclass(lh):
                     f.write(ln + '\n')
@@ -1395,10 +1395,10 @@ class ExtRenderer(JsRenderer, JsCacheRenderer):
             yield "LANGUAGE_CHOICES = %s;" % py2js(
                 list(settings.SITE.LANGUAGE_CHOICES))
             yield "MEDIA_URL = %s;" % py2js(settings.SITE.build_media_url())
-            if settings.SITE.never_build_site_cache:
-                yield "GEN_TIMESTAMP = '%s';" % settings.SITE.kernel.lino_version
-            else:
-                yield "GEN_TIMESTAMP = %s;" % py2js(settings.SITE.kernel.code_mtime)
+            # if settings.SITE.never_build_site_cache:
+            #     yield "GEN_TIMESTAMP = '%s';" % settings.SITE.kernel.lino_version
+            # else:
+            yield "GEN_TIMESTAMP = %s;" % py2js(settings.SITE.kernel.code_mtime)
 
         return '\n'.join(fn())
 
@@ -1413,7 +1413,7 @@ class ExtRenderer(JsRenderer, JsCacheRenderer):
         either `data_record` or a `record_id`.
 
         Usually `data_record`, except if it is a `file upload
-        <https://docs.djangoproject.com/en/3.1/topics/http/file-uploads/>`_
+        <https://docs.djangoproject.com/en/4.1/topics/http/file-uploads/>`_
         where some mysterious decoding problems (:blogref:`20120209`)
         force us to return a `record_id` which has the same visible
         result but using an additional GET.
