@@ -26,8 +26,9 @@ Summary from <http://en.wikipedia.org/wiki/Restful>:
 
 """
 import json
+import os
 
-from os import environ
+from pathlib import Path
 
 from django import http
 from django.db import models
@@ -139,18 +140,23 @@ class AdminIndex(View):
         return http.HttpResponse(renderer.html_page(request, **kw))
 
 def test_version_mismatch(request):
-    if environ.get("PYCHARM_HOSTED", False):
+    if os.environ.get("PYCHARM_HOSTED", False):
         return {}
     lv = request.GET.get(constants.URL_PARAM_LINO_VERSION)
-    if (lv is None
-    or (settings.SITE.never_build_site_cache
-    and settings.SITE.kernel.lino_version == lv)
-    or float(lv) == settings.SITE.kernel.code_mtime):
+    if lv is None or float(lv) == settings.SITE.kernel.code_mtime:
         return {}
     # print("20201217", lv, settings.SITE.kernel.code_mtime)
     cache.clear()
     if settings.SITE.kernel.default_ui.app_label == 'react':
-        return dict(version_mismatch=True)
+        vm_data = dict(version_mismatch=True)
+        try:
+            if float(request.GET.get(
+                    constants.URL_PARAM_MAIN_JS_TIMESTAMP)
+            ) != os.stat(Path(settings.STATIC_ROOT) / 'react' / 'main.js'):
+                vm_data.update(js_version_mismatch=True)
+        except Exception:
+            pass
+        return vm_data
     return dict(alert=_("Version mismatch"),
                 message=_("Your browser is using a previous version of the site, press OK to reload the site"),
                 alert_eval_js="window.location.reload(true);")
