@@ -152,7 +152,7 @@ def layout2html(ar, elem):
 
     wl = ar.bound_action.get_window_layout()
     #~ print 20120901, wl.main
-    lh = wl.get_layout_handle(settings.SITE.kernel.default_ui)
+    lh = wl.get_layout_handle()
 
     items = list(lh.main.as_plain_html(ar, elem))
     # if navigator:
