@@ -1,13 +1,9 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2010-2018 Rumma & Ko Ltd
+# Copyright 2010-2022 Rumma & Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
 
-
-from builtins import object
 from django.contrib.contenttypes.models import *
-
 from django.conf import settings
-
 from django.utils.translation import gettext_lazy as _
 from django.utils.text import format_lazy
 
@@ -31,13 +27,14 @@ class Controllable(dd.Model):
         ContentType,
         editable=True,
         blank=True, null=True,
-        verbose_name=format_lazy(u"{} {}", owner_label, _('(type)')))
+        related_name="%(app_label)s_%(class)s_set",
+        verbose_name=format_lazy("{} {}", owner_label, _('(type)')))
 
     owner_id = GenericForeignKeyIdField(
         owner_type,
         editable=True,
         blank=True, null=True,
-        verbose_name=format_lazy(u"{} {}", owner_label, _('(object)')))
+        verbose_name=format_lazy("{} {}", owner_label, _('(object)')))
 
     owner = GenericForeignKey(
         'owner_type', 'owner_id',
@@ -77,4 +74,3 @@ class Controllable(dd.Model):
         gfk = self._meta.get_field('owner')
         kwargs = gfk2lookup(gfk, self, **kwargs)
         return model.objects.filter(**kwargs)
-
