@@ -1,5 +1,5 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2010-2020 Rumma & Ko Ltd
+# Copyright 2010-2023 Rumma & Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
 
 from django import VERSION
@@ -31,7 +31,6 @@ class ContentTypes(dd.Table):
 
     detail_layout = """
     id app_label model base_classes
-    HelpTextsByModel
     BrokenGFKsByModel
     """
 
@@ -61,68 +60,68 @@ class ContentTypes(dd.Table):
         return E.p(*join_elems(chunks, sep=', '))
 
 
-class HelpText(dd.Model):
-    # Deprecated. Nobody every used this feature in reality.
-    class Meta(object):
-        app_label = 'gfks'
-        verbose_name = _("Help Text")
-        verbose_name_plural = _("Help Texts")
-
-    content_type = dd.ForeignKey('contenttypes.ContentType',
-                                 verbose_name=_("Model"))
-    field = models.CharField(_("Field"), max_length=200)
-
-    help_text = dd.RichTextField(_("HelpText"),
-                                 blank=True, null=True, format='plain')
-
-    def __str__(self):
-        return self.content_type.app_label + '.' \
-            + self.content_type.model + '.' + self.field
-
-    @dd.chooser(simple_values=True)
-    def field_choices(cls, content_type):
-        l = []
-        if content_type is not None:
-            model = content_type.model_class()
-            meta = model._meta
-            for f in meta.fields:
-                if not getattr(f, '_lino_babel_field', False):
-                    l.append(f.name)
-            for f in meta.many_to_many:
-                l.append(f.name)
-            for f in meta.virtual_fields:
-                l.append(f.name)
-            for a in model.get_default_table().get_actions():
-                l.append(a.action.action_name)
-            l.sort()
-        return l
-
-    #~ def get_field_display(cls,fld):
-        #~ return fld
-
-    @dd.virtualfield(models.CharField(_("Verbose name"), max_length=200))
-    def verbose_name(self, request):
-        m = self.content_type.model_class()
-        de = m.get_default_table().get_data_elem(self.field)
-        if isinstance(de, models.Field):
-            return "%s (%s)" % (str(de.verbose_name),
-                                str(_("database field")))
-        if isinstance(de, dd.VirtualField):
-            return str(de.return_type.verbose_name)
-        if isinstance(de, dd.Action):
-            return str(de.label)
-        return str(de)
-
-
-class HelpTexts(dd.Table):
-    required_roles = dd.login_required(SiteStaff)
-    model = 'gfks.HelpText'
-    column_names = "field verbose_name help_text id content_type"
-
-
-class HelpTextsByModel(HelpTexts):
-    master_key = 'content_type'
-
+# class HelpText(dd.Model):
+#     # Deprecated. Nobody every used this feature in reality.
+#     class Meta(object):
+#         app_label = 'gfks'
+#         verbose_name = _("Help Text")
+#         verbose_name_plural = _("Help Texts")
+#
+#     content_type = dd.ForeignKey('contenttypes.ContentType',
+#                                  verbose_name=_("Model"))
+#     field = models.CharField(_("Field"), max_length=200)
+#
+#     help_text = dd.RichTextField(_("HelpText"),
+#                                  blank=True, null=True, format='plain')
+#
+#     def __str__(self):
+#         return self.content_type.app_label + '.' \
+#             + self.content_type.model + '.' + self.field
+#
+#     @dd.chooser(simple_values=True)
+#     def field_choices(cls, content_type):
+#         l = []
+#         if content_type is not None:
+#             model = content_type.model_class()
+#             meta = model._meta
+#             for f in meta.fields:
+#                 if not getattr(f, '_lino_babel_field', False):
+#                     l.append(f.name)
+#             for f in meta.many_to_many:
+#                 l.append(f.name)
+#             for f in meta.virtual_fields:
+#                 l.append(f.name)
+#             for a in model.get_default_table().get_actions():
+#                 l.append(a.action.action_name)
+#             l.sort()
+#         return l
+#
+#     #~ def get_field_display(cls,fld):
+#         #~ return fld
+#
+#     @dd.virtualfield(models.CharField(_("Verbose name"), max_length=200))
+#     def verbose_name(self, request):
+#         m = self.content_type.model_class()
+#         de = m.get_default_table().get_data_elem(self.field)
+#         if isinstance(de, models.Field):
+#             return "%s (%s)" % (str(de.verbose_name),
+#                                 str(_("database field")))
+#         if isinstance(de, dd.VirtualField):
+#             return str(de.return_type.verbose_name)
+#         if isinstance(de, dd.Action):
+#             return str(de.label)
+#         return str(de)
+#
+#
+# class HelpTexts(dd.Table):
+#     required_roles = dd.login_required(SiteStaff)
+#     model = 'gfks.HelpText'
+#     column_names = "field verbose_name help_text id content_type"
+#
+#
+# class HelpTextsByModel(HelpTexts):
+#     master_key = 'content_type'
+#
 
 class BrokenGFKs(dd.VirtualTable):
     label = _("Broken GFKs")
@@ -170,7 +169,8 @@ class BrokenGFKsByModel(BrokenGFKs):
 
     @classmethod
     def get_pk_field(self):
-        return settings.SITE.site_config._meta.get_field('id')
+        return rt.models.system.SiteConfig._meta.get_field('id')
+        # return settings.SITE.site_config._meta.get_field('id')
 
     @classmethod
     def get_row_by_pk(self, ar, pk):
@@ -190,22 +190,22 @@ class BrokenGFKsByModel(BrokenGFKs):
         return True
 
 
-if False:  # disabled 20160712
-
-  @dd.receiver(dd.pre_ui_build)
-  def my_pre_ui_build(sender, **kw):
-    try:
-        HelpText = rt.models.gfks.HelpText
-        for ht in HelpText.objects.filter(help_text__isnull=False):
-            # dd.logger.info("20120629 %s.help_text", ht)
-            try:
-                dd.resolve_field(str(ht)).help_text = ht.help_text
-            except FieldDoesNotExist as e:
-                #~ logger.debug("No help texts : %s",e)
-                pass
-    except DatabaseError as e:
-        dd.logger.debug("No help texts : %s", e)
-        pass
+# if False:  # disabled 20160712
+#
+#   @dd.receiver(dd.pre_ui_build)
+#   def my_pre_ui_build(sender, **kw):
+#     try:
+#         HelpText = rt.models.gfks.HelpText
+#         for ht in HelpText.objects.filter(help_text__isnull=False):
+#             # dd.logger.info("20120629 %s.help_text", ht)
+#             try:
+#                 dd.resolve_field(str(ht)).help_text = ht.help_text
+#             except FieldDoesNotExist as e:
+#                 #~ logger.debug("No help texts : %s",e)
+#                 pass
+#     except DatabaseError as e:
+#         dd.logger.debug("No help texts : %s", e)
+#         pass
 
 
 # cause `inv mm` to generate translatable strings from Django's
