@@ -126,9 +126,13 @@ class GeneratingCommand(BaseCommand):
 
     def handle(self, *args, **options):
 
+        if settings.SITE.master_site:
+            settings.SITE.logger.info(
+                "No need to `makehelp` on slave site '%s'.", settings.SETTINGS_MODULE)
+            return
+
         self.options = options
-        parts = ('cache', 'help')
-        self.output_dir = join(settings.SITE.site_cache_root, *parts)
+        self.output_dir = settings.SITE.media_root / 'cache' / 'help'
         self.generated_count = 0
         self.htl = HelpTextsLoader(settings.SITE)
 
@@ -162,9 +166,9 @@ class GeneratingCommand(BaseCommand):
                 args += ['-Q'] # no output
             args += ['.']
             if lng.index == 0:
-                args += [self.output_dir]
+                args += [str(self.output_dir)]
             else:
-                args += [join(self.output_dir, lng.django_code)]
+                args += [str(self.output_dir / lng.django_code)]
             cmd = ' '.join(args)
             print("Run `cd {} && {}`".format(docs_dir, cmd))
             with cd(docs_dir):
@@ -430,7 +434,7 @@ class Command(GeneratingCommand):
 
         s += rubric(_("Toolbar actions"))
         # s += rstgen.ul([action2par(a) for a in rpt.get_toolbar_actions()])
-        s += rstgen.ul([self.action2par(ba) for ba in rpt._actions_list if ba.action.show_in_bbar])
+        s += rstgen.ul([self.action2par(ba) for ba in rpt._actions_list if ba.action.show_in_toolbar])
         if rpt.parameters:
             s += show(_("Filter parameters"), rpt.parameters.values())
             # s += rubric(_("Filter parameters"))
