@@ -61,26 +61,29 @@ class Plugin(ad.Plugin):
         return self.renderer.jinja_env.list_templates(extensions=[ext])
 
     def render_from_request(self, request, template_name, **context):
-        """Render the named Jinja template, replacing ar.renderer by the
-        Site's default renderer.
-        Adds some more context names.
+        """
+        Render the named Jinja template using an incoming HTTP request.
         """
         from lino.core import requests
         context.update(request=request)
+        # print("20210615 render_from_request", self.site.kernel.default_renderer)
         ar = requests.BaseRequest(
-            # renderer=settings.SITE.plugins.jinja.renderer,
             renderer=self.site.kernel.default_renderer,
             request=request)
-        # self.site.logger.info(
-        #     "20160529 render_from_request() %s",
-        #     self.site.kernel.default_renderer)
+        return self.render_from_ar(ar, template_name, **context)
 
+    def render_from_ar(self, ar, template_name, **context):
+        """
+        Render the named Jinja template using the given action request `ar`.
+        """
+        # print("20210615 render_from_ar", ar.renderer)
+        # raise Exception("20210615")
+        # if not "front_end" in context:
+        #     context.update(front_end=ar.renderer.front_end)
         context = ar.get_printable_context(**context)
         context.update(ar=ar)  # probably useless because done by
                                # get_printable_context()
         template = self.renderer.jinja_env.get_template(template_name)
-        # u = ar.get_user()
-        # print("20170607", u)
         return template.render(**context)
 
     def render_jinja(self, ar, tplname, context):
