@@ -1,4 +1,5 @@
-# Copyright 2015-2020 Rumma & Ko Ltd
+# -*- coding: UTF-8 -*-
+# Copyright 2015-2023 Rumma & Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
 
 """
@@ -15,6 +16,7 @@ from django.conf import settings
 
 from django.utils.translation import gettext
 from django.utils.translation import pgettext
+from django.utils.html import mark_safe, format_html
 
 from etgen import html as xghtml
 from etgen.html import E, tostring
@@ -46,8 +48,8 @@ class JinjaRenderer(HtmlRenderer):
 
         paths = list(settings.SITE.get_settings_subdirs(SUBDIR_NAME))
         if True:  # settings.SITE.is_local_project_dir:
-            p = join(settings.SITE.cache_dir, SUBDIR_NAME)
-            if isdir(p):
+            p = settings.SITE.site_dir / SUBDIR_NAME
+            if p.is_dir():
                 paths.append(p)
         #~ logger.info("20130717 web.py paths %s",paths)
         if len(paths) > 0:
@@ -78,7 +80,7 @@ class JinjaRenderer(HtmlRenderer):
         def as_table(action_spec):
             a = settings.SITE.models.resolve(action_spec)
             ar = a.request(
-                user=settings.SITE.user_model.get_anonymous_user())
+                user=settings.SITE.get_anonymous_user())
             return self.as_table(ar)
 
         def as_table2(ar):
@@ -96,11 +98,24 @@ class JinjaRenderer(HtmlRenderer):
         def as_ul(action_spec):
             a = settings.SITE.models.resolve(action_spec)
             ar = a.request(
-                user=settings.SITE.user_model.get_anonymous_user())
+                user=settings.SITE.get_anonymous_user())
             # 20150810
             ar.renderer = self
-            # ar.renderer = settings.SITE.plugins.bootstrap3.renderer
-            return tostring(E.ul(*[obj.as_list_item(ar) for obj in ar]))
+            # return tostring(E.ul(*[obj.as_paragraph(ar) for obj in ar]))
+            items = []
+            for obj in ar:
+                par = ar.row_as_paragraph(obj)  # 20230207
+                # par = ar.obj2str(obj, mark_safe(par))
+                par = ar.add_detail_link(obj, par)
+                # url = ar.renderer.obj2url(ar, obj)
+                # if url is not None:
+                #     url = html.escape(url)
+                #     # par += ' <a href="{}">(Detail)</a>'.format(url)
+                #     par = '<a href="{}">{}</a>'.format(url, par)
+
+                items.append("<li>{}</li>".format(par))
+                # items.append("<li>{}</li>".format(obj.as_paragraph(ar)))
+            return "<ul>{}</ul>".format("".join(items))
 
         self.jinja_env.globals.update(
             settings=settings,
