@@ -1,13 +1,13 @@
 # -*- coding: UTF-8 -*-
 # Copyright 2009-2019 Rumma & Ko Ltd
-# License: BSD (see file COPYING for details)
+# License: GNU Affero General Public License v3 (see file COPYING for details)
 """
 Adds an arbitrary selection of a few languages.
 """
 
 from __future__ import unicode_literals
 
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 # from lino.utils.instantiator import Instantiator
 from lino.api import dd, rt
 
