@@ -1,6 +1,6 @@
 # -*- coding: UTF-8 -*-
 # Copyright 2008-2017 Luc Saffre
-# License: BSD (see file COPYING for details)
+# License: GNU Affero General Public License v3 (see file COPYING for details)
 
 """Defines the :class:`Language` model.
 
@@ -12,7 +12,7 @@ from django.db import models
 
 from lino.api import dd
 from lino import mixins
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 from lino.modlib.office.roles import OfficeStaff
 
