@@ -1,4 +1,4 @@
-# Copyright 2008-2021 Rumma & Ko Ltd
+# Copyright 2008-2022 Rumma & Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
 
 """Adds functionality for managing :term:`notification messages <notification
@@ -8,16 +8,9 @@ See :doc:`/specs/notify`.
 
 """
 
+import re
 from lino.api import ad, _
 from lino.core.utils import is_devserver
-try:
-    import redis
-except ImportError:
-    redis = None
-try:
-    import channels
-except ImportError:
-    channels = None
 
 
 class Plugin(ad.Plugin):
@@ -26,7 +19,6 @@ class Plugin(ad.Plugin):
     needs_plugins = ['lino.modlib.users', 'lino.modlib.memo']
     media_name = 'js'
 
-    use_websockets = False
     use_push_api = False
     # Beware: The key pair used here are supposed to be used only in a
     # development environment and the keys are publicly available on the
@@ -39,61 +31,19 @@ class Plugin(ad.Plugin):
     keep_unseen = True
     mark_seen_when_sent = False
 
-    def on_init(self):
-        if self.use_websockets:
-            if channels is None:
-                # if channels is not installed, we cannot use it as a plugin
-                # because even :manage:`install` would fail.
-                return
-            self.needs_plugins.append('channels')
-
-    def on_plugins_loaded(self, site):
-        assert self.site is site
-        if self.use_websockets:
-            sd = site.django_settings
-            # the dict which will be used to create settings
-            cld = {}
-            sd['CHANNEL_LAYERS'] = {"default": cld}
-            #if not DJANGO2:
-            #    cld["ROUTING"] = "lino.modlib.notify.routing.channel_routing"
-            #    cld["BACKEND"] = "asgiref.inmemory.ChannelLayer"
-            #else:
-            sd['ASGI_APPLICATION'] = "lino.modlib.notify.routing.application"
-            cld["BACKEND"] = "channels_redis.core.RedisChannelLayer"
-            cld['CONFIG'] = {"hosts": [("localhost", 6379)], }
-            if False:  # not is_devserver():
-                cld['BACKEND'] = "asgi_redis.RedisChannelLayer"
-                cld['CONFIG'] = {"hosts": [("localhost", 6379)], }
-
     def get_requirements(self, site):
-        if self.use_websockets:
-            yield 'channels'
-            # yield 'asgiref'
-            yield 'channels_redis'
-            if False:  # not is_devserver():
-                yield 'asgi_redis'
-        if self.use_push_api:
+        if self.use_push_api and site.use_linod:
             yield 'pywebpush'
 
-
-    def get_used_libs(self, html=None):
-        if self.use_websockets:
-            try:
-                import channels
-                version = channels.__version__
-            except ImportError:
-                version = self.site.not_found_msg
-            yield ("Channels", version, "https://github.com/django/channels")
-
     def get_patterns(self):
-        if self.use_push_api:
+        if self.use_push_api and self.site.use_linod:
             from django.urls import re_path as url
             from . import views
             yield url(r'pushsubscription', views.PushSubscription.as_view())
             # yield url(r'testpush', views.TestPush.as_view())
 
     def get_js_includes(self, settings, language):
-        if self.use_websockets:
+        if self.site.use_linod:
             if settings.DEBUG:
                 yield self.build_lib_url(('push.js/push.min.js'))
             else:
@@ -110,7 +60,7 @@ class Plugin(ad.Plugin):
         m.add_action('notify.AllMessages')
 
     def get_head_lines(self, site, request):
-        if self.use_push_api:
+        if self.use_push_api and site.use_linod:
             yield """<script type="text/javascript">
                 window.addEventListener('click', () => {
                     Notification.requestPermission((status) => {
@@ -139,7 +89,7 @@ class Plugin(ad.Plugin):
                 });
             </script>"""
 
-        if not self.use_websockets:
+        if not self.site.use_linod:
             return
         from lino.utils.jsgen import py2js
         user_name = "anony"
@@ -161,10 +111,10 @@ class Plugin(ad.Plugin):
             // connection gets bumped over to WebSocket consumers
             var ws_scheme = window.location.protocol == "https:" ? "wss" : "ws";
             var ws_path = "/WS/";
+            let webSocket;
             console.log("Connecting to " + ws_path);
-            // var webSocketBridge = new channels.WebSocketBridge();
             function connect() {
-                var webSocket = new WebSocket(ws_scheme + "://" + window.location.host + ws_path);
+                webSocket = new WebSocket(ws_scheme + "://" + window.location.host + ws_path);
                 webSocket.addEventListener('open', (event) => {
                     console.log(event);
                 });
@@ -202,55 +152,9 @@ class Plugin(ad.Plugin):
                 });
             }
             connect();
-            // var username = '%s' ;
-            // webSocketBridge.connect();
-            // lino_connecting = function() {
-            //     console.log("lino connecting ...");
-            //     webSocketBridge.send({
-            //                 "command": "user_connect",
-            //                 "username": username
-            //             });
-            // }
-            // webSocketBridge.socket.addEventListener('open', function() {
-            //     lino_connecting();
-            // });
-            // // Helpful debugging
-            // webSocketBridge.socket.onclose = function () {
-            //     console.log("Disconnected from chat socket");
-            // }
-            //
-            // onGranted = console.log("onGranted");
-            // onDenied = console.log("onDenied");
-            // // Ask for permission if it's not already granted
-            // Push.Permission.request(onGranted,onDenied);
-            //
-            // webSocketBridge.listen(function(action, stream) {
-            //     try {
-            //         Push.create( %s , {
-            //             body: action['body'],
-            //             icon: '/static/img/lino-logo.png',
-            //             onClick: function () {
-            //                 window.focus();
-            //                 """ + site.kernel.default_renderer.reload_js() + """
-            //                 this.close();
-            //             }
-            //         });
-            //         if (false && Number.isInteger(action["id"])){
-            //             webSocketBridge.stream('lino').send({message_id: action["id"]})
-            //             webSocketBridge.send(JSON.stringify({
-            //                             "command": "seen",
-            //                             "message_id": action["id"],
-            //                         }));
-            //                     }
-            //         }
-            //     catch(err) {
-            //         console.log(err.message);
-            //     }
-            // });
         });
-        // end of onReady()"
         </script>
-            """) % (user_name, py2js(site_title))
+            """) #% (user_name, py2js(site_title))
         yield js_to_add
 
     def get_dashboard_items(self, user):
