@@ -1,12 +1,16 @@
-# Copyright 2016-2021 Rumma & Ko Ltd
+# Copyright 2016-2022 Rumma & Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
 
 import multiprocessing as mp
+# import pickle
 from etgen.html import E, tostring
+from asgiref.sync import async_to_sync
 from django.conf import settings
+# from channels.layers import get_channel_layer
 from lino.api import dd, rt, _
 
 PUBLIC_GROUP = 'all_users_channel'
+# CHANNEL_LAYER = get_channel_layer()
 
 class ChangeNotifier(dd.Model):
 
@@ -32,7 +36,7 @@ class ChangeNotifier(dd.Model):
             # raise NotImplementedError()
 
         def get_change_body(self, ar, cw):
-            ctx = dict(user=ar.user, what=ar.obj2memo(self))
+            ctx = dict(user=ar.user, what=self.obj2memo())
             if cw is None:
                 elems = [E.p(
                     _("{user} created {what}").format(**ctx), ".")]
@@ -90,11 +94,11 @@ class ChangeNotifier(dd.Model):
                     return None
                 return (subject, self.get_change_body(ar, cw))
             owner = self.get_change_owner()
-            if settings.SITE.use_multiprocessing:
-                proc = mp.Process(
-                    target=rt.models.notify.Message.emit_notification,
-                    args=(ar, owner, mt, msg, self.get_change_observers(ar)))
-                proc.start()
-            else:
-                rt.models.notify.Message.emit_notification(
-                    ar, owner, mt, msg, self.get_change_observers(ar))
+            # if settings.SITE.use_multiprocessing:
+            #     proc = mp.Process(
+            #         target=rt.models.notify.Message.emit_notification,
+            #         args=(ar, owner, mt, msg, self.get_change_observers(ar)))
+            #     proc.start()
+            # else:
+            rt.models.notify.Message.emit_notification(
+                ar, owner, mt, msg, self.get_change_observers(ar))
