@@ -13,9 +13,8 @@ your API requires authentication::
 In Django versions older than 1.9, the urls must be namespaced as 'rest_framework',
 and you should make sure your authentication settings include `SessionAuthentication`.
 """
-from __future__ import unicode_literals
 
-from django.conf.urls import url, include
+from django.urls import re_path, include
 
 # urlpatterns = [
 #     url(r'^api-auth/', include('rest_framework.urls',
@@ -35,4 +34,3 @@ from django.conf.urls import url, include
 #     url(r'^login/$', views.login, template_name, name='login'),
 #     url(r'^logout/$', views.logout, template_name, name='logout'),
 # ]
-
