@@ -1,5 +1,5 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2021-2022 Rumma & Ko Ltd
+# Copyright 2021-2023 Rumma & Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
 
 import re
@@ -24,10 +24,10 @@ class SiteSearchBase(dd.VirtualTable):
     column_names = "description matches"
     private_apps = frozenset(['sessions', 'contenttypes', 'users'])
 
-    display_mode_main = constants.DISPLAY_MODE_STORY
+    display_mode = ((None, constants.DISPLAY_MODE_STORY), )
 
     card_layout = """description"""
-    item_layout = """
+    list_layout = """
     search_overview
     matches
     """
@@ -46,7 +46,10 @@ class SiteSearchBase(dd.VirtualTable):
     @dd.displayfield(_("Except"))
     def search_overview(cls, obj, ar):
         if obj is not None:
-            t = cls.get_table_for_role(obj.get_default_table(), ar.get_user().user_type.role)
+            t = obj.get_default_table()
+            if t is None:
+                return
+            t = cls.get_table_for_role(t, ar.get_user().user_type.role)
             sar = t.request(parent=ar)
             return obj.as_search_item(sar)
 
@@ -58,10 +61,13 @@ class SiteSearchBase(dd.VirtualTable):
         return default_table
 
     @classmethod
-    def get_card_title(cls, ar, elem):
-        t = cls.get_table_for_role(elem.get_default_table(), ar.get_user().user_type.role)
+    def get_card_title(cls, ar, obj):
+        t = obj.get_default_table()
+        if t is None:
+            return
+        t = cls.get_table_for_role(t, ar.get_user().user_type.role)
         sar = t.request(parent=ar)
-        return t.get_card_title(sar, elem)
+        return t.get_card_title(sar, obj)
 
     @classmethod
     def return_rows(cls, ar) -> bool:
@@ -124,7 +130,7 @@ class SiteSearchBase(dd.VirtualTable):
 
 class SiteSearch(SiteSearchBase):
 
-    display_mode_main = constants.DISPLAY_MODE_LIST
+    display_mode = ((None, constants.DISPLAY_MODE_LIST), )
 
     @classmethod
     def get_data_rows(cls, ar):
@@ -134,15 +140,18 @@ class SiteSearch(SiteSearchBase):
                 if model._meta.app_label in cls.private_apps:
                     continue
                 if model.show_in_site_search:
-                    t = cls.get_table_for_role(model.get_default_table(), user_type.role)
-                    # for t in cls._site_search_tables:
+                    t = model.get_default_table()
+                    if t is None:
+                        continue
+                    t = cls.get_table_for_role(t, user_type.role)
                     if not t.get_view_permission(user_type):
                         continue
                     sar = t.request(
                         parent=ar, quick_search=ar.quick_search)
                     for obj in sar:
-                        if t.get_row_permission(obj, sar, t.get_row_state(obj), sar.bound_action) and obj.show_in_site_search:  # don't show calview.HeaderRow
-                            yield obj
+                        if obj.show_in_site_search:  # don't show calview.HeaderRow
+                            if t.get_row_permission(obj, sar, t.get_row_state(obj), sar.bound_action):
+                                yield obj
 
 
 if settings.SITE.use_elasticsearch and has_elasticsearch:
@@ -160,6 +169,8 @@ if settings.SITE.use_elasticsearch and has_elasticsearch:
             for hit in sq.response.hits:
                 model = dd.resolve_model(hit['model'])
                 t = model.get_default_table()
+                if t is None:
+                    continue
                 if not t.get_view_permission(ar.get_user().user_type):
                     continue
                 # yield model.objects.annotate_and_get(hit['id'], sq)
