@@ -3,12 +3,12 @@
 
 """Run an SMTP daemon process.
 
+See :doc:`/plugins/smtpd`.
+
 .. autosummary::
    :toctree:
 
    signals
-   management.commands.recmail
-
 
 """
 
