@@ -1,5 +1,5 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2009-2021 Rumma & Ko Ltd
+# Copyright 2009-2022 Rumma & Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
 
 from etgen.html import E
@@ -7,6 +7,7 @@ from django.conf import settings
 from django.utils.encoding import force_str
 
 from django.db import models
+from django.db.utils import DatabaseError
 from django.utils.translation import gettext_lazy as _
 
 from django.apps import apps ; get_models = apps.get_models
@@ -31,7 +32,7 @@ class BuildSiteCache(dd.Action):
     url_action_name = "buildjs"
 
     def run_from_ui(self, ar):
-        settings.SITE.kernel.default_renderer.build_site_cache(True)
+        settings.SITE.build_site_cache(force=True)
         return ar.success(
             """\
 Seems that it worked. Refresh your browser.
@@ -39,7 +40,7 @@ Seems that it worked. Refresh your browser.
 Note that other users might experience side effects because
 of the unexpected .js update, but there are no known problems so far.
 Please report any anomalies.""",
-            alert=_("Success"))
+            alert=_("Success"), clear_site_cache=True)
 
 
 if False:
@@ -56,6 +57,22 @@ class SiteConfig(dd.Model):
         abstract = dd.is_abstract_model(__name__, 'SiteConfig')
         verbose_name = _("Site configuration")
 
+    config_id = 1
+    """
+    The primary key of the one and only :class:`SiteConfig
+    <lino.modlib.system.SiteConfig>` instance of this
+    :class:`Site`. Default value is 1.
+
+    This is Lino's equivalent of Django's :setting:`SITE_ID` setting.
+    Lino applications don't need ``django.contrib.sites`` (`The
+    "sites" framework
+    <https://docs.djangoproject.com/en/4.1/ref/contrib/sites/>`_)
+    because an analog functionality is provided by
+    :mod:`lino.modlib.system`.
+    """
+
+
+
     if False:
         objects = SiteConfigManager()
         real_objects = models.Manager()
@@ -73,6 +90,49 @@ class SiteConfig(dd.Model):
         verbose_name=_("Site operator"),
         related_name='site_company_sites')
 
+    _site_config = None
+
+    @classmethod
+    def clear_site_config(cls):
+        cls._site_config = None
+
+    @classmethod
+    def get_site_config(cls):
+
+        site = settings.SITE
+
+        if not site._startup_done:
+            return None
+
+        if cls._site_config is None:
+            #~ raise Exception(20130301)
+            #~ print '20130320 create _site_config'
+            #~ from lino.core.utils import resolve_model
+            # from lino.core.utils import obj2str
+            SiteConfig = cls
+            try:
+                cls._site_config = SiteConfig.objects.get(id=cls.config_id)
+                # print("20180502 loaded SiteConfig {}",
+                #       obj2str(self._site_config, True))
+            except (SiteConfig.DoesNotExist, DatabaseError):
+                # e.g. during migrate the SiteConfig maybe doesn't yet exist
+            # except SiteConfig.DoesNotExist:
+            #~ except Exception,e:
+                kw = dict(id=cls.config_id)
+                #~ kw.update(settings.SITE.site_config_defaults)
+                kw.update(site.site_config_defaults)
+                site_config = SiteConfig(**kw)
+                site_config.full_clean()
+                # site_config.save() 20220824 don't save it too quickly
+                cls._site_config = site_config
+                # print("20180502 Created SiteConfig {}".format(
+                #     obj2str(self._site_config, True)))
+                # 20120725
+                # polls_tutorial menu selection `Config --> Site Parameters`
+                # said "SiteConfig 1 does not exist"
+                # cannot save the instance here because the db table possibly doesn't yet exit.
+                #~ self._site_config.save()
+        return cls._site_config
 
     def __str__(self):
         return force_str(_("Site Parameters"))
@@ -90,10 +150,34 @@ class SiteConfig(dd.Model):
         self.full_clean()
         self.save()
 
+    # def update_from(self, other):
+    #     cls = self.__class__
+    #     kw = dict()
+    #     for fld in cls._meta.concrete_fields:
+    #         if fld.attname != "id":
+    #             kw[fld.attname] = getattr(other, fld.attname)
+    #     self.update(**kw)
+
     def save(self, *args, **kw):
+        cls = self.__class__
+        if cls._site_config is None:
+            cls._site_config = self
+        elif cls._site_config is not self:
+            diffs = []
+            for fld in cls._meta.concrete_fields:
+                oldval = getattr(cls._site_config, fld.attname)
+                newval = getattr(self, fld.attname)
+                if oldval != newval:
+                    diffs.append(
+                        "{}: {} -> {}".format(fld.attname, oldval, newval))
+            if len(diffs):
+                print("20220824 Overriding SiteConfig instance (diffs={})".format(diffs))
+            cls._site_config = self
+            # cls._site_config.update_from(self)
+            # return
         # print("20180502 save() {}".format(dd.obj2str(self, True)))
-        super(SiteConfig, self).save(*args, **kw)
-        settings.SITE.clear_site_config()
+        super().save(*args, **kw)
+        # settings.SITE.clear_site_config()
 
 
 def my_handler(sender, **kw):
@@ -220,8 +304,8 @@ class Dashboard(EmptyTable):
     #     if m is None:
     #         continue
     #     assert m is not Problem
-    #     m.define_action(check_data=UpdateProblemsByController(m))
-    #     m.define_action(fix_problems=FixProblemsByController(m))
+    #     m.define_action(check_data=UpdateMessagesByController(m))
+    #     m.define_action(fix_problems=FixMessagesByController(m))
 
 
 class BleachChecker(Checker):
