@@ -84,10 +84,14 @@ class Plugin(ad.Plugin):
 
     """
 
-    media_root = None
     # media_base_url = "http://www.tinymce.com/js/tinymce/jscripts/tiny_mce/"
     # media_base_url = "http:////tinymce.cachefly.net/4.1/tinymce.min.js"
 
+    def on_init(self):
+        super().on_init()
+        if self.site.default_ui != "lino.modlib.extjs":
+            self.deactivate()
+
     def get_used_libs(self, html=False):
         if html is not None:
             yield ("TinyMCE", TINYMCE_VERSION, "http://www.tinymce.com/")
