@@ -24,9 +24,9 @@ class Plugin(ad.Plugin):
     """
 
     def on_ui_init(self, kernel):
-        from django.conf import settings
-        super(Plugin, self).on_ui_init(kernel)
-        kernel.site.makedirs_if_missing(self.get_uploads_root())
+        # from django.conf import settings
+        super().on_ui_init(kernel)
+        self.site.makedirs_if_missing(self.get_uploads_root())
 
     def get_uploads_root(self):
         # from django.conf import settings
