@@ -1,5 +1,5 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2008-2021 Rumma & Ko Ltd
+# Copyright 2008-2023 Rumma & Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
 
 import shutil
@@ -8,9 +8,15 @@ from pathlib import Path
 from django.db import models
 from django.conf import settings
 from django.core.files.storage import default_storage
+from django.core.exceptions import ValidationError, FieldError
+from django.template.defaultfilters import filesizeformat
 
 from etgen.html import E
+from rstgen.sphinxconf.sigal_image import parse_image_spec
 from lino.api import dd, rt, _
+from lino.modlib.memo.mixins import MemoReferrable
+# from lino.mixins.sequenced import Sequenced
+# from lino.modlib.gfks.mixins import Controllable
 from .choicelists import UploadAreas
 
 
@@ -56,6 +62,20 @@ def demo_upload(filename, src=None, upload_date=None, **kw):
     return rt.models.uploads.Upload(**kw)
 
 
+# class FileUsable(Sequenced, Controllable):
+#
+#     class Meta:
+#         abstract = True
+#
+#     file = None
+#
+#     @classmethod
+#     def on_analyze(cls, site):
+#         if cls.file is None:
+#             raise FieldError("Set 'file' field to ForeignKey pointing to a file model.")
+#         return super().on_analyze(site)
+
+
 class UploadController(dd.Model):
 
     class Meta(object):
@@ -86,7 +106,7 @@ class GalleryViewable(dd.Model):
         return {}
 
 
-class UploadBase(GalleryViewable):
+class UploadBase(MemoReferrable, GalleryViewable):
 
     class Meta(object):
         abstract = True
@@ -116,12 +136,6 @@ class UploadBase(GalleryViewable):
         self.size = uf.size
         self.mimetype = uf.content_type
 
-        if self.size > settings.SITE.max_file_size:
-            raise ValidationError(
-                _("File size is {}! Must be below {}.").format(
-                    filesizeformat(self.size),
-                    filesizeformat(settings.SITE.max_file_size)))
-
         # Certain Python versions or systems don't manage non-ascii filenames,
         # so we replace any non-ascii char by "_". In Py3, encode() returns a
         # bytes object, but we want the name to remain a str.
@@ -146,7 +160,7 @@ class UploadBase(GalleryViewable):
         dd.logger.info("Wrote uploaded file %s", ff.path)
 
     def full_clean(self, *args, **kw):
-        super(UploadBase, self).full_clean(*args, **kw)
+        super().full_clean(*args, **kw)
         self.file_size = self.get_real_file_size()
 
     def get_gallery_item(self, ar):
@@ -167,3 +181,20 @@ class UploadBase(GalleryViewable):
             url = settings.SITE.build_media_url(self.file.name)
             return E.a(text, href=url, target="_blank")
         return text
+
+    def memo2html(self, ar, text, **kwargs):
+        # if not text:
+        #     text = self.description or str(self)
+        kwargs.update(caption=self.description or str(self))
+        text, kwargs = parse_image_spec(text, **kwargs)
+        kwargs.update(src=settings.SITE.build_media_url(self.file.name))
+        kwargs.update(href=ar.renderer.obj2url(ar, self))
+
+        # if ar.renderer.front_end.media_name == 'react':
+        #     return ('<figure class="lino-memo-image"><img src="{src}" ' +
+        #         'style="{style}" title="{caption}"/><figcaption' +
+        #         ' style="text-align: center;">{caption}</figcaption>' +
+        #         '</figure>').format(**kwargs)
+
+        return ('<a href="{href}" target="_blank"/><img src="{src}"' +
+            ' style="{style}" title="{caption}"/></a>').format(**kwargs)
