@@ -13,7 +13,6 @@ from django.conf import settings
 from django.utils.text import format_lazy
 # from lino.api import string_concat
 from django.utils.translation import pgettext_lazy as pgettext
-from django.template.defaultfilters import filesizeformat
 from django.core.exceptions import ValidationError
 
 from etgen.html import E, join_elems, tostring
@@ -28,7 +27,8 @@ from lino.modlib.checkdata.choicelists import Checker
 
 from .choicelists import Shortcuts, UploadAreas
 from .mixins import UploadController, UploadBase
-
+# from .mixins import FileUsable
+from lino.core import constants
 
 def filename_leaf(name):
     i = name.rfind('/')
@@ -96,6 +96,8 @@ class Upload(UploadBase, UserAuthored, Controllable):
         verbose_name = _("Upload file")
         verbose_name_plural = _("Upload files")
 
+    memo_command = 'upload'
+
     upload_area = UploadAreas.field(default='general')
     type = dd.ForeignKey("uploads.UploadType", blank=True, null=True)
     volume = dd.ForeignKey("uploads.Volume", blank=True, null=True)
@@ -117,6 +119,16 @@ class Upload(UploadBase, UserAuthored, Controllable):
             s = str(self.type) + ' ' + s
         return s
 
+    def get_memo_command(self, ar=None):
+        if dd.is_installed('memo'):
+            cmd = f"[upload {self.pk}"
+            if self.description:
+                cmd += " " + self.description + "]"
+            else:
+                cmd += "]"
+            return cmd
+        return None
+
     @dd.displayfield(_("Description"))
     def description_link(self, ar):
         s = str(self)
@@ -143,6 +155,16 @@ class Upload(UploadBase, UserAuthored, Controllable):
         if self.type is not None:
             self.upload_area = self.type.upload_area
 
+
+# class FileUsage(FileUsable):
+#     class Meta(object):
+#         abstract = dd.is_abstract_model(__name__, 'FileUsage')
+#         verbose_name = _("Usage")
+#         verbose_name_plural = _("File usages")
+#
+#     file = dd.ForeignKey("uploads.Upload")
+
+
 dd.update_field(Upload, 'user', verbose_name=_("Uploaded by"))
 
 
@@ -303,7 +325,7 @@ class AreaUploads(Uploads):
     required_roles = dd.login_required((OfficeUser, OfficeOperator))
     stay_in_grid = True
     # _upload_area = UploadAreas.general
-    display_mode_main = 'summary'
+    display_mode = ((None, constants.DISPLAY_MODE_SUMMARY), )
 
     # 20180119
     # @classmethod
