@@ -1,5 +1,5 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2011-2022 Rumma & Ko Ltd
+# Copyright 2011-2023 Rumma & Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
 
 import datetime
@@ -60,7 +60,7 @@ class VerifyUser(dd.Action):
     # default_format = 'json'
     required_roles = set([])
     # required_roles = dd.login_required(SiteAdmin)
-    # show_in_bbar = False
+    # show_in_toolbar = False
     # show_in_workflow = True
     parameters = dict(
         email=models.EmailField(_('e-mail address')),
@@ -113,7 +113,7 @@ class VerifyUser(dd.Action):
 class MySettings(dd.Action):
     label = _("My settings")
     select_rows = False
-    show_in_bbar = False
+    show_in_toolbar = False
     # http_method = "POST"
     default_format = None
 
@@ -128,10 +128,10 @@ class MySettings(dd.Action):
 class SendWelcomeMail(dd.Action):
     label = _("Welcome mail")
     if True:  # #1336
-        show_in_bbar = True
+        show_in_toolbar = True
         show_in_workflow = False
     else:
-        show_in_bbar = False
+        show_in_toolbar = False
         show_in_workflow = True
     button_text = "\u2709"  # ✉
     # required_roles = dd.login_required(SiteAdmin)
@@ -236,7 +236,7 @@ class SignOut(dd.Action):
     label = _("Sign out")
     select_rows = False
     default_format = 'ajax'
-    show_in_bbar = False
+    show_in_toolbar = False
 
     def run_from_ui(self, ar, **kw):
         # print(20170921, ar.request)
@@ -272,7 +272,7 @@ def validate_sessions_limit(request):
             _("There are more than {} active user sessions. Please try again later.").format(
                 dd.plugins.users.active_sessions_limit))
 
-def get_social_auth_links_func(content_header, flex_row):
+def get_social_auth_links_func(content_header, flex_row, ar=None):
     def text_fn(*args):
         elems = [E.div(
             E.hr(style="width: -moz-available; margin-right: 1ch;"),
@@ -281,7 +281,15 @@ def get_social_auth_links_func(content_header, flex_row):
             style='display: flex;')]
         elems.append(E.br())
         links = []
+        linked = set()
+        if ar is not None:
+            user = ar.get_user()
+            if not user.is_anonymous:
+                for sauth in user.social_auth.all():
+                    linked.add(sauth.provider)
         for name, href in settings.SITE.get_social_auth_links(chunks=True):
+            if name in linked:
+                continue
             anchor = E.a(E.span(" " + name, CLASS='pi pi-' + name) , href=href)
             style = "padding: 1ch; margin: 2px; border: 2px solid gray; border-radius: 6px;"
             if flex_row:
@@ -314,7 +322,7 @@ class SignIn(dd.Action):
     """)
 
     http_method = "POST"
-    # show_in_bbar = False
+    # show_in_toolbar = False
 
     def run_from_ui(self, ar, **kw):
         # ipdict = dd.plugins.ipdict
@@ -328,10 +336,12 @@ class SignIn(dd.Action):
         else:
             # user.is_authenticated:
             auth.login(ar.request, user)
+            # gurl = ar.renderer.front_end.build_plain_url()
             ar.success(
                 _("Now logged in as {}").format(user),
                 close_window=True,
-                goto_url=ar.renderer.front_end.build_plain_url())
+                goto_url='/')
+
 
 class CreateAccount(dd.Action):
     label = _("Create Account")
@@ -356,7 +366,7 @@ class CreateAccount(dd.Action):
     social_auth_links
     """
     http_method = "POST"
-    # show_in_bbar = False
+    # show_in_toolbar = False
 
     def run_from_ui(self, ar, **kw):
         # validate_sessions_limit(ar.request)
@@ -384,6 +394,16 @@ class CreateAccount(dd.Action):
         rt.models.about.About.sign_in.run_from_ui(ar)
 
 
+class ConnectAccount(dd.Action):
+    label = _("Connect account")
+
+    def run_from_ui(self, ar, **kw):
+        cb = ar.add_callback(get_social_auth_links_func(gettext("Connect account"), flex_row=False, ar=ar)())
+        cb.add_choice('cancel', lambda x: None, gettext("Cancel"))
+        cb.set_title(gettext("Connect account"))
+        ar.set_callback(cb)
+
+
 class SignInWithSocialAuth(SignIn):
     # 20171207 nice as an example of a action dialog window with a
     # HtmlBox, but we don't currently use it.
