@@ -44,7 +44,7 @@ class Authored(Printable):
         """
         if ar and ar.user:
             self.set_author(ar.user)
-        super(Authored, self).on_duplicate(ar, master)
+        super().on_duplicate(ar, master)
 
     def get_row_permission(self, ar, state, ba):
         """Only "managers" can edit other users' work.
@@ -52,7 +52,7 @@ class Authored(Printable):
         See also :attr:`manager_roles_required`.
 
         """
-        if not super(Authored, self).get_row_permission(ar, state, ba):
+        if not super().get_row_permission(ar, state, ba):
             return False
         if ar and ba.action.select_rows:
             user = ar.get_user()
@@ -68,7 +68,7 @@ class Authored(Printable):
     def on_analyze(cls, site):
         if hasattr(cls, 'manager_level_field'):
             raise ChangedAPI("{0} has a manager_level_field".format(cls))
-        super(Authored, cls).on_analyze(site)
+        super().on_analyze(site)
 
     # no longer needed after 20170826
     # @classmethod
@@ -83,14 +83,14 @@ class Authored(Printable):
 
     @classmethod
     def get_simple_parameters(cls):
-        for p in super(Authored, cls).get_simple_parameters():
+        for p in super().get_simple_parameters():
             yield p
         yield 'user'  # cls.author_field_name)
 
     def get_print_language(self):
         u = self.get_author()
         if u is None or not u.language:
-            return super(Authored, self).get_print_language()
+            return super().get_print_language()
         return u.language
 
 
@@ -122,7 +122,7 @@ class UserAuthored(Authored):
             u = ar.user
             if u is not None:
                 self.user = u
-        super(UserAuthored, self).on_create(ar)
+        super().on_create(ar)
 
     def get_time_zone(self):
         """Return the author's timezone. Used by
@@ -164,7 +164,7 @@ class My(dbtables.Table):
 
     @classmethod
     def param_defaults(self, ar, **kw):
-        kw = super(My, self).param_defaults(ar, **kw)
+        kw = super().param_defaults(ar, **kw)
         # kw.update(user=ar.get_user())
         # k = self.author_field_name or self.model.author_field_name
         # kw[k] = ar.get_user()
@@ -174,7 +174,7 @@ class My(dbtables.Table):
 
 
 class StartPlan(dd.Action):
-    show_in_bbar = False
+    show_in_toolbar = False
     # icon_name = 'basket'
     sort_index = 52
     select_rows = False
@@ -276,7 +276,7 @@ class AssignToMe(dd.Action):
     """
     label = _("Assign to me")
     show_in_workflow = True
-    show_in_bbar = False  # added 20180515 for noi. possible side
+    show_in_toolbar = False  # added 20180515 for noi. possible side
                           # effects in welfare.
 
     # readonly = False
@@ -297,8 +297,7 @@ class AssignToMe(dd.Action):
         #     return False
         # if user == obj.get_author():
         #     return False
-        return super(AssignToMe,
-                     self).get_action_permission(ar, obj, state)
+        return super().get_action_permission(ar, obj, state)
 
     def run_from_ui(self, ar, **kw):
         obj = ar.selected_rows[0]
@@ -333,7 +332,7 @@ class TakeAuthorship(dd.Action):
     """
     label = _("Take")
     show_in_workflow = True
-    show_in_bbar = False
+    show_in_toolbar = False
 
     # This action modifies the object, but we don't tell Lino about it
     # because we want that even non-manager users can run it on
@@ -409,7 +408,7 @@ class Assignable(Authored):
     """
 
     def disabled_fields(self, ar):
-        s = super(Assignable, self).disabled_fields(ar)
+        s = super().disabled_fields(ar)
         user = ar.get_user()
         if self.assigned_to == user:
             s.add('assign_to_me')
@@ -424,11 +423,11 @@ class Assignable(Authored):
         # 20130722 e.g. CreateClientEvent sets assigned_to it explicitly
         if self.assigned_to is None:
             self.assigned_to = ar.subst_user
-        super(Assignable, self).on_create(ar)
+        super().on_create(ar)
 
 
     @classmethod
     def get_simple_parameters(cls):
-        for p in super(Assignable, cls).get_simple_parameters():
+        for p in super().get_simple_parameters():
             yield p
         yield 'assigned_to'
