@@ -1,9 +1,10 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2011-2020 Rumma & Ko Ltd
+# Copyright 2011-2023 Rumma & Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
 
 import datetime
 from django.db import models
+from django.db.models import Q
 from django.conf import settings
 from django.contrib.auth.base_user import AbstractBaseUser, BaseUserManager
 from django.utils import timezone
@@ -20,10 +21,9 @@ from lino.mixins import DateRange
 from .choicelists import UserTypes
 from .mixins import UserAuthored  #, TimezoneHolder
 from .actions import ChangePassword, SignOut, VerifyUser, CheckedSubmitInsert
-from .actions import SendWelcomeMail, SignIn, CreateAccount
+from .actions import SendWelcomeMail, SignIn, CreateAccount, ConnectAccount
 from .actions import MySettings
 # from .actions import SignIn
-from lino.core.auth.utils import AnonymousUser
 from lino.modlib.about.choicelists import TimeZones, DateFormats
 from lino.modlib.system.choicelists import DashboardLayouts
 from lino.modlib.printing.mixins import Printable
@@ -127,6 +127,8 @@ class User(AbstractBaseUser, Contactable, CreatedModified, Printable, DateRange)
 
     @property
     def is_active(self):
+        # if not self.has_usable_password():
+        #     return False
         if self.start_date and self.start_date > dd.today():
             return False
         if self.end_date and self.end_date < dd.today():
@@ -286,32 +288,20 @@ class User(AbstractBaseUser, Contactable, CreatedModified, Printable, DateRange)
         # dict(obj=self, E=E, rt=rt)
         return template.render(**context)
 
-    def as_list_item(self, ar):
-        pv = dict(username=self.username)
-        if settings.SITE.is_demo_site:
-            pv.update(password='1234')
-        btn = rt.models.about.About.get_action_by_name('sign_in')
-        # print btn.get_row_permission(ar, None, None)
-        btn = btn.request(
-            action_param_values=pv,
-            renderer=settings.SITE.kernel.default_renderer)
-        btn = btn.ar2button(label=self.username)
-        items = [ btn, ' : ',
-                  str(self), ', ',
-                  str(self.user_type)]
-        if self.language:
-            items += [', ',
-            E.strong(str(settings.SITE.LANGUAGE_DICT.get(self.language)))]
-        return E.li(*items)
-        # if settings.SITE.is_demo_site:
-        #     p = "'{0}', '{1}'".format(self.username, '1234')
-        # else:
-        #     p = "'{0}'".format(self.username)
-        # url = "javascript:Lino.show_login_window(null, {0})".format(p)
-        # return E.li(E.a(self.username, href=url), ' : ',
-        #             str(self), ', ',
-        #             str(self.user_type), ', ',
-        #             E.strong(settings.SITE.LANGUAGE_DICT.get(self.language)))
+    @classmethod
+    def get_active_users(cls, required_roles=[], unwanted_roles=None, **kwargs):
+        user_types = [t for t in UserTypes.get_list_items()
+              if t.has_required_roles(required_roles)]
+        if unwanted_roles is not None:
+            user_types = [t for t in user_types
+                if not t.has_required_roles(unwanted_roles)]
+        qs = cls.objects.filter(
+            Q(end_date__isnull=True)|Q(end_date__gt=dd.today()),
+            Q(start_date__isnull=True)|Q(start_date__lt=dd.today()),
+            user_type__in=user_types)
+        if kwargs:
+            qs = qs.filter(**kwargs)
+        return qs
 
     @classmethod
     def get_by_username(cls, username, default=models.NOT_PROVIDED):
@@ -338,10 +328,10 @@ class User(AbstractBaseUser, Contactable, CreatedModified, Printable, DateRange)
 
     @classmethod
     def get_anonymous_user(cls):
-        return AnonymousUser()
+        return settings.SITE.get_anonymous_user()
 
     # @dd.action(label=_("Send e-mail"),
-    #            show_in_bbar=True, show_in_workflow=False,
+    #            show_in_toolbar=True, show_in_workflow=False,
     #            button_text="✉")  # u"\u2709"
     # def do_send_email(self, ar):
     #     self.send_welcome_email()
@@ -432,3 +422,9 @@ def setup_memo_commands(sender=None, **kwargs):
         sender.models.users.User.objects.filter(
             username__isnull=False).order_by('username'),
         'username')
+
+
+from .ui import *
+
+if settings.SITE.has_feature('third_party_authentication'):
+    Me.connect_account = ConnectAccount()
