@@ -18,6 +18,7 @@ import sys
 from pathlib import Path
 from typing import Any, Dict, List, Tuple
 
+from synodal import KNOWN_REPOS
 from rstgen import sphinxconf
 from rstgen.sphinxconf import interproject
 from sphinx.ext import autosummary
@@ -116,15 +117,21 @@ def configure(globals_dict, django_settings_module=None):
     # be used with either atelier.sc.configure() or rstgen.sc.configure()
     # sphinxconf.configure(globals_dict, project)
 
-    im = {}
-    im['lf'] = ('https://www.lino-framework.org/', None)
-    im['cg'] = ('https://community.lino-framework.org/', None)
-    im['ug'] = ('https://using.lino-framework.org/', None)
-    im['hg'] = ('https://hosting.lino-framework.org/', None)
-    im['book'] = ('https://dev.lino-framework.org/', None)
-    # im['www'] = ('https://www.saffre-rumma.net/', None)
+    intersphinx_mappings = {}
 
-    interproject.configure(globals_dict, **im)
+    for r in KNOWN_REPOS:
+        if r.public_url:
+            intersphinx_mappings[r.nickname] = (r.public_url, None)
+
+    # intersphinx_mappings['ss'] = ('https://www.synodalsoft.net/', None)
+    # intersphinx_mappings['lf'] = (, None)
+    # intersphinx_mappings['cg'] = (, None)
+    # intersphinx_mappings['ug'] = (, None)
+    # intersphinx_mappings['hg'] = (, None)
+    # intersphinx_mappings['book'] = (, None)
+
+
+    interproject.configure(globals_dict, **intersphinx_mappings)
 
     extlinks = globals_dict.setdefault('extlinks', dict())
     extlinks['ticket'] = (
