@@ -40,3 +40,6 @@ def setup(app):
     app.add_object_type(directivename='fixture', rolename='fixture',
                         objname='demo fixture name',
                         indextemplate='pair: %s; demo fixture name')
+    app.add_object_type(directivename='feature', rolename='feature',
+                        objname='site feature name',
+                        indextemplate='pair: %s; site feature name')
