@@ -83,7 +83,8 @@ from sphinx.util import logging ; logger = logging.getLogger(__name__)
 from importlib import import_module
 
 from pathlib import Path
-from lino.core.utils import simplify_name
+from lino.modlib.help.utils import simplify_name
+
 
 useless_starts = set(['lino.core'])
 useless_endings = set(['.My', '.ByUser'])
