@@ -615,29 +615,33 @@ def get_client_ip_address(request):
     return ip or "(unknown)"  # see ticket #2605
 
 
-class DelayedValue:
-    """
+def DelayedValue(ar, fieldname, obj):
+    return dict(delayed_value_url="values/{}/{}/{}".format(
+            str(ar.actor).replace(".","/"), obj.pk, fieldname))
 
-    Creates an url for the related value and passes it to the frontend for the
-    value to be fetched later by the frontend.
-
-    """
-
-    def __init__(self, ar, fieldname, obj):
-        if fieldname is None:
-            raise Exception("20210617 {}".format(field))
-        a = ar.actor
-        self.url = "values/{}/{}/{}".format(
-            str(a).replace(".","/"), obj.pk, fieldname)
-        # print(self, self.url)
-        # self.field = field
-        # self.obj = obj
-
-    def get_url(self):
-        return self.url
-
-    def __repr__(self):
-        return "DelayedValue({})".format(self.url)
+# class DelayedValue:
+#     """
+#
+#     Creates an url for the related value and passes it to the frontend for the
+#     value to be fetched later by the frontend.
+#
+#     """
+#
+#     def __init__(self, actor, fieldname, obj):
+#         if fieldname is None:
+#             raise Exception("20210617 {}".format(field))
+#         # a = ar.actor
+#         self.url = "values/{}/{}/{}".format(
+#             str(actor).replace(".","/"), obj.pk, fieldname)
+#         # print(self, self.url)
+#         # self.field = field
+#         # self.obj = obj
+#
+#     def get_url(self):
+#         return self.url
+#
+#     def __repr__(self):
+#         return "DelayedValue({})".format(self.url)
 
 
 def _test():
