@@ -298,6 +298,7 @@ class Chooser(FieldChooser):
             #~ print e
 
         if hasattr(model, "create_%s_choice" % field.name):
+            # There is a create_FOO_choice method
             self.can_create_choice = True
 
         m = getattr(model, "%s_choice_display" % field.name, None)
@@ -310,6 +311,7 @@ class Chooser(FieldChooser):
             self.context_params)
 
     def create_choice(self, obj, text, ar=None):
+        # Call the create_FOO_choice method
         m = getattr(obj, "create_%s_choice" % self.field.name)
         return m(text, ar)
 
@@ -424,7 +426,7 @@ def uses_simple_values(holder, fld):
     # if isinstance(fld, models.OneToOneRel):
     #     return False
     if not hasattr(fld, 'name'):
-        raise Exception("DEBUG", holder, fld, fld.display_mode_main, fld.display_mode_slave)
+        raise Exception("DEBUG", holder, fld, fld.display_mode)
     if holder is not None and fld.name is not None:
         ch = holder.get_chooser_for_field(fld.name)
         if ch is not None:
