@@ -1,26 +1,26 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2012-2021 Rumma & Ko Ltd
+# Copyright 2012-2022 Rumma & Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
+# docs: https://dev.lino-framework.org/topics/utils.html
 
 """
-Defines some utilities to inspect the running Python code.
+Defines some utilities to inspect Python code.
+See :doc:`/topics/utils`.
 
 """
-import logging
-logger = logging.getLogger(__name__)
+import logging; logger = logging.getLogger(__name__)
 
 import os
 import sys
 import time
 import fnmatch
+from importlib import import_module
+from pathlib import Path
 import rstgen
 
 
-def codefiles(pattern='*'):
-    """
-    Yield a list of the source files corresponding to the currently
-    imported modules that match the given pattern
-    """
+
+def codefiles_imported(pattern='*'):
     #~ exp = re.compile(pattern, flags)
 
     for name, mod in sys.modules.copy().items():
@@ -40,17 +40,9 @@ def codefiles(pattern='*'):
 
 
 def codetime(*args, **kw):
-    """Return the modification time of the youngest source code in memory.
-
-    Used by :mod:`lino.modlib.extjs` to avoid generating .js files if
-    not necessary.
-
-    Inspired by the code_changed() function in `django.utils.autoreload`.
-
-    """
     code_mtime = None
     pivot = None
-    for name, filename in codefiles(*args, **kw):
+    for name, filename in codefiles_imported(*args, **kw):
         stat = os.stat(filename)
         mtime = stat.st_mtime
         if code_mtime is None or code_mtime < mtime:
@@ -61,6 +53,68 @@ def codetime(*args, **kw):
     return code_mtime
 
 
+
+# def codefiles(pattern='*'):
+def codefiles(module_name):
+    #~ exp = re.compile(pattern, flags)
+    mod = import_module(module_name)
+    filename = getattr(mod, "__file__", None)
+    if filename is None:
+        return
+
+    main = Path(filename)
+    suffix = main.suffix
+
+    def recurse(root):
+        for p in root.iterdir():
+            if p.suffix == suffix:
+                yield p
+            elif p.is_dir():
+                for i in recurse(p):
+                    yield i
+
+    for p in recurse(main.parent):
+        yield p
+
+
+    # if filename.endswith(".pyc") or filename.endswith(".pyo"):
+    #     filename = filename[:-1]
+    # if filename.endswith("$py.class"):
+    #     filename = filename[:-9] + ".py"
+    # File might be in an egg, so there's no source available
+    # if os.path.exists(filename):
+
+    # for name, mod in sys.modules.copy().items():
+    #     #~ if name == 'lino.extjs' and pattern == '*':
+    #         # ~ logger.info("20130801 %r -> %r", name,mod.__file__)
+    #     if fnmatch.fnmatch(name, pattern):
+    #     #~ if exp.match(name):
+    #         filename = getattr(mod, "__file__", None)
+    #         if filename is not None:
+    #             if filename.endswith(".pyc") or filename.endswith(".pyo"):
+    #                 filename = filename[:-1]
+    #             if filename.endswith("$py.class"):
+    #                 filename = filename[:-9] + ".py"
+    #             # File might be in an egg, so there's no source available
+    #             if os.path.exists(filename):
+    #                 yield name, filename
+
+
+def codetime_via_source_files(*args):  # not used
+    code_mtime = None
+    pivot = None
+    for module_name in args:
+        for filename in codefiles(module_name):
+            stat = os.stat(filename)
+            mtime = stat.st_mtime
+            if code_mtime is None or code_mtime < mtime:
+                # print 20130204, filename, time.ctime(mtime)
+                code_mtime = mtime
+                pivot = filename
+    # print('20130204 codetime:', args, time.ctime(code_mtime), pivot)
+    return code_mtime
+
+
 def is_start_of_docstring(line):
     for delim in '"""', "'''":
         if line.startswith(delim) or line.startswith('u' + delim) \
@@ -70,16 +124,18 @@ def is_start_of_docstring(line):
 
 
 class SourceFile(object):
+    # Counts the number of code lines in a given Python source file.
 
-    """
-    Counts the number of code lines in a given Python source file.
-    """
-
-    def __init__(self, modulename, filename):
-        self.modulename = modulename
+    def __init__(self, filename):
+        # print("20220917", filename)
         self.filename = filename
         self.analyze()
 
+    # def __init__(self, modulename, filename):
+    #     self.modulename = modulename
+    #     self.filename = filename
+    #     self.analyze()
+
     def analyze(self):
         self.count_code, self.count_total, self.count_blank, self.count_doc = 0, 0, 0, 0
         self.count_comment = 0
@@ -119,27 +175,21 @@ class SourceFile(object):
 
 
 def analyze_rst(*packages):
-    """
-
-    A function to produce an analytical description of the given packages in RST
-    format.
-
-    Example in :doc:`/topics/utils`.
-
-    """
     fields = 'count_code count_doc count_comment count_total'.split()
     headers = ["name", "code lines", "doc lines",
                "comment lines", "total lines"]
     rows = []
 
     def fmt(n):
-        return "{}k".format(round(n/1000.0, 1))
+        if n < 2000:
+            return "{}k".format(round(n/1000.0, 1))
+        return "{:.0f}k".format(round(n/1000, 0))
 
     total_sums = [0] * len(fields)
     for package in packages:
         sums = [0] * len(fields)
-        for name, filename in codefiles(package + '*'):
-            sf = SourceFile(name, filename)
+        for filename in codefiles(package):
+            sf = SourceFile(filename)
             for i, k in enumerate(fields):
                 sums[i] += getattr(sf, k)
         rows.append([package] + [fmt(n) for n in sums])
@@ -147,8 +197,3 @@ def analyze_rst(*packages):
             total_sums[i] += sums[i]
     rows.append(['total'] + [fmt(n) for n in total_sums])
     return rstgen.table(headers, rows)
-
-
-if __name__ == "__main__":
-    import doctest
-    doctest.testmod()
