@@ -81,7 +81,7 @@ class ConfigDirCache(object):
         config_dirs.reverse()
 
         self.LOCAL_CONFIG_DIR = None
-        local_pth = self.site.cache_dir.child(SUBDIR_NAME)
+        local_pth = self.site.site_dir / SUBDIR_NAME
         found = False
         # for pth in self.site.get_settings_subdirs(SUBDIR_NAME):
         #     writeable = pth == local_pth
@@ -101,7 +101,7 @@ class ConfigDirCache(object):
                 self.LOCAL_CONFIG_DIR = cd
 
         # self.LOCAL_CONFIG_DIR = None
-        # p = self.site.cache_dir.child(SUBDIR_NAME)
+        # p = self.site.site_dir.child(SUBDIR_NAME)
         # if isdir(p):
         #     self.LOCAL_CONFIG_DIR = ConfigDir(p, True)
         #     config_dirs.append(self.LOCAL_CONFIG_DIR)
