@@ -1,37 +1,12 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2013-2014 by Rumma & Ko Ltd.
+# Copyright 2013-2021 by Rumma & Ko Ltd.
 # License: GNU Affero General Public License v3 (see file COPYING for details)
 
-"""
-Turns a list of items into an endless loop.
-Useful when generating demo fixtures.
+""" Turns a list of items into an endless loop. Useful when generating demo
+fixtures.
 
->>> from lino.utils import Cycler
->>> def myfunc():
-...     yield "a"
-...     yield "b"
-...     yield "c"
+See examples in :doc:`/topics/utils`.
 
->>> c = Cycler(myfunc())
->>> s = ""
->>> for i in range(10):
-...     s += c.pop()
->>> print (s)
-abcabcabca
-
-An empty Cycler or a Cycler on an empty list will endlessly pop None values:
-
->>> c = Cycler()
->>> print (c.pop(), c.pop(), c.pop())
-None None None
-
->>> c = Cycler([])
->>> print (c.pop(), c.pop(), c.pop())
-None None None
-
->>> c = Cycler(None)
->>> print (c.pop(), c.pop(), c.pop())
-None None None
 """
 
 
