@@ -1,5 +1,5 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2009-2021 Rumma & Ko Ltd
+# Copyright 2009-2022 Rumma & Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
 # $ doctest lino/utils/format_date.py
 
@@ -12,11 +12,20 @@ from babel.dates import format_date as babel_format_date
 from django.conf import settings
 from django.utils import translation
 from django.template import defaultfilters
+from django.contrib.humanize.templatetags.humanize import naturaltime as hnaturaltime
 
 from lino.core.site import to_locale
 from lino.utils import IncompleteDate
 
 
+def naturaltime(v):
+    if settings.SITE.the_demo_date is None:
+        return hnaturaltime(v)
+    delta = datetime.date.today() - settings.SITE.the_demo_date
+    return hnaturaltime(v + delta)
+
+
+
 def monthname(n):
     """
     Return the monthname for month # n in current language.
