@@ -24,7 +24,7 @@ from etgen import etree
 from lino.utils import IncompleteDate
 from lino.utils.quantities import Quantity
 from lino.utils import curry
-from lino.utils import DelayedValue
+# from lino.utils import DelayedValue
 from lino.core.permissions import Permittable
 from lino.core.permissions import make_static_permission_handler
 from lino.modlib.users.utils import get_user_profile
@@ -379,10 +379,10 @@ def py2js(v, compact=True):
     """Note that None values are rendered as ``null`` (not ``undefined``.
 
     """
-    if isinstance(v, DelayedValue):
-        # v = dict(field=v.field.name, pk=v.obj.pk)
-        v = dict(delayed_value_url=v.get_url())
-        # print("20210619", v)
+    # if isinstance(v, DelayedValue):
+    #     # v = dict(field=v.field.name, pk=v.obj.pk)
+    #     v = dict(delayed_value_url=v.get_url())
+    #     # print("20210619", v)
 
     for cv in CONVERTERS:
         v = cv(v)
@@ -470,7 +470,7 @@ def py2js(v, compact=True):
         return repr(v)
     # return json.encoder.encode_basestring(v)
     # print repr(v)
-    # https://docs.djangoproject.com/en/3.2/topics/serialization/
+    # https://docs.djangoproject.com/en/4.1/topics/serialization/
     # if not isinstance(v, (str,unicode)):
         # raise Exception("20120121 %r is of type %s" % (v,type(v)))
     return json.dumps(v, sort_keys=True,
