@@ -1,22 +1,22 @@
-# Copyright 2011 Rumma & Ko Ltd
+# Copyright 2011-2021 Rumma & Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
 
 """
-This is for writing fixtures that import data from an MS-Access 
+This is for writing fixtures that import data from an MS-Access
 database (:xfile:`.mdb`) into Lino.
 
-Usage examples see 
+Usage examples see
 :mod:`lino.projects.pcsw.fixtures.pp2lino`
 and
 :mod:`lino.projects.crl.fixtures.hs2lino`.
 
-It uses `mdb-export` to extract data from the :xfile:`.mdb` 
-file to :xfile:`.csv`, then reads these csv files. 
-`mdb-export` was written by Brian Bruns and is part 
+It uses `mdb-export` to extract data from the :xfile:`.mdb`
+file to :xfile:`.csv`, then reads these csv files.
+`mdb-export` was written by Brian Bruns and is part
 of the `mdbtools` Debian package. To install it::
 
   aptitude install mdbtools
-  
+
 Usage of `mdbtools` command line::
 
   Usage: mdb-export [options] <file> <table>
@@ -30,17 +30,15 @@ Usage of `mdbtools` command line::
     -S             Sanitize names (replace spaces etc. with underscore)
     -q <char>      Use <char> to wrap text-like fields. Default is ".
     -X <char>      Use <char> to escape quoted characters within a field. Default is doubling.
-    
-Thanks to http://farismadi.wordpress.com/2008/07/13/encoding-of-mdb-tool/ 
+
+Thanks to http://farismadi.wordpress.com/2008/07/13/encoding-of-mdb-tool/
 for explanations on the environment variables used by `mdb-export`.
 
-The function :func:`check_output` in this module is a copy from Python 2.7 
+The function :func:`check_output` in this module is a copy from Python 2.7
 which we include here to make it usable in Python 2.6 too.
 
 
 """
-from __future__ import print_function
-from builtins import object
 
 import logging
 logger = logging.getLogger(__name__)
@@ -71,10 +69,12 @@ MDBTOOLS_EXPORT = 'mdb-export'
 
 
 try:
-    from subprocess import check_output
+    from subprocess import check_output, STDOUT
 except ImportError:
     import subprocess
 
+    STDOUT = subprocess.STDOUT
+
     def check_output(*popenargs, **kwargs):
         r"""Run command with arguments and return its output as a byte string.
 
@@ -82,18 +82,8 @@ except ImportError:
         CalledProcessError object will have the return code in the returncode
         attribute and output in the output attribute.
 
-        The arguments are the same as for the Popen constructor.  Example:
-
-        >>> check_output(["ls", "-l", "/dev/null"])
-        'crw-rw-rw- 1 root root 1, 3 Oct 18  2007 /dev/null\n'
-
-        The stdout argument is not allowed as it is used internally.
-        To capture standard error in the result, use stderr=STDOUT.
-
-        >>> check_output(["/bin/sh", "-c",
-        ...               "ls -l non_existent_file ; exit 0"],
-        ...              stderr=STDOUT)
-        'ls: non_existent_file: No such file or directory\n'
+        The arguments are the same as for the Popen constructor.
+        Example in :doc:`/topics/utils`.
         """
         if 'stdout' in kwargs:
             raise ValueError(
