@@ -27,6 +27,11 @@ class Quantity(Decimal):
         # return "{}%".format(self * 100)
         return self._text
 
+    def __format__(self, format_spec):
+        if format_spec:
+            return format(self._text, format_spec)
+        return self._text
+
     def __len__(self):
         return len(str(self))
 
@@ -125,10 +130,9 @@ class Duration(Quantity):
         return self
 
     # def __str__(self):
-    #     minutes = old_div((self - int(self)), DEC2HOUR)
-    #     return '%d:%02d' % (
-    #         int(self),
-    #         minutes.to_integral())
+    #     i = int(self)
+    #     minutes = (self - i) / DEC2HOUR
+    #     return '%d:%02d' % (i, minutes)
 
     def __radd__(self, other, **kwargs):
         # add a Duration to a datetime.datetime
