@@ -1,5 +1,5 @@
 # Copyright 2010-2015 Rumma & Ko Ltd
-# License: BSD (see file COPYING for details)
+# License: GNU Affero General Public License v3 (see file COPYING for details)
 """Send an email to a configurable list of addresses when a
 configurable database item has been changed.
 
@@ -38,7 +38,7 @@ import logging
 logger = logging.getLogger(__name__)
 
 from django.conf import settings
-from django.utils.translation import ugettext as _
+from django.utils.translation import gettext as _
 
 from lino.api import rt
 from lino.core.signals import receiver
