@@ -31,7 +31,7 @@ class CommonTestCase(unittest.TestCase):
 
     A :class:`unittest.TestCase` (not a :class:`django.test.TestCase`) that
     starts a Django test client on a demo database populated using
-    :manage:`prep`.
+    :cmd:`pm prep`.
 
     """
 
@@ -147,7 +147,7 @@ class DemoTestCase(PythonTestCase, CommonTestCase):
     """
 
     Base class for unit tests that are meant to run directly in a demo
-    project that has been initialized with :manage:`prep`.
+    project that has been initialized with :cmd:`pm prep`.
 
     It expects the demo database to be initialized, and it should be read-only,
     i.e. not modify any data.
@@ -173,7 +173,8 @@ class DemoTestCase(PythonTestCase, CommonTestCase):
         data = {
             constants.URL_PARAM_FIELD_VALUES: [username, pwd],
             constants.URL_PARAM_ACTION_NAME: 'sign_in'}
-        url = "/api/about/About/-99998"
+        from django.conf import settings
+        url = settings.SITE.site_prefix + "api/about/About/-99998"
         res = self.client.post(url, data)
         self.assertEqual(res.status_code, 200)
         content = res.content.decode()
